/**
 * 友好格式显示日期与时间
 * @param timestamp 时间戳（毫秒）
 * @param friendly_days 友好格式显示的最大天数（大于0时生效）
 * @returns string
 */
function friendly_format(timestamp, friendly_days = 0) {

	const current_time = new Date();
	const post_time = new Date(timestamp);
	const time_difference = current_time - post_time;

	const seconds = Math.floor(time_difference / 1000);
	const minutes = Math.floor(seconds / 60);
	const hours = Math.floor(minutes / 60);
	const days = Math.floor(hours / 24);
	const months = Math.floor(days / 30);
	const years = Math.floor(months / 12);

	if (friendly_days > 0 && days > friendly_days) {
		return post_time.toLocaleString();
	}

	if (years > 0) {
		return years + home_lang.years_ago;
	} else if (months > 0) {
		return months + home_lang.months_ago;
	} else if (days > 0) {
		return days + home_lang.days_ago;
	} else if (hours > 0) {
		return hours + home_lang.hours_ago;
	} else if (minutes > 0) {
		return minutes + home_lang.minutes_ago;
	} else {
		return seconds + home_lang.seconds_ago;
	}
}