<?php

namespace comment\config\validation;

use comment\library\config;
use venus\validation\validator\general;

class add implements \venus\validation\config
{
	private array $validator_class = [
		general::class,
		self::class
	];

	private int $min_length;
	private int $max_length;

	public function __construct()
	{
		$config = config::get_instance()->get('config');
		$this->min_length = (int)$config['min_length'];
		$this->max_length = (int)$config['max_length'];
	}

	public function get_validator_class(): array
	{
		return $this->validator_class;
	}

	public function get_rules(?string $scene): array
	{
		return [
			'data.content' => [
				'rules' => 'content',
				'errors' => [
					'content' => lang('home.invalid_content', [$this->min_length, $this->max_length])
				]
			],
			'data.module_namespace' => [
				'rules' => 'module_namespace',
				'errors' => [
					'module_namespace' => lang('app.invalid_params')
				]
			],
			'data.resource_id' => [
				'rules' => 'positive_integer',
				'errors' => [
					'positive_integer' => lang('app.invalid_params')
				]
			],
			'data.parent_id' => [
				'rules' => 'natural_number',
				'errors' => [
					'natural_number' => lang('app.invalid_params')
				]
			]
		];
	}

	/**
	 * 评论内容验证规则
	 * @param $value
	 * @return bool
	 */
	public function content($value): bool
	{
		if(!is_string($value)) {
			return false;
		}
		$length = mb_strlen(trim($value));
		return $length >= $this->min_length && $length <= $this->max_length;
	}

	/**
	 * 模块命名空间验证规则
	 * @param $value
	 * @return bool
	 */
	public function module_namespace($value): bool
	{
		return is_string($value) && !is_null(\phpvod::$app->module->get_module($value));
	}
}