<?php

namespace comment\controller\admin;

use config\validation\validator;
use phpvod\event\event;

class comment extends \phpvod\base\backend_controller
{
	protected array $helper = ['form'];
	private \comment\model\comment $model;

	public function init(): void
	{
		parent::init();
		/** @noinspection PhpFieldAssignmentTypeMismatchInspection */
		$this->model = model(\comment\model\comment::class);
	}

	/**
	 * 获取数据(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function get_data(): void
	{
		$params = $this->get_bootstrap_table_query_params();
		if ($params !== false) {
			$data = $this->model->get_data($params);
			$this->response->set_json($data);
		}
	}

	public function index(): string
	{
		return $this->view('comment/index');
	}

	/**
	 * 删除记录(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function delete(): void
	{
		$id = $this->request->post('id');
		if ($this->validation->check($id, 'id', validator::class)) {
			if(!is_array($id)) {
				$id = [$id];
			}

			/**
			 * @var \comment\service\comment $comment_service
			 */
			$comment_service = service(\comment\service\comment::class);
			foreach ($id as $value) {
				$comment_service->delete($value);
			}

			$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_id')]);
		}
	}

	/**
	 * 更改状态(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function change_status(): void
	{
		$id = $this->request->post('id');
		parent::change_status_by_id([$this->model, 'change_status'], $id, function() use($id) {
			//event
			event()->trigger(event::EVENT_UPDATE_FROM_MODULE, 'comment', $id);
		});
	}

}