<?php

namespace comment\controller;

use comment\config\validation\add;
use comment\config\validation\get_child_comment;
use comment\config\validation\get_resource_comment;
use comment\config\validation\like;
use comment\library\config;
use venus\http\status;

class home extends \phpvod\base\frontend_controller
{
	private \comment\service\comment $service;

	/** @noinspection PhpFieldAssignmentTypeMismatchInspection */
	public function init(): void
	{
		parent::init();
		$this->service = service(\comment\service\comment::class);
	}

	/**
	 * 新增评论(ajax)
	 * @route comment/add
	 * @return void
	 * @throws \Exception
	 */
	public function add(): void
	{
		if ($this->validation->load_config(add::class)->with_post()->run()) {
			$this->response->set_json($this->service->add());
		} else {
			$errors = $this->validation->get_errors();
			$msg = array_shift($errors);
			$this->response->set_json(['id' => 0, 'msg' => $msg]);
		}
	}

	/**
	 * 点赞(ajax)
	 * @route comment/like
	 * @return void
	 * @throws \Exception
	 */
	public function like(): void
	{
		if ($this->validation->load_config(like::class)->with_post()->run()) {
			$this->response->set_json($this->service->like());
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_params')]);
		}
	}

	/**
	 * 获取资源评论(ajax)
	 * @route comment/get_resource_comment
	 * @return void
	 * @throws \Exception
	 */
	public function get_resource_comment(): void
	{
		if ($this->validation->load_config(get_resource_comment::class)->with_get()->run()) {
			$params = $this->request->get();
			$data = $this->service->get_resource_comment($params['module_namespace'], $params['resource_id'], $params['order_by'], $params['page_number'], $params['items_per_page']);
			$body = $this->view('home/get_resource_comment', ['data' => $data]);
			$this->response->set_body($body);
		}
	}

	/**
	 * 获取子评论(ajax)
	 * @route comment/get_child_comment
	 * @return void
	 * @throws \Exception
	 */
	public function get_child_comment(): void
	{
		if ($this->validation->load_config(get_child_comment::class)->with_get()->run()) {
			$params = $this->request->get();
			$data = $this->service->get_child_comment($params['parent_id'], 'id ASC', $params['page_number'], $params['items_per_page']);
			$body = $this->view('home/get_child_comment', ['data' => $data, 'parent_id' => $params['parent_id']]);
			$this->response->set_body($body);
		}
	}
}