<?php
/**
 * @var \venus\view\view $this
 */
\phpvod\asset\bootstrap_table\bootstrap_table::register();
\comment\asset\emoji\emoji::register();
$admin_form = \phpvod\widget\form\admin_form::get_instance();
$this->extend('admin/layout');
?>

<?php $this->section('content'); ?>

<div class="card">
	<div class="card-header"><?= lang('admin.comment_management') ?></div>
	<div class="card-body">
		<div id="toolbar" class="toolbar-btn-action">
			<div class="input-group">
				<button type="button" class="btn btn-danger me-4" onclick="batch_delete_comment()">
					<span class="mdi mdi-window-close me-1" aria-hidden="true"></span><?= lang('app.delete') ?>
				</button>

				<span class="input-group-text"><?= lang('pv_comment.username') ?></span>
				<?= $admin_form->input('username', 'text', options: ['class' => 'form-control']) ?>

				<span class="input-group-text"><?= lang('pv_comment.module_namespace') ?></span>
				<?php
				$module = \phpvod\library\options::module();
				unset($module['comment']);
				?>
				<?= $admin_form->select('module_namespace', \phpvod\library\options::unlimited() + $module, null, ['class' => 'form-select']) ?>

				<span class="input-group-text"><?= lang('pv_comment.type') ?></span>
				<?= $admin_form->select('type', \phpvod\library\options::unlimited() + ['comment' => lang('admin.comment'), 'reply' => lang('admin.reply')], null, ['class' => 'form-select']) ?>

				<span class="input-group-text"><?= lang('pv_comment.content') ?></span>
				<?= $admin_form->input('content', 'text', options: ['class' => 'form-control']) ?>

				<span class="input-group-text"><?= lang('pv_comment.status') ?></span>
				<?= $admin_form->select('status', \phpvod\library\options::unlimited() + \phpvod\library\options::checked_unchecked(), null, ['class' => 'form-select']) ?>

				<button type="button" class="btn btn-success search-btn">
					<span class="mdi mdi-magnify me-1" aria-hidden="true"></span><?= lang('app.search') ?>
				</button>
			</div>
		</div>
		<table id="bootstrap-table"></table>
	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>

<?php $this->end_section(); ?>

<?php $this->section('js'); ?>

<script type="text/javascript">
	$.ajaxSetup({headers: <?=csrf_json()?>});

	let bt = new bootstrap_table_helper('backend_comment', ['module_namespace', 'type', 'child_count', 'like', 'dislike', 'created_at', 'ip']);

	let columns = [
		{checkbox: true, width: 4, widthUnit: 'rem'},
		{field: 'id', title: '<?= lang('pv_comment.id') ?>', sortable: true, visible: bt.visible('id')},
		{
			field: 'username',
			title: '<?= lang('pv_comment.username') ?>',
			visible: bt.visible('username'),
			formatter: function(value, row) {
				return value == null ? "<?= lang('app.guest') ?>" : value;
			},
		},
		{field: 'module_namespace', title: '<?= lang('pv_comment.module_namespace') ?>', visible: bt.visible('module_namespace')},
		{
			field: 'type',
			title: '<?= lang('pv_comment.type') ?>',
			visible: bt.visible('type'),
			formatter: function (value, row) {
				return row.parent_id == 0 ? "<?=lang('admin.comment')?>" : "<?=lang('admin.reply')?>";
			},
		},
		{field: 'content', class: 'content', title: '<?= lang('pv_comment.content') ?>', visible: bt.visible('content')},
		{
			field: 'child_count',
			title: '<?= lang('pv_comment.child_count') ?>',
			sortable: true,
			visible: bt.visible('child_count'),
		},
		{field: 'like', title: '<?= lang('pv_comment.like') ?>', sortable: true, visible: bt.visible('like')},
		{field: 'dislike', title: '<?= lang('pv_comment.dislike') ?>', sortable: true, visible: bt.visible('dislike')},
		{
			field: 'status',
			title: '<?= lang('pv_comment.status') ?>',
			visible: bt.visible('status'),
			events: {
				'click .form-check-input[role="switch"]': function (event, value, row, index) {
					//更改状态
					event.stopPropagation();
					$.post("<?= admin_module_uri('comment/change-status') ?>", {id: row.id}, function (r) {
						if (r.id === 1) {
							$(event.currentTarget).prop("checked", r.data === 1);
						} else {
							$(event.currentTarget).prop("checked", !$(event.currentTarget).is(':checked')); //返回之前的状态
							if (r.hasOwnProperty('msg'))
								layer.msg(r.msg);
							else
								layer.msg('<?=lang('app.unknown_error')?>');
						}
					});
				}
			}
		},
		{field: 'created_at', width: 12, widthUnit: 'rem', title: '<?= lang('pv_comment.created_at') ?>', sortable: true, visible: bt.visible('created_at')},
		{field: 'ip', title: '<?= lang('pv_comment.ip') ?>', visible: bt.visible('ip')},
		{
			field: '__operation__',
			width: 8,
			widthUnit: 'rem',
			title: '<?=lang('app.operation')?>',
			visible: bt.visible('__operation__'),
			formatter: function () {
				return '<button type="button" class="btn btn-outline-danger px-1 py-0 del-btn"><i class="mdi mdi-window-close me-1"></i><?=lang('app.delete')?></button>';
			},
			events: {
				'click .edit-btn': function (event, value, row, index) {
					event.stopPropagation();
					window.location.href = "<?= admin_module_uri('comment/edit')?>" + '?id=' + row.id;
				},
				'click .del-btn': function (event, value, row, index) {
					event.stopPropagation();
					delete_comment(row.id);
				}
			}
		}
	];

	let options = {
		columns,
		url: '<?=admin_module_uri('comment/get-data')?>',
		search: false,
		pagination: bt.pagination(),
		pageSize: bt.page_size(),
		locale: '<?=phpvod::$app->language->get_format_language('{lang}-{TAG}')?>',
		onColumnSwitch: function (column, checked) {
			bt.save_hidden_column(column, checked);
			show_emoji();
		},
		onPageChange: function (number, size) {
			bt.save_page_size(size);
		},
		onTogglePagination: function (status) {
			bt.save_pagination(status);
		},
		queryParams: function (params) {
			//username
			let username = $.trim($("input[name='username']").val());
			if (username !== '') {
				params.username = username;
			}
			//module_namespace
			let module_namespace = $("select[name='module_namespace']").val();
			if (module_namespace !== 'unlimited') {
				params.module_namespace = module_namespace;
			}
			//type
			let type = $("select[name='type']").val();
			if (type !== 'unlimited') {
				params.type = type;
			}
			//content
			let content = $.trim($("input[name='content']").val());
			if (content !== '') {
				params.content = content;
			}
			//status
			let status = $("select[name='status']").val();
			if (status !== 'unlimited') {
				params.status = status;
			}
			//sort
			if (params.sort === undefined) {
				params.sort = 'id';
				params.order = 'desc';
			} else if (params.sort === 'like') {
				params.sort = '`like`';
			}
			return params;
		},
		onLoadSuccess() {
			show_emoji();
		}
	};

	$('#bootstrap-table').bootstrapTable({
		...default_options,
		...options
	});

	function batch_delete_comment() {
		let select = $('#bootstrap-table').bootstrapTable('getSelections');
		if (select.length === 0) {
			layer.msg("<?=lang('app.no_object_is_selected')?>");
		} else {
			let id = $.map(select, function (row) {
				return row.id;
			});
			delete_comment(id); //id is array
		}
	}

	function delete_comment(id) {
		layer.confirm("<?=lang('app.confirm_deletion')?>", {
			icon: 3,
			title: "<?=lang('app.message')?>",
			btn: ['<?=lang('app.delete')?>', '<?=lang('app.cancel')?>']
		}, function (index) {
			$.post("<?= admin_module_uri('comment/delete') ?>", {id: id}, function (r) {
				if (r.id === 1) {
					$('#bootstrap-table').bootstrapTable('refresh');
				} else if (r.hasOwnProperty('msg')) {
					layer.msg(r.msg);
				} else {
					layer.msg('<?=lang('app.unknown_error')?>');
				}
			});
			layer.close(index);
		});
	}

	function show_emoji() {
		$("#bootstrap-table .content").emojiParse({
			icons: emoji_icons
		});
	}

	$("#toolbar .search-btn").click(function () {
		$('#bootstrap-table').bootstrapTable('refresh', {pageNumber: 1});
	});
	$("#toolbar input[type='text']").keyup(function (event) {
		if (event.keyCode === 13) { //按回车键开始搜索
			$('#bootstrap-table').bootstrapTable('refresh', {pageNumber: 1});
		}
	});
</script>
<?php $this->end_section(); ?>
