/**
 * 初始化菜单
 * @param ajax_url
 */
function init_menu(ajax_url) {
    $.get(ajax_url, function (data) {
        //init menu
        set_sidebar(data);
        //active
        $(".item-link a").off().on("click", function () {
            $(".item-link a").each(function (i, n) {
                $(n).parent().removeClass("active");
            });
            $(this).parent().addClass("active");
        });
        //open
        let side_down_obj = $("li.item-link.active").parents("ul.subnav").filter(':hidden');
        side_down_obj.each(function(i) {
            $(this).slideDown('fast', function() {
                $(this).parent('li.has-subnav').addClass('open');
            });
        });
    });
}

/**
 * 设置菜单
 * @param data 菜单JSON数据
 *        id 菜单唯一ID
 *        name 菜单名称
 *        route 菜单链接地址
 *        icon 图标
 *        parent_id  父级ID
 *        is_home 是否首页
 */
function set_sidebar(data) {
    if (data.length == 0) return false;
    let tree_obj = get_trees(data, 0, 'id', 'parent_id', 'children');
    let html = create_menu(tree_obj, 0);
    $('.sidebar-main').html(html);
}

function create_menu(data, indent) {
    let menu_body = indent === 0 ? '<ul class="nav-drawer">' : '<ul class="subnav">';
    let indent_style = 'margin-left:' + indent * 15 + 'px';
    //iframe URL中的路径部分，不含前置/
    let iframe_pathname = document.getElementById('main').contentWindow.location.pathname.substring(1);
    for (let i = 0; i < data.length; i++) {
        let iframe_class = 'target="main"';
        let icon_div = data[i].icon !== "" && data[i].icon !== null ? '<i class="mdi mdi-' + data[i].icon + '"></i>' : '';
        let menu_name = data[i].parent_id == '0' ? '<span>' + data[i].name + '</span>' : data[i].name;
        if (data[i].children && data[i].children.length > 0) {
            menu_body += '<li class="has-subnav"><a style="' + indent_style + '" href="javascript:void(0)">' + icon_div + menu_name + '</a>';
            menu_body += create_menu(data[i].children, indent + 1);
        } else {
            //let active = $("iframe").attr('src') === data[i].route ? " active" : "";
            let active = iframe_pathname === data[i].route ? " active" : "";
            menu_body += '<li class="item-link' + active + '"><a style="' + indent_style + '" href="' + data[i].route + '" ' + iframe_class + '>' + icon_div + menu_name + '</a>';
        }
        menu_body += '</li>';
    }
    menu_body += '</ul>';
    return menu_body;
}

function get_trees(list, parent_id, id_name, parent_id_name, children_name) {
    let items = {};
    for (let i = 0; i < list.length; i++) {
        let key = list[i][parent_id_name];
        if (items[key]) {
            items[key].push(list[i]);
        } else {
            items[key] = [];
            items[key].push(list[i]);
        }
    }
    return format_tree(items, parent_id, id_name, children_name);
}

function format_tree(items, parent_id, id_name, children_name) {
    let result = [];
    if (!items[parent_id]) {
        return result;
    }
    for (let t in items[parent_id]) {
        items[parent_id][t][children_name] = format_tree(items, items[parent_id][t][id_name], id_name, children_name)
        result.push(items[parent_id][t]);
    }
    return result;
}