const bt_table_options = {
    classes: 'table table-hover', //表格样式
    loadingFontSize: '14px', //提示信息文字大小
    cache: false, //是否缓存
    clickToSelect: false, // 是否启用点击选中行
    showToggle: false, // 是否显示详细视图和列表视图的切换按钮(clickToSelect同时设置为true时点击会报错)
    dataType: 'json', // 请求得到的数据类型
    method: 'get', // 请求远程数据的方法类型
    totalField: 'total', // 总数字段
    undefinedText: '-', // 当字段为 undefined 显示
    sortOrder: "asc" // 排序方式
};

const bt_pagination_options = {
    pagination: true, // 是否分页
    sidePagination: "server", // 分页方式：[client] 客户端分页，[server] 服务端分页
    pageNumber: 1,// 初始化加载第一页，默认第一页
    pageSize: 10, // 每页的记录行数
    pageList: [10, 20, 50, 100], // 可供选择的每页的行数
    paginationLoop: true, // 启用分页连续循环模式
    paginationPagesBySide: 2, // 展示首尾页的最小页数
};

const bt_button_options = {
    buttonsClass: 'outline-secondary',// 按钮样式
    buttonsPrefix: 'btn', // 按钮样式前缀
    showColumns: true, // 是否显示列选按钮
    showRefresh: true, // 是否显示刷新按钮
    showPaginationSwitch: true, // 开关控制分页
    showFullscreen: false, // 显示全屏
    showButtonIcons: true, // 显示图标
    showButtonText: true, // 显示文本
    toolbar: '#toolbar' // 工具按钮容器
}

const bt_search_options = {
    search: false, //启用搜索输入
    showSearchButton: false, //在搜索输入后面显示搜索按钮。仅在按下按钮时才会执行搜索
    showSearchClearButton: false, //在搜索输入后面显示一个清除按钮，该按钮将清除搜索输入
    searchOnEnterKey: true, //是否按下回车键才开始搜索
    strictSearch: false, //是否启用严格搜索
    trimOnSearch: true, //去除搜索字段中的空格
    searchAlign: 'right', //搜索框位置，可选(left/right)
    searchTimeOut: 500, //搜索触发超时
    searchText: '', //搜索框初始化文本
    queryParamsType: 'limit' //params对象包含：limit, offset, search, sort, order.
}

const bt_icon = {
    iconsPrefix: 'mdi',  // 图标前缀
    iconSize: 'mini', // 图标大小
    icons: {
        paginationSwitchDown: 'mdi-door-closed',
        paginationSwitchUp: 'mdi-door-open',
        refresh: 'mdi-refresh',
        toggleOff: 'mdi-toggle-switch-off',
        toggleOn: 'mdi-toggle-switch',
        columns: 'mdi-table-column-remove',
        detailOpen: 'mdi-plus',
        detailClose: 'mdi-minus',
        fullscreen: 'mdi-monitor-screenshot',
        search: 'mdi-table-search',
        clearSearch: 'mdi-trash-can-outline'
    }
};

const default_options = {
    ...bt_table_options, ...bt_pagination_options, ...bt_search_options, ...bt_button_options, ...bt_icon
};

class bootstrap_table_helper {
    table_name = undefined;
    settings = {};

    /**
     * 构造函数
     * @param table_name 表名
     * @param hidden_column 默认隐藏的字段
     * @param pagination
     * @param page_size
     */
    constructor(table_name, hidden_column = [], pagination = true, page_size = 10) {
        this.table_name = table_name;
        let item = localStorage.getItem(this.table_name);
        if (item != null) {
            this.settings = JSON.parse(item);
        } else {
            this.settings = {
              hidden_column: hidden_column,
              pagination: pagination,
              page_size: page_size
            };
        }
    }

    /**
     * 返回指定的字段是否显示
     * @param column 字段名
     * @returns {boolean}
     */
    visible(column) {
        return this.settings.hidden_column.indexOf(column) === -1;
    }

    pagination() {
        return this.settings.pagination;
    }

    page_size() {
        return this.settings.page_size;
    }

    /**
     * 保存隐藏列
     * @param column 列名
     * @param checked 是否选中
     */
    save_hidden_column(column, checked) {
        let idx = this.settings.hidden_column.indexOf(column)
        if (checked && idx >= 0) { //显示字段
            this.settings.hidden_column.splice(idx, 1);
        } else if (!checked && idx === -1) { //隐藏字段
            this.settings.hidden_column.push(column);
        }
        this.save_settings();
    }

    /**
     * 保存分页状态
     * @param status
     */
    save_pagination(status) {
        this.settings.pagination = status;
        this.save_settings();
    }

    /**
     * 保存每页记录数
     * @param size
     */
    save_page_size(size) {
        this.settings.page_size = size;
        this.save_settings();
    }

    save_settings() {
        localStorage.setItem(this.table_name, JSON.stringify(this.settings));
    }
}