<?php

namespace phpvod\base;

use phpvod\widget\toastr;
use venus\application\exception\controller_exception;
use venus\http\request;
use venus\http\response;
use venus\validation\validation;

class controller extends \venus\base\controller
{
	protected request $request;
	protected response $response;
	protected validation $validation;

	public function init(): void
	{
		parent::init();
		$this->request = \phpvod::$app->request;
		$this->response = \phpvod::$app->response;
		$this->validation = \phpvod::$app->validation;
	}

	/**
	 * 跳转
	 * @param string $url
	 * @param bool $with_input
	 * @param bool|array|string|null $message 提示信息
	 * @return void
	 * @throws \Exception
	 */
	protected function redirect(string $url, bool $with_input = false, bool|array|string|null $message = null): void
	{
		//with_input
		$with_input && $this->response->with_input();

		//message
		if ($message === true) {
			$this->set_success_message();
		} elseif ($message === false) {
			$this->set_error_message();
		} elseif (is_string($message) || is_array($message)) {
			$this->set_message($message);
		}

		$this->response->redirect($url);
	}

	/**
	 * 设置toastr提示消息
	 * @param array|string $message
	 * @param string $type
	 * @throws \Exception
	 */
	protected function set_message(array|string $message, string $type = toastr::TYPE_ERROR): void
	{
		toastr::set_data([$type => $message]);
	}

	/**
	 * set_success_message
	 * @return void
	 * @throws \Exception
	 */
	protected function set_success_message(): void
	{
		$this->set_message(lang('app.operation_succeeded'), toastr::TYPE_SUCCESS);
	}

	/**
	 * set_error_message
	 * @return void
	 * @throws \Exception
	 */
	protected function set_error_message(): void
	{
		$this->set_message(lang('app.operation_failed'), toastr::TYPE_ERROR);
	}

	/**
	 * set_message_from_validator
	 * @param string $type
	 * @return void
	 * @throws \Exception
	 */
	protected function set_message_from_validator(string $type = toastr::TYPE_ERROR): void
	{
		$message = $this->validation->get_errors();
		if (!empty($message)) {
			$this->set_message($message, $type);
		}
	}

	/**
	 * view
	 * @param string $view
	 * @param array $data
	 * @return string
	 * @throws \Exception
	 */
	protected function view(string $view, array $data = []): string
	{
		return view($view, $data);
	}
}