<?php

namespace phpvod\base;

use phpvod\component\user_auth\user_auth;
use phpvod\controller\captcha;
use phpvod\library\config\config;
use phpvod\model\member;
use venus\application\exception\controller_exception;

class frontend_controller extends controller
{
	public const SHOW_MESSAGE_GO_HOME_BTN = 0;
	public const SHOW_MESSAGE_GO_BACK_BTN = 1;

	protected string $template_directory;

	/**
	 * init
	 * @throws \Exception
	 */
	public function init(): void
	{
		parent::init();
		//install
		if(!is_file(\phpvod\controller\install\home::INSTALL_LOCK)) {
			$this->redirect(uri('install/index'));
		}

		//user_auth component
		\phpvod::$app->register('user_auth', user_auth::class);
		/* @var member $member_model */
		$member_model = model(member::class);
		\phpvod::$app->user_auth->init($member_model);

		//template_directory
		$config_template = config::get_instance()->get('config_template');
		$current_module = \phpvod::$app->module->get_current_module();
		if (is_null($current_module)) {
			$this->template_directory = isset($config_template['phpvod']) && !is_blank($config_template['phpvod']) ? $config_template['phpvod'] : 'home';
		} else {
			$namespace = $current_module['namespace'];
			$this->template_directory = isset($config_template['module'][$namespace]) && !is_blank($config_template['module'][$namespace]) ?
				$config_template['module'][$namespace] : 'home';
		}

		//site_status
		$site_status = config::get_instance()->get('config_site', 'site_status');
		$controller = \phpvod::$app->router->get_controller();
		$exclude_controller_list = [
			captcha::class
		];
		if ($site_status != '1' && !in_array($controller, $exclude_controller_list)) {
			if ($this->request->is_ajax()) {
				$this->response->set_json(['id' => 0, 'msg' => lang('home.site_is_closed')]);
				throw controller_exception::for_interrupt();
			} else {
				$this->show_message(lang('home.site_is_closed'));
			}
		}
	}

	/**
	 * 显示消息页面
	 * @param string $message
	 * @param array $btn
	 * @return void
	 * @throws \Exception
	 */
	public function show_message(string $message, array $btn = []): void
	{
		$config_template = config::get_instance()->get('config_template');
		$template_directory = isset($config_template['phpvod']) && !is_blank($config_template['phpvod']) ? $config_template['phpvod'] : 'home';
		$data = ['message' => $message, 'btn' => $btn];
		$view = \phpvod::$app->view->set_view_path(APP_PATH . 'view')->set_data($data)->render($template_directory . '/system/message');
		$this->response->set_body($view);
		throw controller_exception::for_interrupt();
	}

	/**
	 * 模块跳转
	 * @param string $uri
	 * @param bool $with_input
	 * @param $message
	 * @return void
	 * @throws \Exception
	 */
	protected function module_redirect(string $uri, bool $with_input = false, $message = null): void
	{
		parent::redirect(home_module_uri($uri), $with_input, $message);
	}

	/**
	 * 载入视图
	 * @param string $view
	 * @param array $data
	 * @return string
	 * @throws \Exception
	 */
	protected function view(string $view, array $data = []): string
	{
		return parent::view($this->template_directory . '/' . $view, $data);
	}
}