<?php
/**
 * 获取前台会员权限
 * @param string $name 权限名称
 * @return mixed 返回权限值，权限不存在时返回null
 */
function get_permission(string $name): mixed
{
	return phpvod::$app->user_auth->get_frontend_permission($name);
}

/**
 * 容量单位转换为字符数
 * @param string $size
 * @return float
 */
function size2bytes(string $size): float
{
	$unit_list = ['B', 'KB', 'MB', 'GB', 'TB', 'PB'];
	$size = strtoupper(trim($size));
	$unit = substr($size, -2);
	if (!in_array($unit, $unit_list)) {
		$unit = 'B';
	}
	$size = floatval($size);
	$exp = array_search($unit, $unit_list);
	return $size * (1024 ** $exp);
}

/**
 * 字节数转换为容量单位
 * @param float $bytes
 * @return string
 */
function bytes2size(float $bytes): string
{
	$unit = ['B', 'KB', 'MB', 'GB', 'TB', 'PB'];
	if ($bytes == 0) {
		return '0B';
	}
	$exp = floor(log($bytes, 1024));
	$size = round($bytes / (1024 ** $exp), 2);
	return $size . '' . $unit[$exp];
}

/**
 * 秒数转换为时长
 * @param int $seconds 秒数
 * @return string
 */
function seconds2duration(int $seconds): string
{
	$hours = floor($seconds / 3600);
	$minutes = floor(($seconds / 60) % 60);
	$seconds = $seconds % 60;
	return sprintf('%02d:%02d:%02d', $hours, $minutes, $seconds);
}

/**
 * 时长转换成秒数
 * @param string $duration 时长字符串，格式：xx:xx:xx
 * @return int
 */
function duration2seconds(string $duration): int
{
	$time_array = explode(':', $duration);
	$hours = isset($time_array[0]) ? intval($time_array[0]) : 0;
	$minutes = isset($time_array[1]) ? intval($time_array[1]) : 0;
	$seconds = isset($time_array[2]) ? intval($time_array[2]) : 0;
	return $hours * 3600 + $minutes * 60 + $seconds;
}

/**
 * 时间戳转字符串
 * @param mixed $timestamp
 * @param string $format
 * @param bool $easy_to_read
 * @return string
 */
function timetostr(mixed $timestamp = TIMESTAMP, string $format = 'Y-m-d H:i:s', bool $easy_to_read = false): string
{
	if (empty($timestamp)) {
		return '-';
	}

	if ($easy_to_read && TIMESTAMP > $timestamp) {
		$time_diff = TIMESTAMP - $timestamp;
		if ($time_diff < 60) {
			return lang('app.seconds_ago', [$time_diff]);
		} elseif ($time_diff < 3600) {
			return lang('app.minutes_ago', [floor($time_diff / 60)]);
		} elseif ($time_diff < 86400) {
			return lang('app.hours_ago', [floor($time_diff / 3600)]);
		}
	}

	return @date($format, $timestamp);
}

/**
 * 判断值是否为空
 * @param string $value
 * @return bool
 */
function is_blank(string $value): bool
{
	return trim($value) === '';
}
