<?php

namespace config\validation\admin;

use config\validation\validator;
use venus\validation\validator\general;

class admin implements \venus\validation\config
{
	private array $validator_class = [
		general::class,
		validator::class
	];

	/**
	 * @inheritDoc
	 */
	public function get_validator_class(): array
	{
		return $this->validator_class;
	}

	/**
	 * @inheritDoc
	 */
	public function get_rules(?string $scene): array
	{
		return $scene == 'add' ? $this->add() : $this->edit();
	}

	private function add(): array
	{
		return [
			'admin.username' => [
				'rules' => ['required', 'is_unique[pv_admin.username]'],
				'errors' => [
					'required' => lang('app.username_cannot_be_empty'),
					'is_unique' => lang('app.username_already_exists')
				]
			],
			'admin.password' => [
				'rules' => 'required',
				'errors' => [
					'required' => lang('app.password_cannot_be_empty'),
				]
			],
			'admin.role_id' => [
				'rules' => 'id',
				'errors' => [
					'id' => lang('app.invalid_id')
				]
			],
			'admin.email' => [
				'rules' => ['required', 'valid_email', 'is_unique[pv_admin.email]'],
				'errors' => [
					'required' => lang('app.email_cannot_be_empty'),
					'valid_email' => lang('app.invalid_email'),
					'is_unique' => lang('app.email_already_exists')
				]
			],
			'admin.phone' => [
				'rules' => ['regex_match[/^[\+\-\d\s]*$/]'],
				'errors' => [
					'regex_match' => lang('app.invalid_phone')
				]
			]
		];
	}

	private function edit(): array
	{
		return [
			'admin.username' => [
				'rules' => ['required', 'is_unique[pv_admin.username,id,{admin.id}]'],
				'errors' => [
					'required' => lang('app.username_cannot_be_empty'),
					'is_unique' => lang('app.username_already_exists')
				]
			],
			'admin.role_id' => [
				'rules' => 'id',
				'errors' => [
					'id' => lang('app.invalid_id')
				]
			],
			'admin.email' => [
				'rules' => ['required', 'valid_email', 'is_unique[pv_admin.email,id,{admin.id}]'],
				'errors' => [
					'required' => lang('app.email_cannot_be_empty'),
					'valid_email' => lang('app.invalid_email'),
					'is_unique' => lang('app.email_already_exists')
				]
			],
			'admin.phone' => [
				'rules' => ['regex_match[/^[\+\-\d\s]*$/]'],
				'errors' => [
					'regex_match' => lang('app.invalid_phone')
				]
			]
		];
	}
}