<?php

namespace config\validation\admin;

use config\validation\validator;
use venus\validation\validator\general;

class member implements \venus\validation\config
{
	private array $validator_class = [
		general::class,
		validator::class,
		self::class
	];

	/**
	 * @inheritDoc
	 */
	public function get_validator_class(): array
	{
		return $this->validator_class;
	}

	/**
	 * @inheritDoc
	 */
	public function get_rules(?string $scene): array
	{
		return $scene == 'add' ? $this->add() : $this->edit();
	}

	private function add(): array
	{
		return [
			'member.username' => [
				'rules' => ['required', 'is_unique[pv_member.username]'],
				'errors' => [
					'required' => lang('app.username_cannot_be_empty'),
					'is_unique' => lang('app.username_already_exists')
				]
			],
			'member.password' => [
				'rules' => 'required',
				'errors' => [
					'required' => lang('app.password_cannot_be_empty'),
				]
			],
			'member.group_id' => [
				'rules' => 'id',
				'errors' => [
					'id' => lang('app.invalid_id')
				]
			],
			'member.group_expiry' => [
				'rules' => 'group_expiry',
				'errors' => [
					'group_expiry' => lang('admin.invalid_group_expiry')
				]
			],
			'member.change_to' => [
				'rules' => 'id',
				'errors' => [
					'id' => lang('app.invalid_id')
				]
			],
			'member.email' => [
				'rules' => ['required', 'valid_email', 'is_unique[pv_member.email]'],
				'errors' => [
					'required' => lang('app.email_cannot_be_empty'),
					'valid_email' => lang('app.invalid_email'),
					'is_unique' => lang('app.email_already_exists')
				]
			],
			'member.phone' => [
				'rules' => ['regex_match[/^[\+\-\d\s]*$/]'],
				'errors' => [
					'regex_match' => lang('app.invalid_phone')
				]
			],
			'member.balance' => [
				'rules' => 'money',
				'errors' => [
					'money' => lang('admin.invalid_balance')
				]
			],
		];
	}

	private function edit(): array
	{
		return [
			'member.id' => [
				'rules' => 'id',
				'errors' => [
					'id' => lang('app.invalid_id')
				]
			],
			'member.username' => [
				'rules' => ['required', 'is_unique[pv_member.username,id,{member.id}]'],
				'errors' => [
					'required' => lang('app.username_cannot_be_empty'),
					'is_unique' => lang('app.username_already_exists')
				]
			],
			'member.group_id' => [
				'rules' => 'digit',
				'errors' => [
					'digit' => lang('app.invalid_id')
				]
			],
			'member.group_expiry' => [
				'rules' => 'group_expiry',
				'errors' => [
					'group_expiry' => lang('admin.invalid_group_expiry')
				]
			],
			'member.change_to' => [
				'rules' => 'digit',
				'errors' => [
					'digit' => lang('app.invalid_id')
				]
			],
			'member.email' => [
				'rules' => ['required', 'valid_email', 'is_unique[pv_member.email,id,{member.id}]'],
				'errors' => [
					'required' => lang('app.email_cannot_be_empty'),
					'valid_email' => lang('app.invalid_email'),
					'is_unique' => lang('app.email_already_exists')
				]
			],
			'member.phone' => [
				'rules' => ['regex_match[/^[\+\-\d\s]*$/]'],
				'errors' => [
					'regex_match' => lang('app.invalid_phone')
				]
			],
			'member.balance' => [
				'rules' => 'money',
				'errors' => [
					'money' => lang('admin.invalid_balance')
				]
			],
		];
	}

	public function group_expiry($value): bool
	{
		return is_string($value) && (is_blank($value) || strtotime($value) !== false);
	}
}