<?php

namespace config\validation\admin;

class module implements \venus\validation\config
{
	private array $validator_class = [
		self::class
	];

	public function get_validator_class(): array
	{
		return $this->validator_class;
	}

	public function get_rules(?string $scene): array
	{
		return $this->$scene();
	}

	private function config(): array
	{
		return [
			'domain' => [
				'rules' => ['rule1', 'rule2', 'rule3'],
				'errors' => [
					'rule1' => lang('admin.domain_bound_other_module'),
					'rule2' => lang('admin.module_cannot_bind_domain'),
					'rule3' => lang('admin.same_as_current_domain'),
				]
			]
		];
	}

	/**
	 * 检测域名是否已绑定其它模块
	 */
	public function rule1($value, $data, $original_data): bool
	{
		if (is_blank($value))
			return true;

		$modules = \phpvod::$app->module->get_modules();
		foreach ($modules as $namespace => $module) {
			if (strtolower($module['domain']) == strtolower(trim($value)) && $namespace != $original_data['namespace']) {
				return false;
			}
		}

		return true;
	}

	/**
	 * 模块是否允许绑定域名（不能设置为主模块不允许绑定域名）
	 */
	public function rule2($value, $data, $original_data): bool
	{
		if (is_blank($value))
			return true;

		return \phpvod::$app->module->get_module($original_data['namespace'], 'main') == '1';
	}

	/**
	 * 检测域名是否与当前域名相同
	 */
	public function rule3($value, $data, $original_data): bool
	{
		if (is_blank($value))
			return true;

		$http_host = \phpvod::$app->request->server('HTTP_HOST');
		if (is_null($http_host))
			return false;

		return strtolower(trim($value)) != strtolower($http_host);
	}
}