<?php

namespace config\validation\home;

use config\validation\validator;
use phpvod\library\config\config;
use venus\validation\validator\general;

class register implements \venus\validation\config
{
	private array $validator_class = [
		general::class,
		validator::class
	];

	public function get_validator_class(): array
	{
		return $this->validator_class;
	}

	public function get_rules(?string $scene): array
	{
		$rules = [
			'member.username' => [
				'rules' => ['required', 'is_unique[pv_member.username]'],
				'errors' => [
					'required' => lang('app.username_cannot_be_empty'),
					'is_unique' => lang('app.username_already_exists')
				]
			],
			'member.password' => [
				'rules' => 'required',
				'errors' => [
					'required' => lang('app.password_cannot_be_empty'),
				]
			],
			'member.repeat_password' => [
				'rules' => ['required', 'matches[member.password]'],
				'errors' => [
					'required' => lang('app.repeat_password_cannot_be_empty'),
					'matches' => lang('app.repeat_password_not_match'),
				]
			],
			'member.email' => [
				'rules' => ['required', 'valid_email', 'is_unique[pv_member.email]'],
				'errors' => [
					'required' => lang('app.email_cannot_be_empty'),
					'valid_email' => lang('app.invalid_email'),
					'is_unique' => lang('app.email_already_exists')
				]
			]
		];

		$verify_email_address = config::get_instance()->get('config_register', 'verify_email_address');
		if ($verify_email_address == '1') {
			$rules = array_merge($rules, $this->get_email_code_rule());
		}

		return array_merge($rules, $this->get_captcha_rule());
	}

	/**
	 * 邮箱验证码规则
	 * @return array
	 */
	private function get_email_code_rule(): array
	{
		return [
			'member.email_code' => [
				'rules' => ['required', 'verify_code[register,member.email]'],
				'errors' => [
					'required' => lang('app.email_code_cannot_be_empty'),
					'verify_code' => lang('app.email_code_error')
				]
			]
		];
	}

	/**
	 * 验证码规则
	 * @return array
	 */
	private function get_captcha_rule(): array
	{
		return [
			'member.captcha' => [
				'rules' => ['required', 'captcha'],
				'errors' => [
					'required' => lang('app.captcha_cannot_be_empty'),
					'captcha' => lang('app.captcha_error')
				]
			]
		];
	}
}
