<?php

namespace config\validation;

use phpvod\controller\api\member;
use phpvod\library\verify_manager;

class validator
{
	/**
	 * 验证码
	 * @param string $value
	 * @return bool
	 * @throws \Exception
	 */
	public function captcha(string $value): bool
	{
		$captcha = session()->get('captcha');
		return !empty($captcha) && strtolower($value) == strtolower($captcha);
	}

	/**
	 * 验证验证码(email/phone)
	 * @param $value
	 * @param $params
	 * @param $data
	 * @return bool
	 * @throws \Exception
	 */
	public function verify_code($value, $params, $data): bool
	{
		[$action, $field] = explode(',', $params);

		if (!is_string($field) || !array_key_exists($field, $data) ||
			!is_string($action) || !in_array($action, [
				member::ACTION_REGISTER, member::ACTION_RESET_PASSWORD
			]))
			return false;

		return verify_manager::get_instance(\phpvod::$app->cache->get_handler())
			->compare_code($value, $action, $data[$field]);
	}

	/**
	 * ID验证
	 * @param $value
	 * @return bool
	 */
	public function id($value): bool
	{
		if (is_string($value)) {
			return preg_match('/\A[1-9][0-9]*\z/', $value) === 1;
		} elseif (is_int($value)) {
			return $value > 0;
		} elseif (is_array($value)) {
			foreach ($value as $id) {
				if ($this->id($id) === false) {
					return false;
				}
			}
			return true;
		} else {
			return false;
		}
	}

	/**
	 * 货币验证
	 * @param $value
	 * @return bool
	 */
	public function money($value): bool
	{
		return is_numeric($value) && floatval($value) >= 0 && floatval($value) <= 42949672.95; //mysql无符号整型取值范围0-4294967295
	}
}