<?php

namespace phpvod\controller\admin;

use config\validation\validator;

class admin extends \phpvod\base\backend_controller
{
	protected array $helper = ['form'];
	private \phpvod\model\admin $model;

	public function init(): void
	{
		parent::init();
		/** @noinspection PhpFieldAssignmentTypeMismatchInspection */
		$this->model = model(\phpvod\model\admin::class);
	}

	public function index(): string
	{
		return $this->view('admin/index');
	}

	public function add(): string
	{
		if ($this->request->is_post()) {
			if ($this->validation->load_config(\config\validation\admin\admin::class, 'add')->with_post()->run()) {
				$admin = $this->request->post('admin');
				$admin['password_hash'] = password_hash($admin['password'], PASSWORD_BCRYPT);
				is_blank($admin['phone']) && $admin['phone'] = null;
				$admin['status'] = $admin['status'] == '1' ? 1 : 0;
				$admin['created_at'] = TIMESTAMP;
				$this->model->save($admin);
				$this->backend_redirect('admin/index', false, true);
			} else {
				$this->set_message_from_validator();
				$this->backend_redirect('admin/add', true);
			}
		}
		return $this->view('admin/add');
	}

	public function edit(): string
	{
		if ($this->request->is_post()) {
			$admin = $this->request->post('admin');
			if ($this->validation->load_config(\config\validation\admin\admin::class, 'edit')->with_post()->run()) {
				//password
				if (trim($admin['password']) == '') {
					unset($admin['password']);
				} else {
					$admin['password_hash'] = password_hash($admin['password'], PASSWORD_BCRYPT);
				}
				//phone
				is_blank($admin['phone']) && $admin['phone'] = null;
				//status
				$admin['status'] = $admin['status'] == '1' ? 1 : 0;
				$this->model->save($admin);
				$this->backend_redirect('admin/index', false, true);
			} else {
				$this->set_message_from_validator();
				$this->redirect(admin_uri('admin/edit') . '?id=' . $admin['id'], true);
			}
		}

		$id = $this->request->get('id');
		$admin = $this->model->find($id)->fetch_array();
		if ($admin === false) {
			$this->backend_redirect('admin/index', false, lang('app.invalid_id'));
		}
		return $this->view('admin/edit', [
			'admin' => $admin
		]);
	}

	/**
	 * 删除记录(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function delete(): void
	{
		$id = $this->request->post('id');
		if ($this->validation->check($id, 'id', validator::class)) {
			$this->model->delete($id);
			$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_id')]);
		}
	}

	/**
	 * 获取表格数据(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function get_data(): void
	{
		$params = $this->get_bootstrap_table_query_params();
		if ($params !== false) {
			$data = $this->model->get_data($params);
			$this->response->set_json($data);
		}
	}

	/**
	 * 更改状态(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function change_status(): void
	{
		$id = $this->request->post('id');
		parent::change_status_by_id([$this->model, 'change_status'], $id);
	}

}