<?php

namespace phpvod\controller\admin;

use config\validation\validator;
use phpvod\library\config\config;

class admin_role extends \phpvod\base\backend_controller
{
	protected array $helper = ['form'];
	private \phpvod\model\admin_role $model;

	public function init(): void
	{
		parent::init();
		/** @noinspection PhpFieldAssignmentTypeMismatchInspection */
		$this->model = model(\phpvod\model\admin_role::class);
	}

	public function index(): string
	{
		return $this->view('admin_role/index');
	}

	public function add(): string
	{
		if ($this->request->is_post()) {
			if ($this->validation->load_config(\config\validation\admin\admin_role::class, 'add')->with_post()->run()) {
				$permissions = is_array($this->request->post('permissions')) ? implode(',', $this->request->post('permissions')) : '';
				$this->model->insert(['name' => $this->request->post('name'), 'permissions' => $permissions]);
				config::get_instance()->update('admin_role');
				$this->backend_redirect('admin-role/index', false, true);
			} else {
				$this->set_message_from_validator();
				$this->backend_redirect('admin-role/add', true);
			}
		}
		return $this->view('admin_role/add');
	}

	public function edit(): string
	{
		if ($this->request->is_post()) {
			$id = (int)$this->request->post('id');
			if ($this->validation->load_config(\config\validation\admin\admin_role::class, 'edit')->with_post()->run()) {
				$permissions = $id === 1 ? '-1' : (is_array($this->request->post('permissions')) ? implode(',', $this->request->post('permissions')) : '');
				$this->model->update(['name' => $this->request->post('name'), 'permissions' => $permissions], $id);
				config::get_instance()->update('admin_role');
				$this->backend_redirect('admin-role/index', false, true);
			} else {
				$this->set_message_from_validator();
				$this->redirect(admin_uri('admin-role/edit') . '?id=' . $id, true);
			}
		}

		$id = $this->request->get('id');
		$role = $this->model->find($id)->fetch_array();
		if ($role === false) {
			$this->backend_redirect('admin-role/index', false, lang('app.invalid_id'));
		}
		return $this->view('admin_role/edit', ['role' => $role]);
	}

	/**
	 * 删除记录(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function delete(): void
	{
		$id = $this->request->post('id');
		if ($this->validation->check($id, 'id', validator::class)) {
			if ($id == '1') {
				$this->response->set_json(['id' => 0, 'msg' => lang('admin.role_cannot_deleted')]);
			} else {
				/**
				 * @var \phpvod\model\admin $admin_model
				 */
				$admin_model = model(\phpvod\model\admin::class);
				$user_count = (int)$admin_model->select('count(id)')->where('role_id=:role_id', ['role_id' => $id])->query()->fetch_column();
				if ($user_count > 0) {
					$this->response->set_json(['id' => 0, 'msg' => lang('admin.role_being_used')]);
				} else {
					$this->model->delete($id);
					config::get_instance()->update('admin_role');
					$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
				}
			}
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_id')]);
		}
	}

	/**
	 * 获取表格数据(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function get_data(): void
	{
		$params = $this->get_bootstrap_table_query_params();
		if ($params !== false) {
			$data = $this->model->get_data($params);
			$this->response->set_json($data);
		}
	}
}