<?php

namespace phpvod\controller\admin;

use phpvod\base\backend_controller;
use phpvod\library\mail;

class config extends backend_controller
{
	protected array $helper = ['form'];

	private function handler(string $type, string $file, string $view): string
	{
		/**
		 * @var \phpvod\model\config $model
		 */
		$model = model(\phpvod\model\config::class);
		if ($this->request->is_post()) {
			$config = $this->request->post('config');
			$model->update_config($config, $type);
			$this->set_success_message();
			\phpvod\library\config\config::get_instance()->update($file);
		} else {
			$config = $model->get_config($type);
		}
		return $this->view('config/' . $view, ['config' => $config]);
	}

	public function site(): string
	{
		return $this->handler('site', 'config_site', 'site');
	}

	public function register(): string
	{
		return $this->handler('register', 'config_register', 'register');
	}

	public function template(): string
	{
		return $this->handler('template', 'config_template', 'template');
	}

	public function cache(): string
	{
		return $this->handler('cache', 'config_cache', 'cache');
	}

	public function background(): string
	{
		return $this->handler('background', 'config_background', 'background');
	}

	public function mail(): string
	{
		return $this->handler('mail', 'config_mail', 'mail');
	}

	/**
	 * 测试缓存
	 * @return void
	 * @throws \Exception
	 */
	public function test_cache(): void
	{
		try {
			$cache_handler = \phpvod::$app->cache->get_handler();
			$set = $cache_handler->set('test_cache_key', 'test_cache_value');
			$get = $cache_handler->get('test_cache_key');
			$del = $cache_handler->delete('test_cache_key');
			$msg = $set === true && $get == 'test_cache_value' && $del === true ? lang('admin.test_successfully') : lang('admin.test_failed');
		} catch (\Exception) {
			$msg = lang('admin.test_failed');
		}
		$this->response->set_json(['msg' => $msg]);
	}

	/**
	 * 清空缓存数据
	 * @return void
	 * @throws \Exception
	 */
	public function clear_cache(): void
	{
		try {
			$msg = \phpvod::$app->cache->get_handler()->clean() ? lang('admin.clear_successfully') : lang('admin.clear_failed');
		} catch (\Exception) {
			$msg = lang('admin.clear_failed');
		}
		$this->response->set_json(['msg' => $msg]);
	}

	/**
	 * 发送测试邮件，该方法通过ajax调用
	 * @return void
	 * @throws \Exception
	 */
	public function send_test_mail(): void
	{
		$check = $this->validation->check($this->request->post('receiver'), ['required', 'valid_email']);
		if (!$check) {
			$this->response->set_json(['msg' => lang('app.invalid_email')]);
			return;
		}
		$receiver = $this->request->post('receiver');
		$mail = new mail();
		$send = $mail->set_subject(lang('admin.test_email_subject'))
			->set_body_from_template('test.html')
			->add_address($receiver)
			->send();
		if ($send) {
			$this->response->set_json(['msg' => lang('app.mail_sent_successfully')]);
		} else {
			$msg = !empty($mail->ErrorInfo) ? $mail->ErrorInfo : lang('app.mail_sent_failed');
			$this->response->set_json(['msg' => $msg]);
		}
	}
}