<?php

namespace phpvod\controller\admin;

use config\validation\admin\login;
use phpvod\base\backend_controller;
use phpvod\model\backend_menu;
use venus\language\language;

class home extends backend_controller
{
	protected array $helper = ['form'];

	public function index(): string
	{
		return $this->view('home/index');
	}

	/**
	 * 登录
	 * @return string
	 * @throws \Exception
	 */
	public function login(): string
	{
		if(\phpvod::$app->user_auth->backend_is_logged_in()) {
			$this->backend_redirect('index');
		}

		if ($this->request->is_post()) {
			if ($this->validation->load_config(login::class)->with_post()->run()) {
				$login_result = \phpvod::$app->user_auth->login([
					'username' => $this->request->post('username'),
					'password' => $this->request->post('password'),
					'status' => 1
				]);
				if ($login_result) {
					$this->backend_redirect('index');
				} else {
					$this->set_message(lang('app.invalid_username_or_password'));
				}
			} else {
				$this->set_message_from_validator();
			}
		}
		return $this->view('home/login');
	}

	/**
	 * 登出
	 * @return void
	 * @throws \Exception
	 */
	public function logout(): void
	{
		\phpvod::$app->user_auth->logout();
		$this->backend_redirect('login');
	}

	/**
	 * 获取后台菜单json数据
	 * @return void
	 * @throws \Exception
	 */
	public function get_backend_menu(): void
	{
		\phpvod::$app->language->load_file('menu', language::ADDITIONAL_ALL_MODULE_LANGUAGE);

		/**
		 * @var backend_menu $model
		 */
		$model = model(backend_menu::class);
		$data = $model->where('display = 1')->order_by('sort, id')->query()->fetch_all_array();

		foreach ($data as $key => $value) {
			$data[$key]['name'] = lang('menu.' . $value['name']);
			!empty($value['route']) && $data[$key]['route'] = admin_uri($value['route']);
		}

		\phpvod::$app->response->set_json($data);
	}
}