<?php

namespace phpvod\controller\admin;

use config\validation\validator;
use venus\http\file\uploaded_file;
use phpvod\library\config\config;

class language extends \phpvod\base\backend_controller
{
	private \phpvod\model\language $model;
	protected array $helper = ['form', 'array', 'file_system'];

	public function init(): void
	{
		parent::init();
		/** @noinspection PhpFieldAssignmentTypeMismatchInspection */
		$this->model = model(\phpvod\model\language::class);
	}

	public function index(): string
	{
		return $this->view('language/index');
	}

	public function add(): string
	{
		if ($this->request->is_post()) {
			if ($this->validation->load_config(\config\validation\admin\upload::class, 'upload_zip')->run()) {
				/* @var uploaded_file $file */
				$file = $this->request->get_files('zip_file');
				$file->move(WRITABLE_PATH . 'temp', $file->get_random_name());
				$zip_file = $file->get_saved_file();
				try {
					$this->model->install($zip_file);
					remove_file($zip_file);
					config::get_instance()->update('language');
					$this->backend_redirect('language/index', false, true);
				} catch (\Exception $exception) {
					remove_file($zip_file);
					$this->backend_redirect('language/add', false, $exception->getMessage());
				}
			} else {
				$this->set_message_from_validator();
				$this->backend_redirect('language/add');
			}
		}

		return $this->view('language/add');
	}

	public function delete(): void
	{
		$id = $this->request->post('id');
		if ($this->validation->check($id, 'id', validator::class)) {
			try {
				$this->model->uninstall($id);
				config::get_instance()->update('language');
				$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
			} catch (\Exception $exception) {
				$exception->getCode() === 2 && config::get_instance()->update('language');
				$this->response->set_json(['id' => $exception->getCode(), 'msg' => $exception->getMessage()]);
			}
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_params')]);
		}
	}

	public function delete_module_language(): void
	{
		if ($this->validation->set_rules(['module_namespace' => ['rules' => 'required'], 'directory' => ['rules' => 'required']])
			->load_validator(\venus\validation\validator\general::class)->with_post()->run()) {
			$module_namespace = $this->request->post('module_namespace');
			$directory = $this->request->post('directory');
			try {
				$this->model->uninstall_module_language($module_namespace, $directory);
				$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
			} catch (\Exception $exception) {
				$this->response->set_json(['id' => $exception->getCode(), 'msg' => $exception->getMessage()]);
			}
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_params')]);
		}
	}

	/**
	 * 获取表格数据(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function get_data(): void
	{
		$params = $this->get_bootstrap_table_query_params();
		if ($params !== false) {
			$data = $this->model->get_data($params);
			$this->response->set_json($data);
		}
	}

	/**
	 * 设置默认语言(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function set_default_language(): void
	{
		$id = $this->request->post('id');
		if ($this->validation->check($id, 'id', validator::class)) {
			$this->model->set_default_language($id);
			config::get_instance()->update('language');
			$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_params')]);
		}
	}

}