<?php

namespace phpvod\controller\admin;

use config\validation\home\auth;
use phpvod\base\backend_controller;
use venus\http\status;

class main extends backend_controller
{
	public function index(): string
	{
		$db = \phpvod::$app->database;

		$database_size = 0;
		$rows = $db->query('SHOW TABLE STATUS')->fetch_all_array();
		foreach ($rows as $row) {
			$database_size += $row['Data_length'] + $row['Index_length'];
		}

		$server_info = [];
		$server_info['database_size'] = bytes2size($database_size);
		$server_info['system_time'] = timetostr();
		$server_info['php_version'] = PHP_VERSION;
		$server_info['db_version'] = $db->get_server_version();
		$server_info['server_software'] = $_SERVER['SERVER_SOFTWARE'];
		$server_info['max_upload'] = ini_get('file_uploads') ? ini_get('upload_max_filesize') : 'Disabled';
		$server_info['max_ex_time'] = ini_get('max_execution_time') . ' seconds';
		return $this->view('main/index', ['server_info' => $server_info]);
	}

	/**
	 * get-notice(AJAX)
	 * @return void
	 * @throws \Exception
	 */
	public function get_notice(): void
	{
		$curl_response = curl_request()->get(\phpvod::GET_NOTICE_GATEWAY);
		$status_code = $curl_response->get_status_code();
		if($status_code !== status::HTTP_OK) {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.http_error', [$status_code])]);
			return;
		}
		$this->response->set_content_type('application/json; charset=UTF-8');
		$this->response->set_body($curl_response->get_body());
	}

	/**
	 * auth(AJAX)
	 * @return void
	 * @throws \Exception
	 */
	public function auth(): void
	{
		if ($this->validation->load_config(auth::class)->with_post()->run()) {
			$auth = $this->request->post('auth');
			$curl_response = curl_request()->post(\phpvod::AUTH_GATEWAY, ['auth' => $auth]);
			if ($curl_response->get_status_code() == status::HTTP_OK && strtolower($curl_response->get_content_type()) == 'application/octet-stream') {
				file_put_contents(APP_PATH . 'license.lic', $curl_response->get_body());
				$this->response->set_json(['id' => 1, 'msg' => lang('admin.auth_succeeded')]);
			} else {
				$this->response->set_json(['id' => 0, 'msg' => lang('admin.auth_failed')]);
			}
		} else {
			$errors = $this->validation->get_errors();
			$this->response->set_json(['id' => 0, 'msg' => array_shift($errors)]);
		}
	}

	/**
	 * get-license-info(AJAX)
	 * @return void
	 * @throws \Exception
	 */
	public function get_license_info(): void
	{
		$license_file = APP_PATH . 'license.lic';
		$key_file = CONFIG_PATH . 'rsa/key.pem';
		if (is_file($license_file) && is_file($key_file)) {
			$license = file_get_contents($license_file);
			$key = file_get_contents($key_file);
			if ($license !== false && $key !== false) {
				if (openssl_public_decrypt(base64_decode($license), $decrypted_data, $key)) {
					$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded'), 'data' => unserialize($decrypted_data)]);
					return;
				}
			}
		}
		$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_failed')]);
	}
}