<?php

namespace phpvod\controller\admin;

use config\validation\validator;

class member extends \phpvod\base\backend_controller
{
	protected array $helper = ['form'];
	private \phpvod\model\member $model;
	public const EVENT_MEMBER_INSERT = 'event_member_insert';
	public const EVENT_MEMBER_UPDATE = 'event_member_update';
	public const EVENT_MEMBER_DELETE = 'event_member_delete';

	public function init(): void
	{
		parent::init();
		/** @noinspection PhpFieldAssignmentTypeMismatchInspection */
		$this->model = model(\phpvod\model\member::class);
	}

	public function index(): string
	{
		return $this->view('member/index');
	}

	public function add(): string
	{
		if ($this->request->is_post()) {
			if ($this->validation->load_config(\config\validation\admin\member::class, 'add')->with_post()->run()) {
				$member = $this->request->post('member');
				$member['password_hash'] = password_hash($member['password'], PASSWORD_BCRYPT);
				$member['group_expiry'] = is_blank($member['group_expiry']) ? null : (int)strtotime($member['group_expiry']);
				is_blank($member['phone']) && $member['phone'] = null;
				$member['balance'] = round(floatval($member['balance']) * 100);
				$member['status'] = $member['status'] == '1' ? 1 : 0;
				$member['created_at'] = TIMESTAMP;
				$this->model->save($member);
				$id = $this->model->insert_id();
				//event
				event()->trigger(self::EVENT_MEMBER_INSERT, (int)$id);
				$this->backend_redirect('member/index', false, true);
			} else {
				$this->set_message_from_validator();
				$this->backend_redirect('member/add', true);
			}
		}
		return $this->view('member/add');
	}

	public function edit(): string
	{
		if ($this->request->is_post()) {
			$member = $this->request->post('member');
			if ($this->validation->load_config(\config\validation\admin\member::class, 'edit')->with_post()->run()) {
				//password
				if (trim($member['password']) == '') {
					unset($member['password']);
				} else {
					$member['password_hash'] = password_hash($member['password'], PASSWORD_BCRYPT);
				}
				//group_expiry
				$member['group_expiry'] = is_blank($member['group_expiry']) ? null : (int)strtotime($member['group_expiry']);
				//phone
				is_blank($member['phone']) && $member['phone'] = null;
				//balance
				$member['balance'] = round(floatval($member['balance']) * 100);
				//status
				$member['status'] = $member['status'] == '1' ? 1 : 0;
				$this->model->save($member);
				//event
				event()->trigger(self::EVENT_MEMBER_UPDATE, $member['id']);
				$this->backend_redirect('member/index', false, true);
			} else {
				$this->set_message_from_validator();
				$this->redirect(admin_uri('member/edit') . '?id=' . $member['id'], true);
			}
		}

		$id = $this->request->get('id');
		$member = $this->model->find($id)->fetch_array();
		if ($member === false) {
			$this->backend_redirect('member/index', false, lang('app.invalid_id'));
		}
		$member['balance'] = number_format($member['balance'] / 100, 2, '.', '');
		$member['group_expiry'] = is_null($member['group_expiry']) ? '' : timetostr($member['group_expiry']);
		return $this->view('member/edit', [
			'member' => $member
		]);
	}

	/**
	 * 删除记录(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function delete(): void
	{
		$id = $this->request->post('id');
		if ($this->validation->check($id, 'id', validator::class)) {
			$this->model->delete($id);
			//event
			event()->trigger(self::EVENT_MEMBER_DELETE, $id);
			$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_id')]);
		}
	}

	/**
	 * 获取数据(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function get_data(): void
	{
		$params = $this->get_bootstrap_table_query_params();
		if ($params !== false) {
			$data = $this->model->get_data($params);
			$this->response->set_json($data);
		}
	}

	/**
	 * 更改状态(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function change_status(): void
	{
		$id = $this->request->post('id');
		parent::change_status_by_id([$this->model, 'change_status'], $id);
	}

	/**
	 * 通过审核(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function pass(): void
	{
		$id = $this->request->post('id');
		if ($this->validation->check($id, 'id', validator::class)) {
			$this->model->update(['group_id' => 3], $id);
			$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_id')]);
		}
	}
}