<?php

namespace phpvod\controller\admin;

use config\validation\validator;
use phpvod\library\config\config;

class member_group extends \phpvod\base\backend_controller
{
	protected array $helper = ['form'];
	private \phpvod\model\member_group $model;

	public function init(): void
	{
		parent::init();
		/** @noinspection PhpFieldAssignmentTypeMismatchInspection */
		$this->model = model(\phpvod\model\member_group::class);
	}

	public function index(): string
	{
		return $this->view('member_group/index');
	}

	/**
	 * add
	 * @throws \Exception
	 */
	public function add(): string
	{
		if ($this->request->is_post()) {
			if ($this->validation->load_config(\config\validation\admin\member_group::class, 'add')->with_post()->run()) {
				$name = $this->request->post('name');
				$sale = $this->get_sale();
				$permissions = $this->request->post('permissions');
				$permissions = is_array($permissions) ? formatter($permissions) : null;
				$this->model->insert(['name' => $name, 'sale' => $sale, 'permissions' => $permissions]);
				config::get_instance()->update('member_group');
				$this->backend_redirect('member-group/index', false, true);
			} else {
				$this->set_message_from_validator();
				$this->backend_redirect('member-group/add', true);
			}
		}
		return $this->view('member_group/add');
	}

	/**
	 * edit
	 * @throws \Exception
	 */
	public function edit(): string
	{
		if ($this->request->is_post()) {
			$id = (int)$this->request->post('id');
			if ($this->validation->load_config(\config\validation\admin\member_group::class, 'edit')->with_post()->run()) {
				$name = $this->request->post('name');
				$sale = $this->get_sale();
				$permissions = $this->request->post('permissions');
				$permissions = is_array($permissions) ? formatter($permissions) : null;
				$this->model->update(['name' => $name, 'sale' => $sale, 'permissions' => $permissions], $id);
				config::get_instance()->update('member_group');
				$this->backend_redirect('member-group/index', false, true);
			} else {
				$this->set_message_from_validator();
				$this->redirect(admin_uri('member-group/edit') . '?id=' . $id, true);
			}
		}

		$id = $this->request->get('id');
		$group = $this->model->find($id)->fetch_array();
		if ($group === false) {
			$this->backend_redirect('member-group/index', false, lang('app.invalid_id'));
		}
		//sale
		if (!is_null($group['sale'])) {
			$sale = json_decode($group['sale'], true);
			$sale['price'] = array_map(function ($price) {
				return number_format(floatval($price) / 100, 2, '.', '');
			}, $sale['price']);
		} else {
			$sale = ['label' => [''], 'price' => [''], 'days' => ['']];
		}
		return $this->view('member_group/edit', ['group' => $group, 'sale' => $sale]);
	}

	/**
	 * 删除记录(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function delete(): void
	{
		$id = $this->request->post('id');
		if ($this->validation->check($id, 'id', validator::class)) {
			if ($id == '1' || $id == '2' || $id == '3') {
				$this->response->set_json(['id' => 0, 'msg' => lang('admin.member_group_cannot_deleted')]);
			} else {
				/**
				 * @var \phpvod\model\member $member_model
				 */
				$member_model = model(\phpvod\model\member::class);
				$user_count = (int)$member_model->select('count(id)')->where('group_id=:group_id', ['group_id' => $id])->query()->fetch_column();
				if ($user_count > 0) {
					$this->response->set_json(['id' => 0, 'msg' => lang('admin.member_group_being_used')]);
				} else {
					$this->model->delete($id);
					config::get_instance()->update('member_group');
					$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
				}
			}
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_id')]);
		}
	}

	/**
	 * 获取数据(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function get_data(): void
	{
		$params = $this->get_bootstrap_table_query_params();
		if ($params !== false) {
			$data = $this->model->get_data($params);
			$this->response->set_json($data);
		}
	}

	/**
	 * get_sale
	 * @return string|null
	 * @throws \Exception
	 */
	private function get_sale(): ?string
	{
		$result = [];
		$sale = $this->request->post('sale');

		if (isset($sale['label']) && is_array($sale['label'])) {
			foreach ($sale['label'] as $key => $value) {
				if (!is_blank($value) && //label
					(isset($sale['price'][$key]) && is_numeric($sale['price'][$key]) && floatval($sale['price'][$key]) >= 0.01) && //price
					(isset($sale['days'][$key]) && is_numeric($sale['days'][$key]) && floatval($sale['days'][$key]) >= 0) //days
				) {
					$result['label'][] = $value;
					$result['price'][] = round(floatval($sale['price'][$key]) * 100);
					$result['days'][] = round(floatval($sale['days'][$key]));
				}
			}
		}

		return !empty($result) ? formatter($result) : null;
	}
}