<?php

namespace phpvod\controller\admin;

use venus\http\file\uploaded_file;
use phpvod\library\config\config;

class module extends \phpvod\base\backend_controller
{
	private \phpvod\model\module $model;
	protected array $helper = ['form', 'array', 'file_system'];

	public function init(): void
	{
		parent::init();
		/** @noinspection PhpFieldAssignmentTypeMismatchInspection */
		$this->model = model(\phpvod\model\module::class);
	}

	public function index(): string
	{
		return $this->view('module/index');
	}

	public function add(): string
	{
		if ($this->request->is_post()) {
			if ($this->validation->load_config(\config\validation\admin\upload::class, 'upload_zip')->run()) {

				/* @var uploaded_file $file */
				$file = $this->request->get_files('zip_file');
				$file->move(WRITABLE_PATH . 'temp', $file->get_random_name());
				$zip_file = $file->get_saved_file();
				try {
					$this->model->install($zip_file);
					remove_file($zip_file);
					config::get_instance()->update('module'); //更新模块缓存
					$this->update_backend_menu(); //更新菜单
					$this->backend_redirect('module/index', false, true);
				} catch (\Exception $exception) {
					remove_file($zip_file);
					$this->backend_redirect('module/add', false, $exception->getMessage());
				}

			} else {
				$this->set_message_from_validator();
				$this->backend_redirect('module/add');
			}
		}

		return $this->view('module/add');
	}

	public function config(): string {
		if ($this->request->is_post()) {
			$namespace = $this->request->post('namespace');
			if ($this->validation->load_config(\config\validation\admin\module::class, 'config')->with_post()->run()) {
				$domain = $this->request->post('domain');
				$domain = is_blank($domain) ? null : strtolower(trim($domain));
				$this->model->where(['namespace' => $namespace])->update(['domain' => $domain]);
				config::get_instance()->update('module');
				$this->backend_redirect('module/index', false, true);
			} else {
				$this->set_message_from_validator();
				$this->redirect(admin_uri('module/config') . '?namespace=' . $namespace, true);
			}
		}

		$namespace = $this->request->get('namespace');
		$module = $this->model->select('id,name,namespace,domain')->where(['namespace' => $namespace])->query()->fetch_array();
		if ($module === false) {
			$this->backend_redirect('module/index', false, lang('app.invalid_params'));
		}
		return $this->view('module/config', ['module' => $module]);
	}

	public function delete(): void
	{
		$namespace = $this->request->post('namespace');
		if ($this->validation->check($namespace, 'required')) {
			$namespace = trim($namespace);
			try {
				$this->model->uninstall($namespace);
				config::get_instance()->update('module');
				$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
			} catch (\Exception $exception) {
				$exception->getCode() === 2 && config::get_instance()->update('module');
				$this->response->set_json(['id' => $exception->getCode(), 'msg' => $exception->getMessage()]);
			}
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('admin.module_namespace_invalid')]);
		}
	}

	/**
	 * 获取表格数据(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function get_data(): void
	{
		$params = $this->get_bootstrap_table_query_params();
		if ($params !== false) {
			$data = $this->model->get_data($params);
			$this->response->set_json($data);
		}
	}

	/**
	 * 更改状态(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function change_status(): void
	{
		$id = $this->request->post('id');
		parent::change_status_by_id([$this->model, 'change_status'], $id, function () {
			config::get_instance()->update('module');
		});
	}
}