<?php

namespace phpvod\controller\admin;

use venus\http\file\uploaded_file;

class template extends \phpvod\base\backend_controller
{
	private \phpvod\model\template $model;
	protected array $helper = ['form', 'array', 'file_system'];

	public function init(): void
	{
		parent::init();
		/** @noinspection PhpFieldAssignmentTypeMismatchInspection */
		$this->model = model(\phpvod\model\template::class);
	}

	public function index(): string
	{
		return $this->view('template/index');
	}

	/**
	 * 获取表格数据(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function get_data(): void
	{
		$params = $this->get_bootstrap_table_query_params();
		if ($params !== false) {
			$data = $this->model->get_data($params);
			$this->response->set_json($data);
		}
	}

	public function add(): string
	{
		if ($this->request->is_post()) {
			if ($this->validation->load_config(\config\validation\admin\upload::class, 'upload_zip')->run()) {
				/* @var uploaded_file $file */
				$file = $this->request->get_files('zip_file');
				$file->move(WRITABLE_PATH . 'temp', $file->get_random_name());
				$zip_file = $file->get_saved_file();
				try {
					$this->model->install($zip_file);
					remove_file($zip_file);
					$this->backend_redirect('template/index', false, true);
				} catch (\Exception $exception) {
					remove_file($zip_file);
					$this->backend_redirect('template/add', false, $exception->getMessage());
				}
			} else {
				$this->set_message_from_validator();
				$this->backend_redirect('template/add');
			}
		}

		return $this->view('template/add');
	}

	public function delete(): void
	{
		$module_namespace = $this->request->post('module_namespace'); //If module_namespace is null, it means that the parameter does not exist
		$directory = $this->request->post('directory');
		if (!is_null($module_namespace) && !is_null($directory) && !is_blank($directory)) {
			try {
				$this->model->uninstall($module_namespace, $directory); //module_namespace may be an empty string
				$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
			} catch (\Exception $exception) {
				$this->response->set_json(['id' => $exception->getCode(), 'msg' => $exception->getMessage()]);
			}
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_params')]);
		}
	}

}