<?php

namespace phpvod\controller\admin;

use config\validation\validator;
use phpvod\base\backend_controller;
use phpvod\service\update_system;
use venus\http\status;

class update extends backend_controller
{
	private const UPDATE_PACKAGE_DIRECTORY = WRITABLE_PATH . 'temp';

	/**
	 * check_version(AJAX)
	 * @return void
	 * @throws \Exception
	 */
	public function check_version(): void
	{
		$module_namespace = $this->request->post('module_namespace');
		$applicable_version = $this->request->post('applicable_version');

		if (empty($applicable_version)) {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_params')]);
			return;
		}

		$curl_response = curl_request()->post(\phpvod::CHECK_VERSION_GATEWAY, ['module_namespace' => $module_namespace, 'applicable_version' => $applicable_version]);
		$status_code = $curl_response->get_status_code();
		if ($status_code !== status::HTTP_OK) {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.http_error', [$status_code])]);
			return;
		}

		$this->response->set_content_type('application/json; charset=UTF-8');
		$this->response->set_body($curl_response->get_body());
	}

	/**
	 * download_package(AJAX)
	 * @return void
	 * @throws \Exception
	 */
	public function download_package(): void
	{
		$id = $this->request->post('id');
		if(!$this->validation->check($id, 'id', validator::class)) {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_params')]);
			return;
		}

		$license = is_file(APP_PATH . 'license.lic') ? file_get_contents(APP_PATH . 'license.lic') : '';
		$curl_response = curl_request()->post(\phpvod::DOWNLOAD_PACKAGE_GATEWAY, ['id' => $id, 'license' => $license]);

		$status_code = $curl_response->get_status_code();
		if ($status_code != status::HTTP_OK) {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.http_error', [$status_code])]);
			return;
		}

		$content_type = strtolower($curl_response->get_content_type());
		if(str_contains($content_type, 'application/json')) {
			$this->response->set_content_type('application/json; charset=UTF-8');
			$this->response->set_body($curl_response->get_body());
			return;
		}

		$content_md5 = $curl_response->get_header('content-md5');
		$content_disposition = $curl_response->get_header('content-disposition');
		$package = preg_match('/\Aattachment;\s*filename\=[\'"]*(.*?)[\'"]*\z/i', $content_disposition, $matches) === 1 ? $matches[1] : 'update_package.zip';
		$package_path = self::UPDATE_PACKAGE_DIRECTORY . '/' . $package;

		$bytes = file_put_contents($package_path, $curl_response->get_body(), LOCK_EX);
		if ($bytes === false || md5_file($package_path) != $content_md5) {
			$this->response->set_json(['id' => 0, 'msg' => lang('admin.package_download_failed')]);
			return;
		}

		$this->response->set_json(['id' => 1, 'data' => ['package' => $package]]);
	}

	/**
	 * update_system(AJAX)
	 * @return void
	 * @throws \Exception
	 */
	public function update_system(): void
	{
		$package = $this->request->post('package');
		if (is_null($package) || is_blank($package)) {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_params')]);
			return;
		}
		$update_package = self::UPDATE_PACKAGE_DIRECTORY . '/' . $package;
		try {
			/* @var update_system $update_system_service */
			$update_system_service = service(update_system::class);
			$update_system_service->run($update_package);
			$this->response->set_json(['id' => 1, 'msg' => lang('admin.update_completed')]);
		}catch (\Exception $exception) {
			$this->response->set_json(['id' => 0, 'msg' => $exception->getMessage()]);
		}
	}
}