<?php
/**
 * 获取压缩包配置信息
 * @param string $zip_file 压缩包文件
 * @param string $json_file 配置文件名称，配置文件存放于索引号为零(index=0)的文件夹下
 * @return array|null 成功返回配置信息数组，失败返回null
 */
function get_zip_config(string $zip_file, string $json_file = 'info.json'): ?array
{
	$result = null;
	$zip = new ZipArchive();
	if ($zip->open($zip_file, ZipArchive::RDONLY) === true) {
		$dirname = $zip->getNameIndex(0);
		if (is_string($dirname) && str_ends_with($dirname, '/')) { //is directory
			$json = $zip->getFromName($dirname . $json_file);
			if ($json !== false) {
				$config = json_decode($json, true);
				if (is_array($config)) {
					//trim
					$result = array_map(function ($v) {
						return is_string($v) ? trim($v) : $v;
					}, $config);
				}
			}
		}
		$zip->close();
	}
	return $result;
}