<?php
/**
 * 后台URI
 * @param string $uri 可包含模块命名空间，用$开分。
 * <p>如：video$tag/index => admin/video/tag/index</p>
 * @return string
 */
function admin_uri(string $uri): string
{
	return trim(phpvod::$backend_segment . '/' . uri($uri), '/');
}

/**
 * 当前模块后台URI
 * @param string $uri
 * @return string
 */
function admin_module_uri(string $uri): string
{
	$namespace = phpvod::$app->module->get_current_module('namespace');
	if (!is_null($namespace)) {
		$uri = $namespace . '$' . $uri;
	}
	return admin_uri($uri);
}

/**
 * API接口URI
 * @param string $uri
 * @return string
 */
function api_uri(string $uri): string
{
	return trim(phpvod::$api_segment . '/' . uri($uri), '/');
}

/**
 * 当前模块API接口URI
 * @param string $uri
 * @return string
 */
function api_module_uri(string $uri): string
{
	$namespace = phpvod::$app->module->get_current_module('namespace');
	if (!is_null($namespace)) {
		$uri = $namespace . '$' . $uri;
	}
	return api_uri($uri);
}

/**
 * 前台URI
 * @param string $uri
 * @return string
 */
function home_uri(string $uri): string
{
	if ($uri == '/')
		return $uri;

	$domain = null;
	if (str_contains($uri, '$')) {
		[$namespace, $uri] = explode('$', $uri);
		$module = venus::$app->module->get_module($namespace);

		if (!is_null($module)) {
			if (!is_null($module['domain'])) { //domain bound
				$http_host = strtolower($_SERVER['HTTP_HOST'] ?? '');
				if ($module['domain'] !== $http_host) {
					$domain = $module['domain'];
				}
			} else { //unbound domain
				if ($module['namespace'] !== phpvod::$app->get_main_module()) {
					$uri = $module['segment'] . '/' . $uri;
				}
			}
		}
	}

	$uri = trim($uri, " \n\r\t\v\x00/");
	// add domain & suffix
	if($uri == '') {
		$uri = is_null($domain) ? '/' : '//' . $domain;
	} else {
		$uri .= venus::$app->router->get_config()->get_url_suffix();
		!is_null($domain) && $uri = '//' . $domain . '/' . $uri;
	}

	return $uri;
}

/**
 * 当前模块前台URI
 * @param string $uri
 * @return string
 */
function home_module_uri(string $uri): string
{
	$namespace = phpvod::$app->module->get_current_module('namespace');
	if (!is_null($namespace)) {
		$uri = $namespace . '$' . $uri;
	}
	return home_uri($uri);
}

/**
 * 检测是否为网址(允许省略协议名)
 * @param string $url
 * @return bool
 */
function is_http_url(string $url): bool
{
	return (bool)preg_match('/^(https?\:)?\/\/[^\/]+.*$/i', $url);
}
