<?php

namespace phpvod\library;

use Gregwar\Captcha\CaptchaBuilder;
use Gregwar\Captcha\PhraseBuilder;

class captcha
{
	private bool $distortion = true; //图像是否失真
	private bool $ignore_all_effects = false; //是否忽略所有图像效果
	private int $width = 120;
	private int $height = 40;

	/**
	 * 图像是否失真
	 * @param bool $distortion
	 * @return captcha
	 */
	public function set_distortion(bool $distortion): captcha
	{
		$this->distortion = $distortion;
		return $this;
	}

	/**
	 * 是否忽略所有图像效果
	 * @param bool $ignore_all_effects
	 * @return captcha
	 */
	public function set_ignore_all_effects(bool $ignore_all_effects): captcha
	{
		$this->ignore_all_effects = $ignore_all_effects;
		return $this;
	}

	/**
	 * 设置验证码宽度
	 * @param int $width
	 * @return captcha
	 */
	public function set_width(int $width): captcha
	{
		$this->width = $width;
		return $this;
	}

	/**
	 * 设置验证码高度
	 * @param int $height
	 * @return captcha
	 */
	public function set_height(int $height): captcha
	{
		$this->height = $height;
		return $this;
	}

	/**
	 * 获取验证码
	 * @param int $length
	 * @param string $charset
	 * @return string
	 */
	public function get_phrase(int $length = 5, string $charset = 'abcdefghijklmnpqrstuvwxyz123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'): string
	{
		return (new PhraseBuilder($length, $charset))->build();
	}

	/**
	 * 输出验证码图片
	 * @param string $phrase
	 * @return void
	 */
	public function output(string $phrase): void
	{
		$captcha_builder = new CaptchaBuilder($phrase);
		$captcha_builder->setDistortion($this->distortion)
			->setIgnoreAllEffects($this->ignore_all_effects);
		\phpvod::$app->response->set_content_type('image/jpeg', '');
		$captcha_builder->build($this->width, $this->height)->output();
	}

	/**
	 * 比较验证码
	 * @param string $str1
	 * @param string $str2
	 * @return bool
	 */
	public static function compare(string $str1, string $str2): bool
	{
		return PhraseBuilder::comparePhrases($str1, $str2);
	}
}