<?php

namespace phpvod\library\config;

use phpvod\model\admin_role;
use phpvod\model\language;
use phpvod\model\member_group;
use phpvod\model\module;

class config extends abstract_config
{
	public static ?config $instance = null;

	protected array $method_map = [
		'config_site' => ['config_cache', 'config_site', 'site'],
		'config_register' => ['config_cache', 'config_register', 'register'],
		'config_template' => ['config_cache', 'config_template', 'template'],
		'config_cache' => ['config_cache', 'config_cache', 'cache'],
		'config_background' => ['config_cache', 'config_background', 'background'],
		'config_mail' => ['config_cache', 'config_mail', 'mail'],
		'admin_role' => ['admin_role_cache', 'admin_role'],
		'module' => ['module_cache', 'module'],
		'language' => ['language_cache', 'language'],
		'member_group' => ['member_group_cache', 'member_group'],
	];

	private function __construct()
	{
	}

	private function __clone()
	{
	}

	public static function get_instance(): ?config
	{
		if (is_null(self::$instance)) {
			self::$instance = new config();
		}
		return self::$instance;
	}

	/**
	 * 创建配置缓存
	 * @param string $file
	 * @param string $type
	 * @return void
	 * @throws \Exception
	 */
	public function config_cache(string $file, string $type): void
	{
		/**
		 * @var \phpvod\model\config $model
		 */
		$model = model(\phpvod\model\config::class);
		$data = $model->get_config($type);
		write_file($this->get_file_path($file), "<?php\nreturn " . var_export($data, true) . ";");
	}

	/**
	 * 创建管理员角色缓存
	 * @param string $file
	 * @return void
	 * @throws \Exception
	 */
	public function admin_role_cache(string $file): void
	{
		/**
		 * @var admin_role $model
		 */
		$model = model(admin_role::class);
		$data = $model->select('id,name')->order_by('id')->query()->fetch_all_by_callback(function (array $row) {
			return ['key' => $row['id'], 'value' => $row['name']];
		});
		write_file($this->get_file_path($file), "<?php\nreturn " . var_export($data, true) . ";");
	}

	/**
	 * 创建模块缓存
	 * @param string $file
	 * @return void
	 * @throws \Exception
	 */
	public function module_cache(string $file): void
	{
		/**
		 * @var module $model
		 */
		$model = model(module::class);
		$data = $model->order_by('id')->query()->fetch_all_by_callback(function (array $row) {
			return ['key' => $row['namespace'], 'value' => $row];
		});
		write_file($this->get_file_path($file), "<?php\nreturn " . var_export($data, true) . ";");
	}

	/**
	 * 创建语言缓存
	 * @param string $file
	 * @return void
	 * @throws \Exception
	 */
	public function language_cache(string $file): void
	{
		/**
		 * @var language $model
		 */
		$model = model(language::class);
		$data = $model->order_by('default_language DESC, id ASC')->query()->fetch_all_by_callback(function (array $row) {
			return ['key' => $row['id'], 'value' => $row];
		});
		write_file($this->get_file_path($file), "<?php\nreturn " . var_export($data, true) . ";");
	}

	/**
	 * 创建会员组缓存
	 * @param string $file
	 * @return void
	 * @throws \Exception
	 */
	public function member_group_cache(string $file): void
	{
		/**
		 * @var member_group $model
		 */
		$model = model(member_group::class);
		$data = $model->select('*')->order_by('id')->query()->fetch_all_by_callback(function (array $row) {
			//sale
			$row['sale'] = is_null($row['sale']) ? [] : json_decode($row['sale'], true);
			//permissions
			$row['permissions'] = is_null($row['permissions']) ? [] : json_decode($row['permissions'], true);
			return ['key' => $row['id'], 'value' => $row];
		});
		write_file($this->get_file_path($file), "<?php\nreturn " . var_export($data, true) . ";");
	}
}
