<?php

namespace phpvod\library;

use Imagine\Gd\Imagine;
use Imagine\Image\Box;
use Imagine\Image\ImageInterface;
use Imagine\Image\Point;

class image
{
	public const TOP_LEFT = 1;
	public const TOP_CENTER = 2;
	public const TOP_RIGHT = 3;
	public const MIDDLE_LEFT = 4;
	public const MIDDLE_CENTER = 5;
	public const MIDDLE_RIGHT = 6;
	public const BOTTOM_LEFT = 7;
	public const BOTTOM_CENTER = 8;
	public const BOTTOM_RIGHT = 9;

	private Imagine $imagine;
	private ImageInterface $image;

	public function __construct()
	{
		$this->imagine = new Imagine();
	}

	/**
	 * 打开图像
	 * @param string $image 图片路径
	 * @return $this
	 * @throws \Imagine\Exception\InvalidArgumentException
	 * @throws \Imagine\Exception\RuntimeException
	 */
	public function open(string $image): image
	{
		$this->image = $this->imagine->open($image);
		return $this;
	}

	/**
	 * 保存图像
	 * @param string $path
	 * @return void
	 */
	public function save(string $path): void
	{
		$this->image->save($path);
	}

	/**
	 * 调整图片大小
	 * @param int $width 图片宽度
	 * @param int $height 图片高度
	 * @return $this
	 */
	public function resize(int $width, int $height): image
	{
		$this->image->resize(new Box($width, $height), ImageInterface::FILTER_UNDEFINED);
		return $this;
	}

	/**
	 * 添加水印
	 * @param string $watermark
	 * @param int $position
	 * @return $this
	 * @throws \Imagine\Exception\InvalidArgumentException
	 * @throws \Imagine\Exception\RuntimeException
	 */
	public function watermark(string $watermark, int $position = self::BOTTOM_RIGHT): image
	{
		$watermark_image = $this->imagine->open($watermark);
		$watermark_size = $watermark_image->getSize();
		$size = $this->image->getSize();

		$point = match ($position) {
			self::TOP_LEFT => [0, 0],
			self::TOP_CENTER => [($size->getWidth() - $watermark_size->getWidth()) / 2, 0],
			self::TOP_RIGHT => [$size->getWidth() - $watermark_size->getWidth(), 0],
			self::MIDDLE_LEFT => [0, ($size->getHeight() - $watermark_size->getHeight()) / 2],
			self::MIDDLE_CENTER => [($size->getWidth() - $watermark_size->getWidth()) / 2, ($size->getHeight() - $watermark_size->getHeight()) / 2],
			self::MIDDLE_RIGHT => [$size->getWidth() - $watermark_size->getWidth(), ($size->getHeight() - $watermark_size->getHeight()) / 2],
			self::BOTTOM_LEFT => [0, $size->getHeight() - $watermark_size->getHeight()],
			self::BOTTOM_CENTER => [($size->getWidth() - $watermark_size->getWidth()) / 2, $size->getHeight() - $watermark_size->getHeight()],
			self::BOTTOM_RIGHT => [$size->getWidth() - $watermark_size->getWidth(), $size->getHeight() - $watermark_size->getHeight()]
		};

		$start = new Point($point[0], $point[1]);
		$this->image->paste($watermark_image, $start);
		return $this;
	}
}