<?php

namespace phpvod\library;

use phpvod\library\config\config;

class options
{
	/**
	 * 无限制
	 * @return array
	 */
	public static function unlimited(): array
	{
		return [
			'unlimited' => lang('app.unlimited')
		];
	}

	/**
	 * 无
	 * @return array
	 */
	public static function none(): array
	{
		return [
			'' => lang('app.none')
		];
	}

	/**
	 * 开启与关闭
	 * @return array
	 */
	public static function open_close(): array
	{
		return [
			1 => lang('app.open'),
			0 => lang('app.close')
		];
	}

	/**
	 * 是与否
	 * @return array
	 */
	public static function yes_no(): array
	{
		return [
			1 => lang('app.yes'),
			0 => lang('app.no')
		];
	}

	/**
	 * 已审核与待审核
	 * @return array
	 */
	public static function checked_unchecked(): array
	{
		return [
			1 => lang('app.checked'),
			0 => lang('app.unchecked')
		];
	}

	/**
	 * 生产模式与开发模式
	 * @return string[]
	 */
	public static function prod_dev(): array
	{
		return [
			'prod' => lang('admin.production_mode'),
			'dev' => lang('admin.development_mode'),
		];
	}

	/**
	 * 时区列表
	 * @return array
	 */
	public static function datetime_zone(): array
	{
		static $datetime_zone = null;
		if (is_null($datetime_zone)) {
			$list = \DateTimeZone::listIdentifiers();
			$datetime_zone = [];
			foreach ($list as $zone) {
				$datetime_zone[$zone] = $zone;
			}
		}
		return $datetime_zone;
	}

	/**
	 * 登录背景
	 * @return array
	 */
	public static function background(): array
	{
		$r = [];
		$directory_list = [
			'image' => APP_PATH . 'asset/admin/login/image',
			'class' => APP_PATH . 'widget/background/class'
		];
		foreach ($directory_list as $type => $directory) {
			if ($handle = opendir($directory)) {
				while (false !== ($file = readdir($handle))) {
					if ($file != '.' && $file != '..') {
						['filename' => $filename, 'extension' => $extension] = pathinfo($file);
						if ($type == 'image') {
							if (in_array($extension, ['jpg', 'jpeg', 'gif'])) {
								$r[$type . ':' . $file] = $file;
							}
						} elseif ($type == 'class') {
							if ($extension == 'php') {
								$r[$type . ':' . $filename] = $file;
							}
						}
					}
				}
				closedir($handle);
			}
		}
		return $r;
	}

	/**
	 * 缓存处理器
	 * @return array
	 */
	public static function cache_handler(): array
	{
		$cache_config = \phpvod::$app->cache->get_config();
		return array_map(function ($v) {
			return ucfirst(basename(str_replace('\\', '/', $v)));
		}, $cache_config->handler_list);
	}

	/**
	 * 邮件发送协议
	 * @return array
	 */
	public static function mail_protocol(): array
	{
		return [
			'mail' => 'mail',
			'sendmail' => 'sendmail',
			'qmail' => 'qmail',
			'smtp' => 'smtp',
		];
	}

	/**
	 * smtp加密类型
	 * @return array
	 */
	public static function smtp_secure(): array
	{
		return self::none() + [
				'ssl' => 'ssl',
				'tls' => 'tls',
			];
	}

	/**
	 * 管理员角色
	 * @return array
	 * @throws \Exception
	 */
	public static function admin_role(): array
	{
		return config::get_instance()->get('admin_role');
	}

	/**
	 * 会员组
	 * @return array
	 * @throws \Exception
	 */
	public static function member_group(): array
	{
		$member_group = config::get_instance()->get('member_group');
		$member_group_options = array_column($member_group, 'name', 'id');
		unset($member_group_options[1]); //exclude guest
		return $member_group_options;
	}

	/**
	 * 语言
	 * @return array
	 */
	public static function language(): array
	{
		$language = config::get_instance()->get('language');
		return array_column($language, 'name', 'directory');
	}

	/**
	 * 模块
	 * @return array
	 */
	public static function module(): array
	{
		$modules = \phpvod::$app->module->get_modules();
		return array_column($modules, 'name', 'namespace');
	}

	/**
	 * 主模块
	 * @return array
	 */
	public static function main_module(): array
	{
		$options = [];
		$modules = \phpvod::$app->module->get_modules();
		foreach ($modules as $module) {
			$module['main'] == '1' && $options[$module['namespace']] = $module['name'];
		}
		return self::none() + $options;
	}

	/**
	 * 模板列表
	 * @param string|null $module_namespace
	 * @return array
	 */
	public static function template(?string $module_namespace): array
	{
		//view directory
		if (is_null($module_namespace)) {
			$view_directory = APP_PATH . 'view';
		} else {
			$module_directory = \phpvod::$app->module->get_module($module_namespace, 'directory');
			if (is_null($module_directory)) {
				return [];
			}
			$view_directory = MODULE_PATH . $module_directory . '/view';
		}

		$template_manager = template_manager::get_instance();
		$template_list = $template_manager->get_template_list($view_directory);
		return array_column($template_list, 'name', 'directory');
	}

	/**
	 * 磁盘容量单位
	 * @return array
	 */
	public static function disk_unit(): array
	{
		return [
			'b' => 'B',
			'kb' => 'KB',
			'mb' => 'MB',
			'gb' => 'GB'
		];
	}
}
