<?php

namespace phpvod\model;

use phpvod\widget\form\admin_form;

class admin extends \phpvod\base\model
{
	protected string $table = 'pv_admin';
	protected ?string $primary_key = 'id';
	protected array $allowed_fields = ['role_id', 'username', 'password_hash', 'email', 'phone', 'status', 'created_at', 'login_at', 'login_ip'];

	/**
	 * 管理员登录认证
	 * @param array $auth_field
	 * @return array|null
	 */
	public function auth(array $auth_field): ?array
	{
		$password = $auth_field['password'];
		unset($auth_field['password']);

		$admin = $this->select('a.*,ar.name AS role_name,ar.permissions')
			->from('pv_admin AS a LEFT JOIN pv_admin_role AS ar ON a.role_id = ar.id')
			->where($auth_field)->query()->fetch_array();

		return is_array($admin) && password_verify($password, $admin['password_hash']) ? $admin : null;
	}

	/**
	 * 通过id获取管理员数据
	 * @param int $id
	 * @return array|null
	 * @throws \Exception
	 */
	public function get_identity_by_id(int $id): ?array
	{
		$admin = $this->select('a.*,ar.name AS role_name,ar.permissions')
			->from('pv_admin AS a LEFT JOIN pv_admin_role AS ar ON a.role_id = ar.id')
			->where('a.id=:id', ['id' => $id])->query()->fetch_array();
		return is_array($admin) ? $admin : null;
	}

	/**
	 * 获取管理员数据
	 * @param array $params
	 * @return array
	 */
	public function get_data(array $params): array
	{
		//where
		if (!is_null($params['search'])) {
			$this->where('username LIKE :username OR email LIKE :email OR phone LIKE :phone', [
				'username' => '%' . $params['search'] . '%',
				'email' => '%' . $params['search'] . '%',
				'phone' => '%' . $params['search'] . '%'
			]);
		}

		$total = (int)$this->select('count(id)')->query(false)->fetch_column();

		//order by
		if (!is_null($params['order_by'])) {
			$this->order_by($params['order_by']);
		}

		//offset_limit
		if (!is_null($params['offset_limit'])) {
			$this->limit($params['offset_limit']);
		}

		$rows = $this->select('au.*,ar.name AS role_name')->from('pv_admin AS au LEFT JOIN pv_admin_role AS ar ON au.role_id = ar.id')->query()
			->fetch_all_by_callback(function (array $row) {
				$row['status'] = admin_form::get_instance()->switch((boolean)$row['status'], ['class' => 'form-check-input', 'role' => 'switch']);
				$row['created_at'] = timetostr($row['created_at']);
				$row['login_at'] = timetostr($row['login_at']);
				return $row;
			});

		return ['total' => $total, 'rows' => $rows];
	}

	/**
	 * 更新用户状态
	 * @param int $id 用户ID
	 * @return int|false 成功返回更新后的状态，失败返回false
	 * @throws \Exception
	 */
	public function change_status(int $id): int|false
	{
		$this->update(['status' => 'CASE status WHEN 0 THEN 1 ELSE 0 END'], $id, ['status']);
		$row = $this->select("status")->find($id)->fetch_array();
		return is_array($row) ? (int)$row['status'] : false;
	}
}