<?php

namespace phpvod\model;

use phpvod\base\model;
use venus\database\statement;

class config extends model
{
	protected string $table = 'pv_config';
	protected ?string $primary_key = 'id';
	protected array $allowed_fields = ['type', 'name', 'value'];

	/**
	 * 获取配置
	 * @param string $type
	 * @return array
	 */
	public function get_config(string $type): array
	{
		return $this->where(['type' => $type])->query()->fetch_all_by_callback(function (array $row) {
			if ((str_starts_with($row['value'], '{') && str_ends_with($row['value'], '}')) ||
				(str_starts_with($row['value'], '[') && str_ends_with($row['value'], ']'))
			) {
				$value = json_decode($row['value'], true);
				if (is_array($value)) {
					$row['value'] = $value;
				}
			}
			return ['key' => $row['name'], 'value' => $row['value']];
		});
	}

	/**
	 * 更新配置
	 * @param array $config
	 * @param string $type
	 * @return void
	 * @throws \Exception
	 */
	public function update_config(array $config, string $type): void
	{
		/**
		 * @var statement $query_statement
		 * @var statement $update_statement
		 * @var statement $insert_statement
		 */
		$query_statement = $this->db->prepare('SELECT count(name) FROM pv_config WHERE name = :name AND type = :type');
		$update_statement = $this->db->prepare('UPDATE pv_config SET value = :value WHERE name = :name AND type = :type');
		$insert_statement = $this->db->prepare('INSERT INTO pv_config (name, value, type) VALUES (:name, :value, :type)');
		foreach ($config as $name => $value) {
			if (is_array($value)) {
				$value = formatter($value);
			}
			$query_statement->execute([':name' => $name, ':type' => $type]);
			$n = (int)$query_statement->fetch_column();
			if ($n > 0) {
				$update_statement->execute([':name' => $name, ':value' => $value, ':type' => $type]);
			} else {
				$insert_statement->execute([':name' => $name, ':value' => $value, ':type' => $type]);
			}
		}
	}
}