<?php

namespace phpvod\model;

use phpvod\widget\form\admin_form;

class member extends \phpvod\base\model
{
	protected string $table = 'pv_member';
	protected ?string $primary_key = 'id';
	protected array $allowed_fields = ['group_id', 'group_expiry', 'change_to', 'username', 'password_hash', 'email', 'phone', 'balance', 'status', 'created_at', 'login_at', 'login_ip'];

	/**
	 * 会员登录认证
	 * @param array $auth_field
	 * @return array|null
	 */
	public function auth(array $auth_field): ?array
	{
		$password = $auth_field['password'];
		unset($auth_field['password']);

		$member = $this->select('m.*,mg.name AS group_name')
			->from('pv_member AS m LEFT JOIN pv_member_group AS mg ON m.group_id = mg.id')
			->where($auth_field)->query()->fetch_array();

		return is_array($member) && password_verify($password, $member['password_hash']) ? $member : null;
	}

	/**
	 * 通过id获取会员数据
	 * @param int $id
	 * @return array|null
	 * @throws \Exception
	 */
	public function get_identity_by_id(int $id): ?array
	{
		$member = $this->select('m.*,mg.name AS group_name')
			->from('pv_member AS m LEFT JOIN pv_member_group AS mg ON m.group_id = mg.id')
			->where('m.id=:id', ['id' => $id])->query()->fetch_array();
		return is_array($member) ? $member : null;
	}

	/**
	 * 获取管理员数据
	 * @param array $params 查询参数，包含search/order_by/offset_limit元素(非null即可用)
	 * @return array
	 */
	public function get_data(array $params): array
	{
		//where
		if (!is_null($params['search'])) {
			$this->where('username LIKE :username OR email LIKE :email OR phone LIKE :phone', [
				'username' => '%' . $params['search'] . '%',
				'email' => '%' . $params['search'] . '%',
				'phone' => '%' . $params['search'] . '%'
			]);
		}

		$total = (int)$this->select('count(id)')->query(false)->fetch_column();

		//order by
		if (!is_null($params['order_by'])) {
			$this->order_by($params['order_by']);
		}

		//offset_limit
		if (!is_null($params['offset_limit'])) {
			$this->limit($params['offset_limit']);
		}

		$rows = $this->select('m.*,mg.name AS group_name')->from('pv_member AS m LEFT JOIN pv_member_group AS mg ON m.group_id = mg.id')->query()
			->fetch_all_by_callback(function (array $row) {
				$row['balance'] = number_format(floatval($row['balance'])/100, 2, '.', '');
				$row['status'] = admin_form::get_instance()->switch((boolean)$row['status'], ['class' => 'form-check-input', 'role' => 'switch', 'value' => '1']);
				$row['created_at'] = timetostr($row['created_at']);
				$row['login_at'] = timetostr($row['login_at']);
				return $row;
			});

		return ['total' => $total, 'rows' => $rows];
	}

	/**
	 * 更新用户状态
	 * @param int $id 用户ID
	 * @return int|false 成功返回更新后的状态，失败返回false
	 * @throws \Exception
	 */
	public function change_status(int $id): int|false
	{
		$this->update(['status' => 'CASE status WHEN 0 THEN 1 ELSE 0 END'], $id, ['status']);
		$row = $this->select("status")->find($id)->fetch_array();
		return is_array($row) ? (int)$row['status'] : false;
	}

	/**
	 * 更改会员组ID
	 * @param int $id
	 * @return void
	 */
	public function change_group_id(int $id): void
	{
		$this->update(['group_id' => 'change_to', 'group_expiry' => 'null'], $id, ['group_id', 'group_expiry']);
	}
}