<?php

namespace phpvod\model;

class transaction_history extends \phpvod\base\model
{
	public const TYPE_INCOME = 1;
	public const TYPE_EXPENDITURE = 2;
	protected string $table = 'pv_transaction_history';
	protected ?string $primary_key = 'id';
	protected array $allowed_fields = ['member_id', 'type', 'action', 'related', 'amount', 'created_at', 'data'];
	protected ?string $created_field = 'created_at';

	/**
	 * 获取交易数据
	 * @param array $params
	 * @return array
	 */
	public function get_data(array $params): array
	{
		//where
		if (!is_null($params['search'])) {
			$this->where('m.username LIKE :username', [
				'username' => '%' . $params['search'] . '%'
			]);
		}

		$total = (int)$this->select('count(th.id)')->from('pv_transaction_history AS th LEFT JOIN pv_member AS m ON th.member_id = m.id')->query(false)->fetch_column();

		//order by
		if (!is_null($params['order_by'])) {
			$this->order_by($params['order_by']);
		}

		//offset_limit
		if (!is_null($params['offset_limit'])) {
			$this->limit($params['offset_limit']);
		}

		$rows = $this->select('th.*,m.username')->from('pv_transaction_history AS th LEFT JOIN pv_member AS m ON th.member_id = m.id')->query()
			->fetch_all_by_callback(function (array $row) {
				$row['action'] = lang('transaction_action.' . $row['action']);
				$row['amount'] = number_format(floatval($row['amount']) / 100, 2, '.', '');
				$row['created_at'] = timetostr($row['created_at']);
				return $row;
			});

		return ['total' => $total, 'rows' => $rows];
	}
}