<?php

namespace phpvod\service;

class transaction
{
	protected \venus\database\database $db;

	public function __construct()
	{
		$this->db = \phpvod::$app->database;
	}

	/**
	 * 购买会员组
	 * @param int $id
	 * @param int $index
	 * @return array
	 * @throws \Exception
	 */
	public function buy_member_group(int $id, int $index): array
	{
		$identity = \phpvod::$app->user_auth->get_frontend_identity();
		if (!is_array($identity)) {
			return ['id' => 0, 'msg' => lang('app.please_login_first')];
		}

		if ($identity['group_id'] == $id && is_null($identity['group_expiry'])) {
			return ['id' => 0, 'msg' => lang('home.no_need_to_buy')];
		}

		$member_group = \phpvod\library\config\config::get_instance()->get('member_group');
		$price = $member_group[$id]['sale']['price'][$index];
		$days = $member_group[$id]['sale']['days'][$index];

		if ((int)$identity['balance'] < $price) {
			return ['id' => 0, 'msg' => lang('app.insufficient_balance')];
		}

		$group_expiry = $identity['group_expiry'];
		if ($days == 0) {
			$group_expiry = null;
		} elseif (is_null($group_expiry)) {
			$group_expiry = TIMESTAMP + ($days * 86400);
		} else {
			$group_expiry = $group_expiry > TIMESTAMP ? $group_expiry + ($days * 86400) : TIMESTAMP + ($days * 86400);
		}

		$this->db->begin_transaction();
		try {
			//member
			/* @var \phpvod\model\member $member_model */
			$member_model = model(\phpvod\model\member::class);
			$member_model->update(['group_id' => $id, 'group_expiry' => $group_expiry, 'balance' => 'balance-' . $price], $identity['id'], ['balance']);
			//transaction_history
			/* @var \phpvod\model\transaction_history $transaction_history_model */
			$transaction_history_model = model(\phpvod\model\transaction_history::class);
			$transaction_history_model->insert([
				'member_id' => $identity['id'],
				'type' => \phpvod\model\transaction_history::TYPE_EXPENDITURE,
				'action' => 'buy_member_group',
				'related' => $member_group[$id]['name'],
				'amount' => $price,
				'data' => formatter(['group_id' => $id, 'price' => $price, 'days' => $days, 'group_expiry' => $group_expiry])
			]);
		} catch (\Exception) {
			$this->db->roll_back();
			return ['id' => 0, 'msg' => lang('app.operation_failed')];
		}

		return $this->db->commit() ? ['id' => 1, 'msg' => lang('app.purchase_succeeds')] : ['id' => 0, 'msg' => lang('app.operation_failed')];
	}
}