<?php
/**
 * @var \phpvod\widget\form\admin_form $form
 * @var \venus\view\view $this
 */
\phpvod\asset\bootstrap_table\bootstrap_table::register();
$form = \phpvod\widget\form\admin_form::get_instance();
$this->extend('admin/layout');
?>

<?php $this->section('content'); ?>

<div class="card">
	<div class="card-header"><?= lang('admin.admin') ?></div>
	<div class="card-body">
		<div id="toolbar" class="toolbar-btn-action">
			<div class="input-group">
				<button type="button" class="btn btn-primary me-2" onclick="window.location='<?=admin_uri('admin/add')?>'">
					<span class="mdi mdi-plus me-1" aria-hidden="true"></span><?=lang('app.add')?>
				</button>
				<button type="button" class="btn btn-danger" onclick="batch_delete_admin()">
					<span class="mdi mdi-window-close me-1" aria-hidden="true"></span><?=lang('app.delete')?>
				</button>
			</div>
		</div>
		<table id="bootstrap-table"></table>
	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>

<?php $this->end_section(); ?>

<?php $this->section('js'); ?>

<script type="text/javascript">
    $.ajaxSetup({headers: <?=csrf_json()?>});

    let bt = new bootstrap_table_helper('backend_admin', ['created_at', 'login_at', 'login_ip']);

    let columns = [
        {checkbox: true, width: 4, widthUnit: 'rem'},
        {field: 'id', title: '<?= lang('pv_admin.id') ?>', sortable:true, visible: bt.visible('id')},
        {field: 'username', title: '<?= lang('pv_admin.username') ?>', sortable:true, visible: bt.visible('username')},
        {field: 'role_name', title: '<?= lang('pv_admin.role_name') ?>', sortable:true, visible: bt.visible('role_name')},
        {field: 'email', title: '<?= lang('pv_admin.email') ?>', visible: bt.visible('email')},
        {field: 'phone', title: '<?= lang('pv_admin.phone') ?>', visible: bt.visible('phone')},
        {
            field: 'status',
            title: '<?= lang('pv_admin.status') ?>',
            visible: bt.visible('status'),
            events: {
                'click .form-check-input[role="switch"]': function (event, value, row, index) {
                    //更改状态
                    event.stopPropagation();
                    $.post("<?= admin_uri('admin/change-status') ?>", {id: row.id}, function (r) {
                        if (r.id === 1) {
                            $(event.currentTarget).prop("checked", r.data === 1);
                        } else {
                            $(event.currentTarget).prop("checked", !$(event.currentTarget).is(':checked')); //返回之前的状态
                            if (r.hasOwnProperty('msg'))
                                layer.msg(r.msg);
                            else
                                layer.msg('<?=lang('app.unknown_error')?>');
                        }
                    });
                }
            }
        },
        {field: 'created_at', title: '<?= lang('pv_admin.created_at') ?>', sortable:true, visible: bt.visible('created_at')},
        {field: 'login_at', title: '<?= lang('pv_admin.login_at') ?>', sortable:true, visible: bt.visible('login_at')},
        {field: 'login_ip', title: '<?= lang('pv_admin.login_ip') ?>', visible: bt.visible('login_ip')},
        {
            field: '__operation__',
            title: '<?=lang('app.operation')?>',
            visible: bt.visible('__operation__'),
            formatter: function () {
                return '<button type="button" class="btn btn-outline-primary px-1 py-0 me-1 edit-btn"><i class="mdi mdi-pencil me-1"></i><?=lang('app.edit')?></button>' +
                    '<button type="button" class="btn btn-outline-danger px-1 py-0 del-btn"><i class="mdi mdi-window-close me-1"></i><?=lang('app.delete')?></button>';
            },
            events: {
                'click .edit-btn': function (event, value, row, index) {
                    event.stopPropagation();
                    window.location.href = "<?=admin_uri('admin/edit')?>" + "?id=" + row.id;
                    return false;
                },
                'click .del-btn': function (event, value, row, index) {
                    //删除
                    event.stopPropagation();
                    delete_admin(row.id);
                }
            }
        }
    ];

    let options = {
        columns,
        url: '<?=admin_uri('admin/get-data')?>',
	    search: true,
		pagination: bt.pagination(),
		pageSize: bt.page_size(),
        locale: '<?=phpvod::$app->language->get_format_language('{lang}-{TAG}')?>',
		onColumnSwitch: function (column, checked) {
			bt.save_hidden_column(column, checked);
		},
		onPageChange: function(number, size) {
			bt.save_page_size(size);
		},
		onTogglePagination: function(status) {
			bt.save_pagination(status);
		},
	    queryParams: function (params) {
			//sort
			if(params.sort === undefined) {
				params.sort = 'id';
				params.order = 'asc';
			}
			return params;
	    }
    }

    $('#bootstrap-table').bootstrapTable({
        ...default_options,
        ...options
    });

    function batch_delete_admin() {
        let select = $('#bootstrap-table').bootstrapTable('getSelections');
        if (select.length === 0) {
            layer.msg("<?=lang('app.no_object_is_selected')?>");
        } else {
            let id = $.map(select, function (row) {
                return row.id;
            });
            delete_admin(id); //id is array
        }
    }

    function delete_admin(id) {
        layer.confirm("<?=lang('app.confirm_deletion')?>", {
            icon: 3,
            title: "<?=lang('app.message')?>",
            btn: ['<?=lang('app.delete')?>', '<?=lang('app.cancel')?>']
        }, function (index) {
            $.post("<?= admin_uri('admin/delete') ?>", {id: id}, function (r) {
                if (r.id === 1) {
                    $('#bootstrap-table').bootstrapTable('refresh');
                } else if (r.hasOwnProperty('msg')) {
                    layer.msg(r.msg);
                } else {
                    layer.msg('<?=lang('app.unknown_error')?>');
                }
            });
            layer.close(index);
        });
    }
</script>
<?php $this->end_section(); ?>
