<?php

use phpvod\library\options;

/**
 * @var \phpvod\widget\form\admin_form $form
 * @var \venus\view\view $this
 * @var array $config
 */
$form = \phpvod\widget\form\admin_form::get_instance();
$this->extend('admin/layout');
?>

<?php $this->section('content'); ?>

<div class="card">
	<div class="card-header"><?= lang('admin.cache_settings') ?></div>
	<div class="card-body">

		<?php $this->set_vars(['active' => 'cache'])->include('admin/config/_site_tabs'); ?>

		<div class="tab-content p-4">
			<div id="cache" class="tab-pane fade show active">
				<?= form_open(admin_uri('config/cache')) ?>
				<div class="row mb-4">
					<label class="col-md-2 col-form-label text-md-end"><?= lang('admin.cache_handler') ?></label>
					<div class="col-md-6">
						<?= $form->select('config[cache_handler]', options::cache_handler(), $config['cache_handler'], ['class' => 'form-select']) ?>
					</div>
				</div>

				<div id="redis" class="f-d-n">
					<div class="row mb-4">
						<label class="col-md-2 col-form-label text-md-end" for="redis-config">
							<?= lang('admin.redis_config') ?>
							<?= $form->tips(lang('admin.redis_tips')) ?>
						</label>
						<div class="col-md-6">
							<input class="form-control" type="text" id="redis-config" name="config[redis_config]" value="<?= $config['redis_config'] ?? '' ?>">
						</div>
					</div>
				</div>

				<div id="memcached" class="f-d-n">
					<div class="row mb-4">
						<label class="col-md-2 col-form-label text-md-end" for="memcached-config">
							<?= lang('admin.memcached_config') ?>
							<?= $form->tips(lang('admin.memcached_tips')) ?>
						</label>
						<div class="col-md-6">
							<textarea class="form-control" id="memcached-config" name="config[memcached_config]"><?= $config['memcached_config'] ?? '' ?></textarea>
						</div>
					</div>
				</div>

				<div class="row">
					<div class="col-md-6 offset-md-2">
						<button class="btn btn-primary" type="submit"><?= lang('app.save') ?></button>
						<button id="test-cache" class="btn btn-success" type="button">
							<span class="spinner-border spinner-border-sm f-d-n" role="status" aria-hidden="true"></span>
							<?= lang('admin.test_cache') ?>
						</button>
						<button id="clear-cache" class="btn btn-success" type="button">
							<span class="spinner-border spinner-border-sm f-d-n" role="status" aria-hidden="true"></span>
							<?= lang('admin.clear_cache') ?>
						</button>
					</div>
				</div>

				<?= form_close() ?>
			</div>
		</div>

	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>

<?php $this->end_section(); ?>

<?php $this->section('js') ?>
<script type="text/javascript">
	$.ajaxSetup({headers: <?=csrf_json()?>});
	let panel_list = [{"id": "redis", "value": "redis"}, {"id": "memcached", "value": "memcached"}];
	bindPanel("config[cache_handler]", panel_list, 'select');
	/**
	 * 测试缓存
	 */
	$("#test-cache").click(function () {
		$('#test-cache > span[role="status"]').css('display', 'inline-block');
		$("#test-cache").attr('disabled', 'disabled');
		$.post('<?= admin_uri('config/test-cache') ?>', function (r) {
			$('#test-cache > span[role="status"]').css('display', 'none');
			$("#test-cache").removeAttr('disabled');
			if (r.hasOwnProperty('msg'))
				layer.msg(r.msg);
			else
				layer.msg('<?=lang('app.unknown_error')?>');
		});
	});

	/**
	 * 清空缓存数据
	 */
	$("#clear-cache").click(function () {
		$('#clear-cache > span[role="status"]').css('display', 'inline-block');
		$("#clear-cache").attr('disabled', 'disabled');
		$.post('<?= admin_uri('config/clear-cache') ?>', function (r) {
			$('#clear-cache > span[role="status"]').css('display', 'none');
			$("#clear-cache").removeAttr('disabled');
			if (r.hasOwnProperty('msg'))
				layer.msg(r.msg);
			else
				layer.msg('<?=lang('app.unknown_error')?>');
		});
	});
</script>
<?php $this->end_section(); ?>
