<?php
/**
 * @var \phpvod\asset\admin\login $login_asset
 */
$login_asset = \phpvod\asset\admin\login::register();
?>
<!DOCTYPE html>
<html lang="<?= phpvod::$app->language->get_language() ?>">
<head>
	<base href="/">
	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<meta name="viewport" content="width=device-width, initial-scale=1.0, user-scalable=0, minimal-ui">
	<meta name="author" content="phpvod development team">
	<title><?= lang('admin.phpvod_backend_manage') ?></title>
	<?php phpvod::$app->event->trigger(\venus\view\event::EVENT_VIEW_HEAD); ?>
</head>

<body class="center-center"
      style="background: <?= $login_asset->get_background() ?>; background-size: cover; background-position: center;">
<?php phpvod::$app->event->trigger(\venus\view\event::EVENT_VIEW_BEGIN_BODY); ?>

<div class="sign-in-box p-5 mb-0 mr-2 ml-2">

	<?php if(count(phpvod::$app->language->get_supported_language()) > 1): ?>
	<div class="language">
		<div class="dropdown">
			<a id="dropdown-menu-button" data-bs-toggle="dropdown" aria-expanded="false">
				<span class="mdi mdi-google-translate"></span>
			</a>
			<ul class="dropdown-menu" aria-labelledby="dropdown-menu-button">
				<?php foreach (\phpvod\library\options::language() as $directory => $name): ?>
					<li><a class="dropdown-item" onclick="set_language('<?= $directory ?>')"><?= $name ?></a></li>
				<?php endforeach; ?>
			</ul>
		</div>
	</div>
	<?php endif; ?>

	<div class="text-center text-light mb-3"><?= lang('admin.phpvod_backend_manage') ?></div>

	<?= form_open(admin_uri('login'), ['method' => 'post', 'class' => 'sign-in-form needs-validation']) ?>
	<div class="mb-3 has-feedback">
		<span class="mdi mdi-account" aria-hidden="true"></span>
		<input type="text" class="form-control" name="username" placeholder="<?= lang('app.username') ?>">
	</div>

	<div class="mb-3 has-feedback">
		<span class="mdi mdi-lock" aria-hidden="true"></span>
		<input type="password" class="form-control" name="password" placeholder="<?= lang('app.password') ?>">
	</div>

	<div class="mb-3 has-feedback row">
		<div class="col-7">
			<span class="mdi mdi-check-all form-control-feedback" aria-hidden="true"></span>
			<input type="text" name="captcha" class="form-control" placeholder="<?= lang('app.captcha') ?>">
		</div>
		<div class="col-5 text-right">
			<img src="captcha/index/120/38" class="pull-right" id="captcha" style="cursor: pointer;"
			     onclick="this.src='captcha/index/120/38?r='+Math.random();"
			     title="<?= lang('app.click_refresh') ?>" alt="captcha">
		</div>
	</div>

	<div class="mb-3 d-grid">
		<button class="btn btn-primary" type="submit"><?= lang('app.login') ?></button>
	</div>
	<?= form_close() ?>

	<p class="copyright"><?= phpvod::copyright() ?></p>
</div>

<?php phpvod::$app->event->trigger(\venus\view\event::EVENT_VIEW_IMPORT_JS); ?>
<?= \phpvod\widget\toastr::show() ?>

<script type="text/javascript">
	$(document).ready(function () {
		$(".sign-in-form").validate({
			rules: {
				username: "required",
				password: "required",
				captcha: {
					required: true,
					remote: 'captcha/check'
				}
			},
			messages: {
				username: "<?= lang('app.username_cannot_be_empty') ?>",
				password: "<?= lang('app.password_cannot_be_empty') ?>",
				captcha: {
					required: "<?= lang('app.captcha_cannot_be_empty') ?>",
					remote: "<?= lang('app.captcha_error') ?>"
				},
			},
			errorPlacement: function (error, element) {
				error.appendTo(element.parent());
			},
			onkeyup: false
		});
	});

	function set_language(language) {
		$.get("<?= api_uri('language/change_language') ?>", {language: language}, function (data) {
			if (data.id === 1) {
				window.location.reload();
			}
		});
	}

</script>
<?php phpvod::$app->event->trigger(\venus\view\event::EVENT_VIEW_END_BODY); ?>
</body>
</html>
