<?php
/**
 * @var \phpvod\widget\form\admin_form $form
 * @var \venus\view\view $this
 */
\phpvod\asset\bootstrap_table\bootstrap_table::register();
$this->extend('admin/layout');
?>

<?php $this->section('content'); ?>

<div class="card">
	<div class="card-header"><?= lang('admin.language_management') ?></div>
	<div class="card-body">
		<div id="toolbar" class="toolbar-btn-action">
			<div class="input-group">
				<button type="button" class="btn btn-primary me-2"
				        onclick="window.location='<?= admin_uri('language/add') ?>'">
					<span class="mdi mdi-plus me-1" aria-hidden="true"></span><?= lang('app.add') ?>
				</button>
			</div>
		</div>
		<table id="bootstrap-table"></table>
	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>

<?php $this->end_section(); ?>

<?php $this->section('js'); ?>
<script type="text/javascript">
	$.ajaxSetup({headers: <?=csrf_json()?>});
	let bt = new bootstrap_table_helper('backend_language', []);

	let columns = [
		{field: 'id', title: '<?= lang('pv_language.id') ?>', sortable: true, visible: bt.visible('id')},
		{
			field: 'name',
			title: '<?= lang('pv_language.name') ?>',
			visible: bt.visible('name'),
			formatter: function (value, row, index, field) {
				let badge_current = row.module_namespace == null && row.directory == '<?=phpvod::$app->language->get_language()?>' ? ' <span class="badge bg-primary"><?=lang('admin.current_language')?></span>' : '';
				let badge_default = row.module_namespace == null && row.default_language == 1 ? ' <span class="badge bg-success"><?=lang('admin.default_language')?></span>' : '';
				return value + badge_current + badge_default;
			}
		},
		{field: 'directory', title: '<?= lang('pv_language.directory') ?>', visible: bt.visible('directory')},
		{field: 'module_name', title: '<?= lang('admin.belong_module') ?>', visible: bt.visible('module_name')},
		{
			field: '__operation__',
			width: 30,
			widthUnit: '%',
			title: '<?=lang('app.operation')?>',
			visible: bt.visible('__operation__'),
			formatter: function (value, row, index, field) {
				if (row.module_namespace == null) {
					return '<button type="button" class="btn btn-outline-primary px-1 py-0 me-1 use-btn"><i class="mdi mdi-translate me-1"></i><?=lang('admin.use_language')?></button>' +
						'<button type="button" class="btn btn-outline-success px-1 py-0 me-1 default-btn"><i class="mdi mdi-translate me-1"></i><?=lang('admin.default_language')?></button>' +
						'<button type="button" class="btn btn-outline-danger px-1 py-0 delete-btn"><i class="mdi mdi-delete me-1"></i><?=lang('app.delete')?></button>';
				} else {
					return '<button type="button" class="btn btn-outline-danger px-1 py-0 delete-module-language-btn"><i class="mdi mdi-delete me-1"></i><?=lang('app.delete')?></button>';
				}
			},
			events: {
				'click .use-btn': function (event, value, row, index) {
					$.get("<?=api_uri('language/change_language')?>", {language: row.directory}, function (r) {
						if (r.id === 1) {
							window.parent.location.reload();
						} else {
							if (r.hasOwnProperty('msg'))
								layer.msg(r.msg);
							else
								layer.msg('<?=lang('app.unknown_error')?>');
						}
					});
				},
				'click .default-btn': function (event, value, row, index) {
					event.stopPropagation();
					$.post("<?= admin_uri('language/set-default-language') ?>", {id: row.id}, function (r) {
						if (r.id === 1) {
							$('#bootstrap-table').bootstrapTable('refresh');
						} else {
							if (r.hasOwnProperty('msg'))
								layer.msg(r.msg);
							else
								layer.msg('<?=lang('app.unknown_error')?>');
						}
					});
				},
				'click .delete-btn': function (event, value, row, index) {
					//删除语言
					event.stopPropagation();
					delete_language(row.id);
				},
				'click .delete-module-language-btn': function (event, value, row, index) {
					//删除模块语言
					event.stopPropagation();
					delete_module_language(row.module_namespace, row.directory);
				}
			}
		}
	];

	let options = {
		columns,
		url: '<?=admin_uri('language/get-data')?>',
		search: true,
		pagination: bt.pagination(),
		pageSize: bt.page_size(),
		locale: '<?=phpvod::$app->language->get_format_language('{lang}-{TAG}')?>',
		onColumnSwitch: function (column, checked) {
			bt.save_hidden_column(column, checked);
		},
		onPageChange: function (number, size) {
			bt.save_page_size(size);
		},
		onTogglePagination: function (status) {
			bt.save_pagination(status);
		},
		queryParams: function (params) {
			if (params.sort === undefined) {
				params.sort = 'id';
				params.order = 'asc';
			}
			return params;
		}
	}

	$('#bootstrap-table').bootstrapTable({
		...default_options,
		...options
	});

	function delete_language(id) {
		layer.confirm("<?=lang('app.confirm_deletion')?>", {
			icon: 3,
			title: "<?=lang('app.message')?>",
			btn: ['<?=lang('app.delete')?>', '<?=lang('app.cancel')?>']
		}, function (index) {
			$.post("<?= admin_uri('language/delete') ?>", {id: id}, function (r) {
				if (r.id === 1 || r.id === 2) {
					$('#bootstrap-table').bootstrapTable('refresh');
					if (r.id === 2) {
						layer.alert(r.msg); //操作完成，请手动删除以下目录
					}
				} else if (r.hasOwnProperty('msg')) {
					layer.msg(r.msg);
				} else {
					layer.msg('<?=lang('app.unknown_error')?>');
				}
			});
			layer.close(index);
		});
	}

	function delete_module_language(module_namespace, directory) {
		layer.confirm("<?=lang('app.confirm_deletion')?>", {
			icon: 3,
			title: "<?=lang('app.message')?>",
			btn: ['<?=lang('app.delete')?>', '<?=lang('app.cancel')?>']
		}, function (index) {
			$.post("<?= admin_uri('language/delete-module-language') ?>", {module_namespace, directory}, function (r) {
				if (r.id === 1 || r.id === 2) {
					$('#bootstrap-table').bootstrapTable('refresh');
					if (r.id === 2) {
						layer.alert(r.msg); //操作完成，请手动删除以下目录
					}
				} else if (r.hasOwnProperty('msg')) {
					layer.msg(r.msg);
				} else {
					layer.msg('<?=lang('app.unknown_error')?>');
				}
			});
			layer.close(index);
		});
	}
</script>
<?php $this->end_section(); ?>
