<?php
/**
 * @var \phpvod\widget\form\admin_form $form
 * @var \venus\view\view $this
 */
\phpvod\asset\bootstrap_table\bootstrap_table::register();
$form = \phpvod\widget\form\admin_form::get_instance();
$this->extend('admin/layout');
?>

<?php $this->section('content'); ?>

<div class="card">
	<div class="card-header"><?= lang('admin.member') ?></div>
	<div class="card-body">
		<div id="toolbar" class="toolbar-btn-action">
			<div class="input-group">
				<button type="button" class="btn btn-primary me-2" onclick="window.location='<?=admin_uri('member/add')?>'">
					<span class="mdi mdi-plus me-1" aria-hidden="true"></span><?=lang('app.add')?>
				</button>
				<button type="button" class="btn btn-danger" onclick="batch_delete_member()">
					<span class="mdi mdi-window-close me-1" aria-hidden="true"></span><?=lang('app.delete')?>
				</button>
			</div>
		</div>
		<table id="bootstrap-table"></table>
	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>

<?php $this->end_section(); ?>

<?php $this->section('js'); ?>

<script type="text/javascript">
    $.ajaxSetup({headers: <?=csrf_json()?>});

    let bt = new bootstrap_table_helper('backend_member', ['created_at', 'login_at', 'login_ip']);

    let columns = [
        {checkbox: true, width: 4, widthUnit: 'rem'},
        {field: 'id', title: '<?= lang('pv_member.id') ?>', sortable:true, visible: bt.visible('id')},
        {field: 'username', title: '<?= lang('pv_member.username') ?>', sortable:true, visible: bt.visible('username')},
        {field: 'group_name', title: '<?= lang('pv_member.group_name') ?>', sortable:true, visible: bt.visible('group_name')},
	    {field: 'email', title: '<?= lang('pv_member.email') ?>', visible: bt.visible('email')},
        {field: 'phone', title: '<?= lang('pv_member.phone') ?>', visible: bt.visible('phone')},
		{field: 'balance', title: '<?= lang('pv_member.balance') ?>', visible: bt.visible('balance')},
        {
            field: 'status',
            title: '<?= lang('pv_member.status') ?>',
            visible: bt.visible('status'),
            events: {
                'click .form-check-input[role="switch"]': function (event, value, row, index) {
                    //更改状态
                    event.stopPropagation();
                    $.post("<?= admin_uri('member/change-status') ?>", {id: row.id}, function (r) {
                        if (r.id === 1) {
                            $(event.currentTarget).prop("checked", r.data === 1);
                        } else {
                            $(event.currentTarget).prop("checked", !$(event.currentTarget).is(':checked')); //返回之前的状态
                            if (r.hasOwnProperty('msg'))
                                layer.msg(r.msg);
                            else
                                layer.msg('<?=lang('app.unknown_error')?>');
                        }
                    });
                }
            }
        },
        {field: 'created_at', title: '<?= lang('pv_member.created_at') ?>', sortable:true, visible: bt.visible('created_at')},
        {field: 'login_at', title: '<?= lang('pv_member.login_at') ?>', sortable:true, visible: bt.visible('login_at')},
        {field: 'login_ip', title: '<?= lang('pv_member.login_ip') ?>', visible: bt.visible('login_ip')},
        {
            field: '__operation__',
            title: '<?=lang('app.operation')?>',
            visible: bt.visible('__operation__'),
            formatter: function (value, row) {
                let pass_btn = row.group_id == '2' ? '<button type="button" class="btn btn-outline-success px-1 py-0 pass-btn"><i class="mdi mdi-check me-1"></i><?=lang('admin.pass')?></button>' : '';
                return '<button type="button" class="btn btn-outline-primary px-1 py-0 me-1 edit-btn"><i class="mdi mdi-pencil me-1"></i><?=lang('app.edit')?></button>' +
                    '<button type="button" class="btn btn-outline-danger px-1 py-0 me-1 del-btn"><i class="mdi mdi-window-close me-1"></i><?=lang('app.delete')?></button>' +
	                pass_btn;
            },
            events: {
                'click .edit-btn': function (event, value, row, index) {
                    event.stopPropagation();
                    window.location.href = "<?=admin_uri('member/edit')?>" + "?id=" + row.id;
                    return false;
                },
                'click .del-btn': function (event, value, row, index) {
                    //删除
                    event.stopPropagation();
                    delete_member(row.id);
                },
                'click .pass-btn': function (event, value, row, index) {
                    //删除
                    event.stopPropagation();
                    pass_member(row.id);
                }
            }
        }
    ];

    let options = {
        columns,
        url: '<?=admin_uri('member/get-data')?>',
	    search: true,
		pagination: bt.pagination(),
		pageSize: bt.page_size(),
        locale: '<?=phpvod::$app->language->get_format_language('{lang}-{TAG}')?>',
		onColumnSwitch: function (column, checked) {
			bt.save_hidden_column(column, checked);
		},
		onPageChange: function(number, size) {
			bt.save_page_size(size);
		},
		onTogglePagination: function(status) {
			bt.save_pagination(status);
		},
	    queryParams: function (params) {
			//sort
			if(params.sort === undefined) {
				params.sort = 'id';
				params.order = 'desc';
			}
			return params;
	    }
    }

    $('#bootstrap-table').bootstrapTable({
        ...default_options,
        ...options
    });

    function batch_delete_member() {
        let select = $('#bootstrap-table').bootstrapTable('getSelections');
        if (select.length === 0) {
            layer.msg("<?=lang('app.no_object_is_selected')?>");
        } else {
            let id = $.map(select, function (row) {
                return row.id;
            });
            delete_member(id); //id is array
        }
    }

    function delete_member(id) {
        layer.confirm("<?=lang('app.confirm_deletion')?>", {
            icon: 3,
            title: "<?=lang('app.message')?>",
            btn: ['<?=lang('app.delete')?>', '<?=lang('app.cancel')?>']
        }, function (index) {
            $.post("<?= admin_uri('member/delete') ?>", {id: id}, function (r) {
                if (r.id === 1) {
                    $('#bootstrap-table').bootstrapTable('refresh');
                } else if (r.hasOwnProperty('msg')) {
                    layer.msg(r.msg);
                } else {
                    layer.msg('<?=lang('app.unknown_error')?>');
                }
            });
            layer.close(index);
        });
    }

    function pass_member(id) {
        $.post("<?= admin_uri('member/pass') ?>", {id: id}, function (r) {
            if (r.id === 1) {
                $('#bootstrap-table').bootstrapTable('refresh');
            } else if (r.hasOwnProperty('msg')) {
                layer.msg(r.msg);
            } else {
                layer.msg('<?=lang('app.unknown_error')?>');
            }
        });
    }
</script>
<?php $this->end_section(); ?>
