<?php
/**
 * @var \venus\view\view $this
 * @var array $group
 * @var array $sale
 */
$this->extend('admin/layout');
$sale = old('sale', $sale);
$permissions = old('permissions');
$member_group_permissions = is_array($permissions) ? $permissions : (empty($group['permissions']) ? [] : json_decode($group['permissions'], true));
$form = \phpvod\widget\form\admin_form::get_instance();
?>
<?php $this->section('content'); ?>

<div class="card">
	<div class="card-header"><?= lang('admin.edit_member_group') ?></div>
	<div class="card-body">
		<?= form_open(admin_uri('member-group/edit'), [], ['id' => $group['id']]) ?>
		<div class="row">
			<div class="col-md-6 offset-md-2">
				<?php if ($group['id'] >= 1 && $group['id'] <= 3): ?>
					<div class="alert alert-primary" role="alert">
						<?= lang('admin.message_group_id_' . $group['id']) ?>
					</div>
				<?php endif; ?>
			</div>
		</div>
		<div class="row mb-4">
			<label class="col-md-2 col-form-label text-md-end" for="name"><?= lang('pv_member_group.name') ?></label>
			<div class="col-md-6">
				<input class="form-control" type="text" id="name" name="name" value="<?= old('name', $group['name']) ?>">
			</div>
		</div>
		<?php if ($group['id'] > 3): ?>
			<div class="row mb-4">
				<label class="col-md-2 col-form-label text-md-end"><?= lang('pv_member_group.sale') ?></label>
				<div class="col-md-6">
					<table class="table table-sm table-borderless sale-table">
						<thead>
						<tr>
							<th><?= lang('app.label') ?></th>
							<th><?= lang('app.price') ?></th>
							<th><?= lang('app.duration') ?> <?= $form->tips(lang('admin.tips_days')) ?></th>
						</tr>
						</thead>
						<tbody>
						<?php foreach ($sale['label'] as $key => $value): ?>
							<tr>
								<td><input type="text" class="form-control form-control-sm" name="sale[label][]" value="<?= $value ?>"/></td>
								<td>
									<div class="input-group input-group-sm">
										<input type="text" class="form-control text-end" name="sale[price][]" value="<?= $sale['price'][$key] ?>"/>
										<div class="input-group-text"><?= lang('app.cny') ?></div>
									</div>
								</td>
								<td>
									<div class="input-group input-group-sm">
										<input type="text" class="form-control text-end" name="sale[days][]" value="<?= $sale['days'][$key] ?>"/>
										<div class="input-group-text"><?= lang('admin.days') ?></div>
									</div>
								</td>
							</tr>
						<?php endforeach; ?>
						</tbody>
						<tfoot>
						<tr>
							<td colspan="3">
								<button type="button" class="btn btn-sm btn-outline-primary px-1 py-0" id="add-btn"><i class="mdi mdi-plus me-1"></i>新增</button>
								<button type="button" class="btn btn-sm btn-outline-danger px-1 py-0" id="remove-btn"><i class="mdi mdi-window-close me-1"></i>删除</button>
							</td>
						</tr>
						</tfoot>
					</table>
				</div>
			</div>
		<?php endif; ?>
		<div class="row mb-4">
			<label class="col-md-2 col-form-label text-md-end"><?= lang('pv_member_group.permissions') ?></label>
			<div class="col-md-6">
				<?= \phpvod\widget\member_group_permission::get_instance()->index($member_group_permissions) ?>
			</div>
		</div>
		<div class="row">
			<div class="col-md-6 offset-md-2">
				<button class="btn btn-primary" type="submit"><?= lang('app.save') ?></button>
			</div>
		</div>
		<?= form_close() ?>
	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>

<?php $this->end_section(); ?>

<?php $this->section('js'); ?>
<script type="text/javascript">
	$('#add-btn').click(function () {
		let table = $('.sale-table');
		let tr = table.find('tbody tr:first').clone();
		tr.find(':input').val('');
		table.append(tr);
	});
	$('#remove-btn').click(function () {
		$('.sale-table tbody tr:not(:first):last').remove();
	});
</script>
<?php $this->end_section(); ?>
