<?php
/**
 * @var \phpvod\widget\form\admin_form $form
 * @var \venus\view\view $this
 */
\phpvod\asset\admin\update::register();
\phpvod\asset\bootstrap_table\bootstrap_table::register();
$form = \phpvod\widget\form\admin_form::get_instance();
$this->extend('admin/layout');
?>

<?php $this->section('content'); ?>

<div class="card">
	<div class="card-header"><?= lang('admin.module_management') ?></div>
	<div class="card-body">
		<div id="toolbar" class="toolbar-btn-action">
			<div class="input-group">
				<button type="button" class="btn btn-primary me-2"
				        onclick="window.location='<?= admin_uri('module/add') ?>'">
					<span class="mdi mdi-plus me-1" aria-hidden="true"></span><?= lang('app.add') ?>
				</button>
			</div>
		</div>
		<table id="bootstrap-table"></table>
	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>

<?php $this->end_section(); ?>

<?php $this->section('js'); ?>
<script type="text/javascript">
	$.ajaxSetup({headers: <?=csrf_json()?>});
	let bt = new bootstrap_table_helper('backend_module', ['domain', 'author', 'description', 'website']);

	let columns = [
		{field: 'id', title: '<?= lang('pv_module.id') ?>', sortable: true, visible: bt.visible('id')},
		{field: 'name', title: '<?= lang('pv_module.name') ?>', visible: bt.visible('name')},
		{field: 'namespace', title: '<?= lang('pv_module.namespace') ?>', visible: bt.visible('namespace')},
		{field: 'segment', title: '<?= lang('pv_module.segment') ?>', visible: bt.visible('segment')},
		{field: 'directory', title: '<?= lang('pv_module.directory') ?>', visible: bt.visible('directory')},
		{field: 'version', title: '<?= lang('pv_module.version') ?>', visible: bt.visible('version')},
		{field: 'domain', title: '<?= lang('pv_module.domain') ?>', visible: bt.visible('domain')},
		{field: 'author', title: '<?= lang('pv_module.author') ?>', visible: bt.visible('author')},
		{field: 'description', title: '<?= lang('pv_module.description') ?>', visible: bt.visible('description')},
		{field: 'website', title: '<?= lang('pv_module.website') ?>', visible: bt.visible('website')},
		{
			field: 'status',
			title: '<?= lang('pv_module.status') ?>',
			visible: bt.visible('status'),
			events: {
				'click .form-check-input[role="switch"]': function (event, value, row, index) {
					//更改状态
					event.stopPropagation();
					$.post("<?= admin_uri('module/change-status') ?>", {id: row.id}, function (r) {
						if (r.id === 1) {
							$(event.currentTarget).prop("checked", r.data === 1);
						} else {
							$(event.currentTarget).prop("checked", !$(event.currentTarget).is(':checked')); //返回之前的状态
							if (r.hasOwnProperty('msg'))
								layer.msg(r.msg);
							else
								layer.msg('<?=lang('app.unknown_error')?>');
						}
					});
				}
			}
		},
		{
			field: '__operation__',
			title: '<?=lang('app.operation')?>',
			visible: bt.visible('__operation__'),
			formatter: function (value, row, index, field) {
				return '<button type="button" class="btn btn-outline-success px-1 py-0 me-1 upgrade-btn"><i class="mdi mdi-cloud-check me-1"></i><?=lang('admin.upgrade')?></button>' +
					'<button type="button" class="btn btn-outline-primary px-1 py-0 me-1 config-btn"><i class="mdi mdi-cog me-1"></i><?=lang('admin.config')?></button>' +
					'<button type="button" class="btn btn-outline-danger px-1 py-0 uninstall-btn"><i class="mdi mdi-delete me-1"></i><?=lang('admin.uninstall')?></button>';
			},
			events: {
				'click .config-btn': function (event, value, row, index) {
					event.stopPropagation();
					window.location.href = "<?= admin_uri('module/config')?>" + '?namespace=' + row.namespace;
				},
				'click .upgrade-btn': function (event, value, row, index) {
					event.stopPropagation();
					update.check_version_url = '<?=admin_uri('update/check-version')?>';
					update.download_package_url = '<?=admin_uri('update/download-package')?>';
					update.update_system_url = '<?=admin_uri('update/update-system')?>';
					update.check_version(row.namespace, row.version);
				},
				'click .uninstall-btn': function (event, value, row, index) {
					//删除
					event.stopPropagation();
					delete_module(row.namespace);
				}
			}
		}
	];

	let options = {
		columns,
		url: '<?=admin_uri('module/get-data')?>',
		search: true,
		pagination: bt.pagination(),
		pageSize: bt.page_size(),
		locale: '<?=phpvod::$app->language->get_format_language('{lang}-{TAG}')?>',
		onColumnSwitch: function (column, checked) {
			bt.save_hidden_column(column, checked);
		},
		onPageChange: function (number, size) {
			bt.save_page_size(size);
		},
		onTogglePagination: function (status) {
			bt.save_pagination(status);
		},
		queryParams: function (params) {
			if (params.sort === undefined) {
				params.sort = 'id';
				params.order = 'asc';
			}
			return params;
		}
	}

	$('#bootstrap-table').bootstrapTable({
		...default_options,
		...options
	});

	function delete_module(namespace) {
		layer.confirm("<?=lang('app.confirm_deletion')?>", {
			icon: 3,
			title: "<?=lang('app.message')?>",
			btn: ['<?=lang('app.delete')?>', '<?=lang('app.cancel')?>']
		}, function (index) {
			$.post("<?= admin_uri('module/delete') ?>", {namespace: namespace}, function (r) {
				if (r.id === 1 || r.id === 2) {
					$('#bootstrap-table').bootstrapTable('refresh');
					update_backend_menu(); //更新菜单
					if (r.id === 2) {
						layer.alert(r.msg); //模块卸载成功，请手动删除模块目录
					}
				} else if (r.hasOwnProperty('msg')) {
					layer.msg(r.msg);
				} else {
					layer.msg('<?=lang('app.unknown_error')?>');
				}
			});
			layer.close(index);
		});
	}
</script>
<?php $this->end_section(); ?>
