<?php
/**
 * @var \phpvod\widget\form\admin_form $form
 * @var \venus\view\view $this
 */
\phpvod\asset\bootstrap_table\bootstrap_table::register();
$this->extend('admin/layout');
?>

<?php $this->section('content'); ?>

<div class="card">
	<div class="card-header"><?= lang('admin.template_management'); ?></div>
	<div class="card-body">
		<div id="toolbar" class="toolbar-btn-action">
			<div class="input-group">
				<button type="button" class="btn btn-primary me-2"
				        onclick="window.location='<?= admin_uri('template/add') ?>'">
					<span class="mdi mdi-plus me-1" aria-hidden="true"></span><?= lang('app.add') ?>
				</button>
			</div>
		</div>
		<table id="bootstrap-table"></table>
	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>

<?php $this->end_section(); ?>

<?php $this->section('js'); ?>
<script type="text/javascript">
	$.ajaxSetup({headers: <?=csrf_json()?>});
	let bt = new bootstrap_table_helper('backend_template', ['author', 'description', 'website']);

	let columns = [
		{field: 'id', title: 'id', visible: bt.visible('id')},
		{field: 'name', title: '<?= lang('admin.template_name') ?>', visible: bt.visible('name')},
		{field: 'directory', title: '<?= lang('admin.template_directory') ?>', visible: bt.visible('directory')},
		{field: 'module_name', title: '<?= lang('admin.belong_module') ?>', visible: bt.visible('module_name')},
		{field: 'author', title: '<?= lang('admin.template_author') ?>', visible: bt.visible('author')},
		{field: 'description', title: '<?= lang('admin.template_description') ?>', visible: bt.visible('description')},
		{field: 'website', title: '<?= lang('admin.template_website') ?>', visible: bt.visible('website')},
		{
			field: '__operation__',
			title: '<?=lang('app.operation')?>',
			visible: bt.visible('__operation__'),
			formatter: function (value, row, index, field) {
				return '<button type="button" class="btn btn-outline-danger px-1 py-0 delete-btn"><i class="mdi mdi-delete me-1"></i><?=lang('app.delete')?></button>';
			},
			events: {
				'click .delete-btn': function (event, value, row, index) {
					//删除语言
					event.stopPropagation();
					let module_namespace = row.hasOwnProperty('module_namespace') ? row.module_namespace : '';
					delete_template(module_namespace, row.directory);
				}
			}
		}
	];

	let options = {
		columns,
		url: '<?=admin_uri('template/get-data')?>',
		search: true,
		pagination: bt.pagination(),
		pageSize: bt.page_size(),
		locale: '<?=phpvod::$app->language->get_format_language('{lang}-{TAG}')?>',
		onColumnSwitch: function (column, checked) {
			bt.save_hidden_column(column, checked);
		},
		onPageChange: function (number, size) {
			bt.save_page_size(size);
		},
		onTogglePagination: function (status) {
			bt.save_pagination(status);
		},
		queryParams: function (params) {
			return params;
		}
	}

	$('#bootstrap-table').bootstrapTable({
		...default_options,
		...options
	});

	function delete_template(module_namespace, directory) {
		layer.confirm("<?=lang('app.confirm_deletion')?>", {
			icon: 3,
			title: "<?=lang('app.message')?>",
			btn: ['<?=lang('app.delete')?>', '<?=lang('app.cancel')?>']
		}, function (index) {
			$.post("<?= admin_uri('template/delete') ?>", {module_namespace, directory}, function (r) {
				if (r.id === 1 || r.id === 2) {
					$('#bootstrap-table').bootstrapTable('refresh');
					if (r.id === 2) {
						layer.alert(r.msg); //模板卸载失败，请手动删除目录
					}
				} else if (r.hasOwnProperty('msg')) {
					layer.msg(r.msg);
				} else {
					layer.msg('<?=lang('app.unknown_error')?>');
				}
			});
			layer.close(index);
		});
	}
</script>
<?php $this->end_section(); ?>
