<?php
/**
 * @var \phpvod\widget\form\admin_form $form
 * @var \venus\view\view $this
 */
\phpvod\asset\bootstrap_table\bootstrap_table::register();
$form = \phpvod\widget\form\admin_form::get_instance();
$this->extend('admin/layout');
?>

<?php $this->section('content'); ?>

<div class="card">
	<div class="card-header"><?= lang('admin.transaction_history') ?></div>
	<div class="card-body">
		<div id="toolbar" class="toolbar-btn-action">
			<div class="input-group">
				<button type="button" class="btn btn-danger" onclick="batch_delete_record()">
					<span class="mdi mdi-window-close me-1" aria-hidden="true"></span><?= lang('app.delete') ?>
				</button>
			</div>
		</div>
		<table id="bootstrap-table"></table>
	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>

<?php $this->end_section(); ?>

<?php $this->section('js'); ?>

<script type="text/javascript">
	$.ajaxSetup({headers: <?=csrf_json()?>});

	let bt = new bootstrap_table_helper('backend_transaction_history', ['data']);

	let columns = [
		{checkbox: true, width: 4, widthUnit: 'rem'},
		{field: 'id', title: '<?= lang('pv_transaction_history.id') ?>', sortable: true, visible: bt.visible('id')},
		{field: 'username', title: '<?= lang('app.username') ?>', visible: bt.visible('username')},
		{
			field: 'type',
			title: '<?= lang('pv_transaction_history.type') ?>',
			sortable: true,
			visible: bt.visible('type'),
			formatter: function (value, row, index, field) {
				return value == 1 ? '<?=lang('app.income')?>' : '<?= lang('app.expenditure')?>';
			},
		},
		{field: 'action', title: '<?= lang('pv_transaction_history.action') ?>', visible: bt.visible('action')},
		{field: 'related', title: '<?= lang('pv_transaction_history.related') ?>', visible: bt.visible('related')},
		{field: 'amount', title: '<?= lang('pv_transaction_history.amount') ?>', visible: bt.visible('amount')},
		{field: 'created_at', title: '<?= lang('pv_transaction_history.created_at') ?>', sortable: true, visible: bt.visible('created_at')},
		{field: 'data', title: '<?= lang('pv_transaction_history.data') ?>', visible: bt.visible('data')},
		{
			field: '__operation__',
			title: '<?=lang('app.operation')?>',
			visible: bt.visible('__operation__'),
			formatter: function () {
				return '<button type="button" class="btn btn-outline-danger px-1 py-0 del-btn"><i class="mdi mdi-window-close me-1"></i><?=lang('app.delete')?></button>';
			},
			events: {
				'click .del-btn': function (event, value, row, index) {
					//删除
					event.stopPropagation();
					delete_record(row.id);
				}
			}
		}
	];

	let options = {
		columns,
		url: '<?=admin_uri('transaction-history/get-data')?>',
		search: true,
		pagination: bt.pagination(),
		pageSize: bt.page_size(),
		locale: '<?=phpvod::$app->language->get_format_language('{lang}-{TAG}')?>',
		onColumnSwitch: function (column, checked) {
			bt.save_hidden_column(column, checked);
		},
		onPageChange: function (number, size) {
			bt.save_page_size(size);
		},
		onTogglePagination: function (status) {
			bt.save_pagination(status);
		},
		queryParams: function (params) {
			//sort
			if (params.sort === undefined) {
				params.sort = 'id';
				params.order = 'desc';
			}
			return params;
		}
	}

	$('#bootstrap-table').bootstrapTable({
		...default_options,
		...options
	});

	function batch_delete_record() {
		let select = $('#bootstrap-table').bootstrapTable('getSelections');
		if (select.length === 0) {
			layer.msg("<?=lang('app.no_object_is_selected')?>");
		} else {
			let id = $.map(select, function (row) {
				return row.id;
			});
			delete_record(id); //id is array
		}
	}

	function delete_record(id) {
		layer.confirm("<?=lang('app.confirm_deletion')?>", {
			icon: 3,
			title: "<?=lang('app.message')?>",
			btn: ['<?=lang('app.delete')?>', '<?=lang('app.cancel')?>']
		}, function (index) {
			$.post("<?= admin_uri('transaction-history/delete') ?>", {id: id}, function (r) {
				if (r.id === 1) {
					$('#bootstrap-table').bootstrapTable('refresh');
				} else if (r.hasOwnProperty('msg')) {
					layer.msg(r.msg);
				} else {
					layer.msg('<?=lang('app.unknown_error')?>');
				}
			});
			layer.close(index);
		});
	}
</script>
<?php $this->end_section(); ?>
