<?php

namespace phpvod\widget;

use venus\language\language;

class admin_role_permission
{
	public static ?admin_role_permission $instance = null;
	private array $select_dataid = [];

	private function __construct()
	{
	}

	public static function get_instance(): ?admin_role_permission
	{
		if (is_null(self::$instance)) {
			self::$instance = new self();
		}
		return self::$instance;
	}

	public function __clone()
	{
		die('Clone is not allowed.' . E_USER_ERROR);
	}

	/**
	 * 生成设置权限的HTML代码块
	 * @param string $role_permissions 角色权限集，-1表示拥有所有权限
	 * @return string
	 */
	public function index(string $role_permissions = ''): string
	{
		helper('string');
		if ($role_permissions == '-1') {
			return '<label class="form-check-label">' . lang('admin.role_have_all_permissions') . '</label>';
		}
		$html = '
				<div class="table-responsive">
					<table class="table table-sm">
						<thead>
						<tr>
							<th>
								<label class="form-check-label">
									<input name="checkbox" type="checkbox" id="check-all" class="form-check-input me-1">
									<span> ' . lang('app.check_all') . '</span>
								</label>
							</th>
						</tr>
						</thead>
						<tbody>
				';

		//加载所有模块语言文件
		\phpvod::$app->language->load_file('permission', language::ADDITIONAL_ALL_MODULE_LANGUAGE);

		$permissions = include CONFIG_PATH . 'permission/admin_role.php';

		//加载所有模块权限
		$modules = \phpvod::$app->module->get_modules();
		foreach ($modules as $module) {
			$file = MODULE_PATH . $module['directory'] . '/config/permission/admin_role.php';
			if (is_file($file)) {
				$module_permissions = include $file;
				$permissions = array_merge($permissions, $module_permissions);
			}
		}

		$html .= $this->make($permissions, $role_permissions);
		$html .= '</tbody></table></div>';
		return $html;
	}

	/**
	 * 生成初始化权限设置的js代码
	 * @return string
	 */
	public function init(): string
	{
		$js = '';
		foreach ($this->select_dataid as $dataid) {
			$js .= '$("input[dataid=' . $dataid . ']").click();';
		}
		return $js;
	}

	private function make(array $permissions, string $role_permissions, int $level = 1, string $id_pre = 'id'): string
	{
		$html = $html_route = '';
		$indent_style = 'padding-left:' . $level * 30 . 'px;';
		$group_style = 'background-color:rgba(0,0,0,0.05);';
		$id = 1;
		$template = '
			<label class="form-check-label me-2">
				<input{name} type="checkbox" class="form-check-input me-1{input_class_name}" dataid="{dataid}"{value}>
				<span> {label}</span>
			</label>
		';
		foreach ($permissions as $label => $route) {
			if (!is_array($route)) {
				$html_route .= strtr($template, [
					'{input_class_name}' => ' checkbox-child',
					'{name}' => ' name="permissions[]"',
					'{value}' => " value=\"$route\"",
					'{dataid}' => $id_pre . '-' . $id,
					'{label}' => lang('permission.' . $label),
				]);
				if (in_string($route, $role_permissions)) {
					$this->select_dataid[] = $id_pre . '-' . $id;
				}
			} else {
				if (!empty($html_route)) {
					$html .= "<tr><td style=\"$indent_style\">" . $html_route . '</td></tr>';
					$html_route = '';
				}
				$html_group = strtr($template, [
					'{input_class_name}' => $level == 1 ? ' checkbox-parent' : ' checkbox-parent checkbox-child',
					'{name}' => '',
					'{value}' => '',
					'{dataid}' => $id_pre . '-' . $id,
					'{label}' => lang('permission.' . $label),
				]);
				$html .= "<tr><td style=\"$indent_style $group_style\">" . $html_group . '</td></tr>';
				$html .= $this->make($route, $role_permissions, $level + 1, $id_pre . '-' . $id);
			}
			$id++;
		}

		if (!empty($html_route)) {
			$html .= "<tr><td style=\"$indent_style\">" . $html_route . '</td></tr>';
		}

		return $html;
	}
}
