<?php

namespace phpvod\widget\background\class;

use phpvod\widget\background\background;
use venus\view\event;

class bing implements background
{
	protected string $bing_gateway = 'https://cn.bing.com/HPImageArchive.aspx?format=js&idx=0&n=8&mkt=zh-CN';
	protected array $images = [];
	protected int $index = 0;

	public function __construct()
	{
		$result = @file_get_contents($this->bing_gateway);
		if ($result !== false) {
			$json = json_decode($result, true);
			if (is_array($json['images'])) {
				$this->images = $json['images'];
				//event
				\phpvod::$app->event->on(event::EVENT_VIEW_HEAD, [$this, 'import_style']);
				\phpvod::$app->event->on(event::EVENT_VIEW_BEGIN_BODY, [$this, 'show_message']);
			}
		}
	}

	public function get_background(): ?string
	{
		$image = $this->get_image();
		return isset($image['url']) ? 'url(https://cn.bing.com' . $image['url'] . ')' : null;
	}

	/**
	 * set_index
	 * @param int $index 图片索引(0-7)，如果小于0或大于7，则随机获取索引值。
	 * @return $this
	 */
	public function set_index(int $index): bing
	{
		if ($index < 0 || $index > 7) {

			try {
				$index = random_int(0, 7);
			} catch (\Exception $e) {
				$index = 0;
			}

		}
		$this->index = $index;
		return $this;
	}

	/**
	 * @return array
	 */
	public function get_image(): array
	{
		return $this->images[$this->index] ?? [];
	}

	public function import_style(): void
	{
		$style = <<<EOT
		<style>
		.bing-message{background-color: rgba(5,5,5,.5); color: rgba(255,255,255,.8); padding: 15px; position: absolute; top: 20px; left: 20px;}
		.bing-message .title{font-size: 14px; font-weight: bold; margin: 0;}
		.bing-message .copyright{font-size: 12px; color: rgba(255,255,255,.6); margin: 10px 0 0 0;}
</style>
EOT;
		echo $style;
	}

	public function show_message(): void
	{
		$image_data = $this->get_image();
		echo '<div class="bing-message"><p class="title">' . $image_data['title'] . '</p><p class="copyright">' . $image_data['copyright'] . '</p></div>';
	}

}