<?php

namespace phpvod\widget\background\class;

use phpvod\widget\background\background;

class color implements background
{
	/**
	 * @var bool $linear_gradient 是否为渐变色
	 */
	private bool $linear_gradient = true;

	/**
	 * @var int $colors 渐变色颜色数量
	 */
	private int $colors = 6;

	/**
	 * @var int $deg 渐变角度
	 */
	private int $deg = 45;

	public function get_background(): ?string
	{
		if ($this->linear_gradient) {
			$colors = $this->get_random_color($this->colors);
			if (count($colors) === $this->colors) {
				$colors_implode = implode(',', $colors);
				return 'linear-gradient(' . $this->deg . 'deg,' . $colors_implode . ')';
			}
		} else {
			$colors = $this->get_random_color();
			if (isset($colors[0])) {
				return $colors[0];
			}
		}
		return null;
	}

	/**
	 * set_linear_gradient
	 * @param bool $linear_gradient
	 * @return color
	 */
	public function set_linear_gradient(bool $linear_gradient): color
	{
		$this->linear_gradient = $linear_gradient;
		return $this;
	}

	/**
	 * set_colors
	 * @param int $colors
	 * @return color
	 */
	public function set_colors(int $colors): color
	{
		$this->colors = $colors;
		return $this;
	}

	/**
	 * set_deg
	 * @param int $deg
	 * @return color
	 */
	public function set_deg(int $deg): color
	{
		if ($deg < 2) $deg = 2;
		$this->deg = $deg;
		return $this;
	}

	/**
	 * get_random_color
	 * @param int $color_num 颜色数量
	 * @return array
	 */
	private function get_random_color(int $color_num = 1): array
	{
		$result = [];

		for ($n = 0; $n < $color_num; $n++) {
			$c = '';
			for ($i = 0; $i < 3; $i++) {
				try {
					$c .= sprintf("%02X", random_int(0, 255));
				} catch (\Exception $e) {
					$c .= 'ff';
				}
			}
			$result[] = '#' . $c;
		}

		return $result;
	}
}