<?php

namespace phpvod\widget\form;

/**
 * Class form 单例
 * @package phpvod\widgets\form
 */
class form
{
	public static ?form $instance = null;
	public string $radio_template = '{input} {label}';
	public string $checkbox_template = '{input} {label}';
	public string $switch_template = '{input}';

	private function __construct()
	{
	}

	/**
	 * 获取实例
	 * @return static
	 */
	public static function get_instance(): static
	{
		if (is_null(self::$instance)) {
			$class = get_called_class();
			self::$instance = new $class();
		}
		return self::$instance;
	}

	/**
	 * __clone
	 * @throws \Exception
	 */
	public function __clone()
	{
		throw new \Exception('Clone is not allowed.');
	}

	/**
	 * input表单
	 * @param string $name
	 * @param string $type
	 * @param string $default_value
	 * @param array $options
	 * @return string
	 */
	public function input(string $name, string $type, string $default_value = '', array $options = []): string
	{
		$options_string = $this->get_options_string($options);
		return "<input name=\"$name\" type=\"$type\" value=\"$default_value\"$options_string />";
	}

	/**
	 * 多行文本
	 * @param string $name
	 * @param string $default_value
	 * @param array $options
	 * @return string
	 */
	public function textarea(string $name, string $default_value = '', array $options = []): string
	{
		$options_string = $this->get_options_string($options);
		return "<textarea name=\"$name\"$options_string>$default_value</textarea>";
	}

	/**
	 * 单选框
	 * @param string $name
	 * @param array $values 格式：[value => label]
	 * @param string|null $checked_value 默认选中的值
	 * @param array $options
	 * @return string
	 */
	public function radio_group(string $name, array $values, ?string $checked_value = null, array $options = []): string
	{
		$html = '';
		$id = $options['id'] ?? null;
		foreach ($values as $value => $label) {
			!is_null($id) && $options['id'] = $id . '-' . $value;
			$options_string = $this->get_options_string($options);
			$checked = !is_null($checked_value) && $value == $checked_value ? ' checked="checked"' : '';
			$input = '<input type="radio" name="' . $name . '" value="' . $value . '"' . $checked . $options_string . ' />';
			$html .= strtr($this->radio_template, ['{input}' => $input, '{label}' => $label]);
		}
		return $html;
	}

	/**
	 * 复选框
	 * @param string $name
	 * @param array $values 格式：[value => label]
	 * @param array|null $checked_values 默认选中的集(当value存在于check_values中即选中)
	 * @param array $options
	 * @return string
	 */
	public function checkbox_group(string $name, array $values, ?array $checked_values = null, array $options = []): string
	{
		$html = '';
		$id = $options['id'] ?? null;
		foreach ($values as $value => $label) {
			!is_null($id) && $options['id'] = $id . '-' . $value;
			$options_string = $this->get_options_string($options);
			$checked = is_array($checked_values) && in_array($value, $checked_values) ? ' checked="checked"' : '';
			$input = '<input type="checkbox" name="' . $name . '" value="' . $value . '"' . $checked . $options_string . ' />';
			$html .= strtr($this->checkbox_template, ['{input}' => $input, '{label}' => $label]);
		}
		return $html;
	}

	/**
	 * 开关
	 * @param bool $checked 是否选中
	 * @param array $options
	 * @return string
	 */
	public function switch(bool $checked = false, array $options = []): string
	{
		$html = '';
		$options_string = $this->get_options_string($options);
		$checked = $checked ? ' checked="checked"' : '';
		$input = '<input type="checkbox"' . $options_string . $checked . ' />';
		$html .= strtr($this->switch_template, ['{input}' => $input]);
		return $html;
	}

	/**
	 * 列表框
	 * @param string $name
	 * @param array $values
	 * @param array|string|int|null $selected_value 默认选中的值，array表示选中的多个值
	 * @param array $options
	 * @return string
	 */
	public function select(string $name, array $values, array|string|int|null $selected_value = null, array $options = []): string
	{
		$options['name'] = $name;
		$options_string = $this->get_options_string($options);

		if (is_null($selected_value)) {
			$selected_value = [];
		} elseif (is_string($selected_value) || is_int($selected_value)) {
			$selected_value = [$selected_value];
		}

		$html = '<select' . $options_string . '>';
		foreach ($values as $value => $label) {
			$selected = in_array($value, $selected_value) ? ' selected="selected"' : '';
			$html .= '<option value="' . $value . '"' . $selected . '>' . $label . '</option>';
		}
		$html .= '</select>';
		return $html;
	}

	private function get_options_string(array $options): string
	{
		$options_string = '';
		foreach ($options as $name => $value) {
			$options_string .= ' ' . $name . '="' . $value . '"';
		}
		return $options_string;
	}
}
