<?php

namespace phpvod\widget\member_center_list;

use venus\language\language;

class member_center_list
{
	public static ?member_center_list $instance = null;
	private string $template = 'default';
	private array $items = [];
	private ?string $active_item = null;

	private function __construct()
	{
		\phpvod::$app->language->load_file('member_center_list', language::ADDITIONAL_ALL_MODULE_LANGUAGE);

		$files = [
			CONFIG_PATH . 'config/member_center_list.php',
		];

		$modules = \phpvod::$app->module->get_modules();
		foreach ($modules as $module) {
			if ($module['status'] != '1') continue;
			$file = MODULE_PATH . $module['directory'] . '/config/config/member_center_list.php';
			if (is_file($file)) {
				$files[] = $file;
			}
		}

		foreach ($files as $file) {
			$config = include $file;
			$this->items = array_merge($this->items, $config);
		}
	}

	private function __clone()
	{
	}

	public static function get_instance(): ?member_center_list
	{
		if (is_null(self::$instance)) {
			self::$instance = new member_center_list();
		}
		return self::$instance;
	}

	/**
	 * 设置模板
	 * @param string $template
	 * @return member_center_list
	 */
	public function set_template(string $template): member_center_list
	{
		$this->template = $template;
		return $this;
	}

	/**
	 * 设置当前列表项
	 * @param string $active_item
	 * @return member_center_list
	 */
	public function set_active_item(string $active_item): member_center_list
	{
		$this->active_item = $active_item;
		return $this;
	}

	/**
	 * 渲染
	 * @return string
	 * @throws \Exception
	 */
	public function render(): string
	{
		$view_file = __DIR__ . '/view/' . $this->template . '.php';

		if (!is_file($view_file)) {
			throw new \Exception('View does not exist (' . $view_file . ')');
		}

		ob_start();
		include $view_file;
		return (string)ob_get_clean();
	}

	/**
	 * 渲染
	 * @return string
	 * @throws \Exception
	 */
	public function __toString(): string
	{
		return $this->render();
	}
}