<?php

namespace phpvod\widget;

use phpvod\widget\form\admin_form;

class member_group_permission
{
	public static ?member_group_permission $instance = null;

	private string $permission_template = '
		<div class="row pb-1">
			<label class="col-md-4 col-form-label text-md-end">{label}</label>
			<div class="col-md-8">{input}</div>
		</div>
	';

	private string $card_template = '
	<div class="mb-3">
		<div class="border-bottom fw-bold py-1 px-3">{header}</div>
		<div class="py-1">{body}</div>
	</div>
	';

	private function __construct()
	{
	}

	public static function get_instance(): ?member_group_permission
	{
		if (is_null(self::$instance)) {
			self::$instance = new self();
		}
		return self::$instance;
	}

	public function __clone()
	{
		die('Clone is not allowed.' . E_USER_ERROR);
	}

	/**
	 * 生成设置权限的HTML代码块
	 * @param array $member_group_permissions 会员组权限集
	 * @return string
	 */
	public function index(array $member_group_permissions): string
	{
		$html = '';

		//加载所有模块语言文件
		\phpvod::$app->language->load_file('permission', \venus\language\language::ADDITIONAL_ALL_MODULE_LANGUAGE);

		$list = [];

		//system permission file
		$permissions_file = CONFIG_PATH . 'permission/member_group.php';
		is_file($permissions_file) && $list[] = ['title' => 'System', 'file' => $permissions_file];

		//module permission file
		$modules = \phpvod::$app->module->get_modules();
		foreach ($modules as $module) {
			$permissions_file = MODULE_PATH . $module['directory'] . '/config/permission/member_group.php';
			if (is_file($permissions_file)) {
				$list[] = ['title' => $module['name'], 'file' => $permissions_file];
			}
		}

		foreach ($list as $item) {
			$permissions = include $item['file'];
			if (is_array($permissions)) {
				$permissions_html = $this->make($permissions, $member_group_permissions);
				!empty($permissions_html) && $html .= strtr($this->card_template, ['{header}' => $item['title'], '{body}' => $permissions_html]);
			}
		}

		return empty($html) ? '<label class="form-check-label">' . lang('admin.no_permissions_to_set') . '</label>' : $html;
	}

	/**
	 * 生成权限代码
	 * @param array $permissions 配置文件中定义的权限
	 * @param array $member_group_permissions 会员组设置的权限
	 * @return string
	 */
	private function make(array $permissions, array $member_group_permissions): string
	{
		$form = admin_form::get_instance();
		$html = '';

		foreach ($permissions as $name => $config) {
			$label = lang('permission.' . $config['label']);
			$input = '';

			//radio
			if ($config['type'] == 'radio') {
				$input = $form->radio_group("permissions[{$name}]", array_map(function ($n) {
					return lang('permission.' . $n);
				}, $config['options']), $member_group_permissions[$name] ?? $config['default'], ['class' => 'form-check-input']);
			} //select
			elseif ($config['type'] == 'select') {
				$input = $form->select("permissions[{$name}]", array_map(function ($n) {
					return lang('permission.' . $n);
				}, $config['options']), $member_group_permissions[$name] ?? $config['default'], ['class' => 'form-select']);
			} //checkbox
			elseif ($config['type'] == 'checkbox') {
				$input = $form->checkbox_group("permissions[{$name}][]", array_map(function ($n) {
					return lang('permission.' . $n);
				}, $config['options']), $member_group_permissions[$name] ?? $config['default'], ['class' => 'form-check-input']);
			} //text
			elseif ($config['type'] == 'text') {
				$value = $member_group_permissions[$name] ?? $config['default'];
				$input = "<input type=\"text\" class=\"form-control\" name=\"permissions[{$name}]\" value=\"$value\" />";
			}

			if (!empty($input)) {
				$html .= strtr($this->permission_template, ['{label}' => $label, '{input}' => $input]);
			}
		}

		return $html;
	}
}
