class pagination {
	num_placeholder = '(:num)';
	total_items = 0;
	items = 10;
	current_page = 1;
	url_pattern = '';
	total_pages = 0;
	page_items = 9;

	constructor(total_items, items_per_page, current_page, url_pattern) {
		this.total_items = total_items;
		this.items_per_page = items_per_page;
		this.current_page = current_page;
		this.url_pattern = url_pattern;
		this.total_pages = Math.ceil(this.total_items / this.items_per_page);
	}

	has_prev() {
		return this.current_page > 1;
	}

	has_next() {
		return this.current_page < this.total_pages;
	}

	get_page_url(page_number) {
		return this.url_pattern.replace(this.num_placeholder, page_number);
	}

	get_next_url() {
		return this.has_next() ? this.get_page_url(this.current_page + 1) : null;
	}

	get_prev_url() {
		return this.has_prev() ? this.get_page_url(this.current_page - 1) : null;
	}

	get_page_data() {
		let pages = [];

		if (this.total_pages <= 1) {
			return [];
		}

		if (this.total_pages <= this.page_items) {
			for (let i = 1; i <= this.total_pages; i++) {
				pages.push({
					num: i, url: this.get_page_url(i), is_current: i === this.current_page
				});
			}
		} else {
			// 确定以当前页面为中心的显示范围
			let num_adjacents = Math.floor((this.page_items - 3) / 2);

			let sliding_start = this.current_page - num_adjacents;
			if (this.current_page + num_adjacents > this.total_pages) {
				sliding_start = this.total_pages - this.page_items + 2;
			}
			if (sliding_start < 2) sliding_start = 2;

			let sliding_end = sliding_start + this.page_items - 3;
			if (sliding_end >= this.total_pages) sliding_end = this.total_pages - 1;

			// 构建页面列表
			pages.push({num: 1, url: this.get_page_url(1), is_current: this.current_page === 1});
			if (sliding_start > 2) {
				pages.push({num: '...', url: null, is_current: false});
			}
			for (let i = sliding_start; i <= sliding_end; i++) {
				pages.push({num: i, url: this.get_page_url(i), is_current: i === this.current_page});
			}
			if (sliding_end < this.total_pages - 1) {
				pages.push({num: '...', url: null, is_current: false});
			}
			pages.push({
				num: this.total_pages,
				url: this.get_page_url(this.total_pages),
				is_current: this.total_pages === this.current_page
			});
		}

		return pages;
	}

	render_bootstrap(container_id) {
		let html = '';
		if (this.has_prev()) {
			html += '<li class="page-item"><a class="page-link" href="' + this.get_prev_url() + '">&laquo;</a></li>';
		}
		for (let page of this.get_page_data()) {
			if (page.url != null) {
				let active = page.is_current ? ' active' : '';
				html += `<li class="page-item${active}"><a class="page-link" href="${page.is_current ? 'javascript:;' : page.url}">${page.num}</a></li>`;
			} else {
				html += `<li class="page-item disabled"><span class="page-link">${page.num}</span></li>`;
			}
		}
		if (this.has_next()) {
			html += '<li class="page-item"><a class="page-link" href="' + this.get_next_url() + '">&raquo;</a></li>';
		}

		if (html !== '') {
			html = '<ul class="pagination justify-content-end">' + html + '</ul>';
			$("#" + container_id).html(html);
		}
	}
}
