<?php

namespace phpvod\widget;
/**
 * Class toastr
 * <p>此类需要注册toastr_asset与jquery_asset</p>
 * @package phpvod\widget
 */
class toastr
{
	public const SESSION_NAME = 'toastr';
	public const TYPE_SUCCESS = 'success';
	public const TYPE_INFO = 'info';
	public const TYPE_WARNING = 'warning';
	public const TYPE_ERROR = 'error';
	public static array $options = [
		'closeButton' => true,
		'debug' => false,
		'newestOnTop' => false,
		'progressBar' => true,
		'positionClass' => 'toast-top-right',
		'preventDuplicates' => false,
		'onclick' => null,
		'showDuration' => '300',
		'hideDuration' => '1000',
		'timeOut' => '3000',
		'extendedTimeOut' => '1000',
		'showEasing' => 'swing',
		'hideEasing' => 'linear',
		'showMethod' => 'fadeIn',
		'hideMethod' => 'fadeOut'
	];

	/**
	 * 设置数据
	 * @param array $data
	 * @return void
	 * @throws \Exception
	 */
	public static function set_data(array $data): void
	{
		session()->set_flash_data(self::SESSION_NAME, $data);
	}

	/**
	 * 获取数据
	 * @return array|null
	 * @throws \Exception
	 */
	public static function get_data(): ?array
	{
		return session()->get_flash_data(self::SESSION_NAME);
	}

	/**
	 * 新增数据
	 * @param array $data
	 * @return void
	 * @throws \Exception
	 */
	public static function add_data(array $data): void
	{
		$current_data = self::get_data();
		if (is_array($current_data)) {
			$data = array_merge($current_data, $data);
		}
		self::set_data($data);
	}

	/**
	 * 清除数据
	 * @return void
	 * @throws \Exception
	 */
	public static function clear_data(): void
	{
		session()->remove(self::SESSION_NAME)->remove_flash_mark(self::SESSION_NAME);
	}

	/**
	 * 显示TOASTR
	 * @param array $data 显示数据，为空时从session中获取。
	 * <p>格式一：['success' => 'success message', 'error' => 'error message', ...]</p>
	 * <p>格式二：['success' => ['field' => 'message', ...], 'error' =>['field' => 'message', ...], ...]</p>
	 * <p>格式二：['success' => ['message', ...], 'error' =>['message', ...], ...]</p>
	 * @param array $options toastr参数
	 * @return string
	 * @throws \Exception
	 */
	public static function show(array $data = [], array $options = []): string
	{
		$js = '';
		if (empty($data)) {
			$data = self::get_data();
			self::clear_data();
		}

		if (!empty($data) && is_array($data)) {
			$options = array_merge(self::$options, $options);
			$options_json = formatter($options);

			$js = '<script type="text/javascript">' .
				'toastr.options = ' . $options_json . ';' .
				'$(document).ready(function(){';
			foreach ($data as $toastr_type => $messages) {
				if (is_string($messages)) {
					$messages = addslashes($messages);
					$js .= "toastr.$toastr_type('$messages');";
				} elseif (is_array($messages)) {
					foreach ($messages as $field => $message) {
						$message = addslashes($message);
						$js .= "toastr.$toastr_type('$message');";
					}
				}
			}
			$js .= '});</script>';
		}
		return $js;
	}
}