<?php

namespace venus\autoloader;

use config\autoload;

class autoloader
{
	protected array $psr4 = [];

	protected array $class_map = [];

	protected array $files = [];

	/**
	 * construct
	 * @param autoload $config
	 */
	public function __construct(autoload $config)
	{
		isset($config->psr4) && $this->psr4 = $config->psr4;
		isset($config->class_map) && $this->class_map = $config->class_map;
		isset($config->files) && $this->files = $config->files;
	}

	public function register(): void
	{
		spl_autoload_register([$this, 'load_psr4'], true, true);
		spl_autoload_register([$this, 'load_class_map'], true, true);

		//files
		foreach ($this->files as $file) {
			if (is_file($file)) {
				include_once $file;
			}
		}
	}

	public function add_psr4($namespace, string $path = null): void
	{
		if (is_array($namespace)) {
			$this->psr4 = array_merge($this->psr4, $namespace);
		} elseif (is_string($namespace) && !is_null($path)) {
			$this->psr4[$namespace] = $path;
		}
	}

	public function add_class_map(string $class, string $file): void
	{
		$this->class_map[$class] = $file;
	}

	public function load_psr4(string $class): bool
	{
		if (strpos($class, '\\') === false) {
			return false;
		}
		foreach ($this->psr4 as $namespace => $directory) {
			$directory = rtrim($directory, '\\/');
			if (strpos($class, $namespace) === 0) {
				$file = $directory . str_replace('\\', DIRECTORY_SEPARATOR, substr($class, strlen($namespace))) . '.php';
				if (is_file($file)) {
					include_once $file;
					return true;
				}
			}
		}
		return false;
	}

	public function load_class_map($class): bool
	{
		$file = $this->class_map[$class] ?? '';
		if (is_string($file) && $file !== '' && is_file($file)) {
			include_once $file;
			return true;
		}
		return false;
	}
}