<?php

namespace venus\base;

class config
{
	/**
	 * 通过数组初始化对象属性
	 * @param mixed $settings 关联数组
	 * @param ?string $parent_attribute 父属性名称，该参数为null时，配置文件返回的关联数组映射为对象属性，否则配置文件返回的关联数组作为该属性的值。
	 * @param array $attributes 要初始化的对象属性列表
	 * <ul>
	 * <li>该参数如为空，则配置文件数组中的所有元素均映射为对象的属性或父属性的值</li>
	 * <li>该参数不为空时，则只映射指定的属性。格式：['属性名称', '属性名称' => '配置文件数组键名' ... ]</li>
	 * </ul>
	 * @return void
	 */
	protected function init_attributes(mixed $settings, ?string $parent_attribute = null, array $attributes = []): void
	{
		if (!is_array($settings) || empty($settings)) {
			return;
		}

		if (empty($attributes)) {
			if (is_null($parent_attribute)) {
				foreach ($settings as $key => $value) {
					if (is_string($key)) {
						$this->$key = $value;
					}
				}
			} else {
				$this->$parent_attribute = $settings;
			}
		} else {
			foreach ($attributes as $key => $value) {
				if (!array_key_exists($value, $settings)) {
					continue;
				}

				if (is_int($key)) {
					if (is_null($parent_attribute))
						$this->$value = $settings[$value];
					else
						is_array($this->$parent_attribute) && $this->$parent_attribute[$value] = $settings[$value];
				} elseif (is_string($key)) {
					if (is_null($parent_attribute))
						$this->$key = $settings[$value];
					else
						is_array($this->$parent_attribute) && $this->$parent_attribute = array_merge($this->$parent_attribute, [$key => $settings[$value]]);
				}
			}
		}
	}

	/**
	 * 通过配置文件初始化对象属性
	 * @param string $file 配置文件路径，该配置文件返回关联数组。
	 * @param ?string $parent_attribute 父属性名称，该参数为null时，配置文件返回的关联数组映射为对象属性，否则配置文件返回的关联数组作为该属性的值。
	 * @param array $attributes 要初始化的对象属性列表
	 * <ul>
	 * <li>该参数如为空，则配置文件数组中的所有元素均映射为对象的属性或父属性的值</li>
	 * <li>该参数不为空时，则只映射指定的属性。格式：['属性名称', '属性名称' => '配置文件数组键名' ... ]</li>
	 * </ul>
	 * @return void
	 * @throws \Exception
	 * @see init_attributes
	 */
	protected function init_attributes_from_file(string $file, ?string $parent_attribute = null, array $attributes = []): void
	{
		if (is_file($file)) {
			$settings = include $file;
			$this->init_attributes($settings, $parent_attribute, $attributes);
		}
	}
}