<?php

namespace venus\cache;

use venus\base\component;
use venus\di\container;

class cache extends component
{
	private \config\cache\cache $config;
	private ?handler $handler = null;

	/**
	 * 构造函数
	 * @param \config\cache\cache $config
	 */
	public function __construct(\config\cache\cache $config)
	{
		$this->config = $config;
	}

	public function get_config(): \config\cache\cache
	{
		return $this->config;
	}

	/**
	 * 获取缓存处理器
	 * @throws \Exception
	 */
	public function get_handler(): handler
	{
		if (!is_null($this->handler)) {
			return $this->handler;
		}

		if (!isset($this->config->handler_list) || !is_array($this->config->handler_list)) {
			throw new \Exception('Cache config must have an array of $handler_list.');
		}

		if (!isset($this->config->handler)) {
			throw new \Exception('Cache config must have a handler set.');
		}

		if (!array_key_exists($this->config->handler, $this->config->handler_list)) {
			throw new \Exception('Cache config has an invalid handler specified.');
		}

		/**
		 * @var handler $handler
		 */
		$handler = container::get($this->config->handler_list[$this->config->handler]);

		if (!$handler instanceof handler) {
			throw new \Exception('Invalid cache handler');
		}

		if (!$handler->is_supported()) {
			throw new \Exception('Cache handler is not supported');
		}

		$handler->init();
		$this->handler = $handler;
		return $this->handler;
	}
}