<?php

namespace venus\cache;

use venus\cache\depend\base_depend;

interface handler
{
	/**
	 * 初始化
	 * @return void
	 */
	public function init(): void;

	/**
	 * 读缓存
	 * @param string $key 缓存名称
	 * @return mixed 如果key不存在，则返回null，否则返回与key相关的值
	 */
	public function get(string $key): mixed;

	/**
	 * 写缓存
	 * @param string $key 缓存名称
	 * @param mixed $value 缓存数据
	 * @param int $ttl 缓存生存期，单位:秒，0表示则永不过期
	 * @param base_depend|null $depend 缓存依赖
	 * @return bool
	 */
	public function set(string $key, mixed $value, int $ttl = 0, ?base_depend $depend = null): bool;

	/**
	 * 删除缓存
	 * @param string $key 缓存名称
	 * @return bool
	 */
	public function delete(string $key): bool;

	/**
	 * 清空缓存
	 * @return bool
	 */
	public function clean(): bool;

	/**
	 * 系统是否支持该缓存处理器
	 * @return bool
	 */
	public function is_supported(): bool;
}