<?php

namespace venus\cache\handler;

use venus\cache\depend\base_depend;

class file extends base
{
	protected \config\cache\file $config;

	/**
	 * 构造函数
	 * @param \config\cache\file $config
	 */
	public function __construct(\config\cache\file $config)
	{
		$this->config = $config;
		helper('file_system');
	}

	public function init(): void
	{
	}

	public function get(string $key): mixed
	{
		$key = $this->validate_key($key);
		$data = $this->get_item($key);
		return is_array($data) ? $data['value'] : null;
	}

	public function set(string $key, mixed $value, int $ttl = 0, ?base_depend $depend = null): bool
	{
		$key = $this->validate_key($key);

		if (!is_null($depend)) {
			$depend->evaluate_depend($this);
		}

		$contents = [
			'value' => $value,
			'expire' => $ttl === 0 ? $ttl : TIMESTAMP + $ttl,
			'depend' => $depend
		];

		$file = $this->get_file_path($key);
		$data = serialize($contents);

		if (write_file($file, $data)) {
			@chmod($file, $this->config->mode);
			return true;
		}

		return false;
	}

	public function delete(string $key): bool
	{
		$key = $this->validate_key($key);
		$file = $this->get_file_path($key);
		return is_file($file) && @remove_file($file);
	}

	public function clean(): bool
	{
		if (!($handle = opendir($this->config->path))) {
			return false;
		}

		while (($filename = readdir($handle)) !== false) {
			if ($filename === '.' || $filename === '..') {
				continue;
			}
			$file = $this->get_file_path($filename);
			is_file($file) && @remove_file($file);
		}

		closedir($handle);
		return true;
	}

	public function is_supported(): bool
	{
		return is_writable($this->config->path);
	}

	/**
	 * 获取缓存数据
	 * @param string $key
	 * @return array|false
	 */
	protected function get_item(string $key): array|false
	{
		$file = $this->get_file_path($key);
		if (!is_file($file)) {
			return false;
		}

		$data = unserialize(file_get_contents($file));
		if (!is_array($data) ||
			!array_key_exists('value', $data) ||
			!array_key_exists('expire', $data) ||
			!array_key_exists('depend', $data)) {
			return false;
		}

		if (($data['expire'] > 0 && TIMESTAMP > $data['expire']) || ($data['depend'] instanceof base_depend && $data['depend']->is_changed($this))) {
			is_file($file) && @remove_file($file);
			return false;
		}

		return $data;
	}

	/**
	 * 获取文件路径
	 * @param string $key
	 * @return string
	 */
	protected function get_file_path(string $key): string
	{
		return rtrim($this->config->path, '\\/') . DIRECTORY_SEPARATOR . $key;
	}
}