<?php

namespace venus\cache\handler;

use venus\cache\depend\base_depend;

class memcached extends base
{
	protected \config\cache\memcached $config;
	protected \Memcached|\Memcache $memcached;

	/**
	 * 构造函数
	 * @param \config\cache\memcached $config
	 */
	public function __construct(\config\cache\memcached $config)
	{
		$this->config = $config;
	}

	/**
	 * 析构函数
	 */
	public function __destruct()
	{
		if (isset($this->memcached)) {
			if ($this->memcached instanceof \Memcached) {
				$this->memcached->quit();
			} elseif ($this->memcached instanceof \Memcache) {
				$this->memcached->close();
			}
		}
	}

	/**
	 * 初始化
	 * @return void
	 * @throws \Exception
	 */
	public function init(): void
	{
		if (class_exists(\Memcached::class)) {
			$this->memcached = new \Memcached();
			if ($this->config->raw) {
				$this->memcached->setOption(\Memcached::OPT_BINARY_PROTOCOL, true); //使用二进制协议
			}
			foreach ($this->config->servers as $server) {
				$this->memcached->addServer($server['host'], $server['port'], $server['weight']);
			}
		} elseif (class_exists(\Memcache::class)) {
			$this->memcached = new \Memcache();
			foreach ($this->config->servers as $server) {
				$this->memcached->addServer($server['host'], $server['port'], true, $server['weight']);
			}
		} else {
			throw new \Exception('Cache: Not support Memcache(d) extension.');
		}
	}

	public function get(string $key): mixed
	{
		$data = $this->memcached->get($this->validate_key($key));

		if ($this->memcached instanceof \Memcached && $this->memcached->getResultCode() === \Memcached::RES_NOTFOUND) {
			return null;
		} elseif ($this->memcached instanceof \Memcache && $data === false) {
			return null;
		}

		$data = unserialize((string)$data);
		if (!is_array($data) ||
			!array_key_exists('value', $data) ||
			!array_key_exists('depend', $data)) {
			return null;
		}

		if ($data['depend'] instanceof base_depend && $data['depend']->is_changed($this)) {
			$this->delete($key);
			return null;
		}

		return $data['value'];
	}

	public function set(string $key, mixed $value, int $ttl = 0, ?base_depend $depend = null): bool
	{
		$key = $this->validate_key($key);
		$expire = $ttl === 0 ? $ttl : TIMESTAMP + $ttl;

		if (!is_null($depend)) {
			$depend->evaluate_depend($this);
		}

		$data = serialize([
			'value' => $value,
			'depend' => $depend
		]);

		if ($this->memcached instanceof \Memcached) {
			return $this->memcached->set($key, $data, $expire);
		}

		if ($this->memcached instanceof \Memcache) {
			return $this->memcached->set($key, $data, 0, $expire);
		}

		return false;
	}

	public function delete(string $key): bool
	{
		$key = $this->validate_key($key);
		return $this->memcached->delete($key);
	}

	public function clean(): bool
	{
		return $this->memcached->flush();
	}

	public function is_supported(): bool
	{
		return extension_loaded('memcached') || extension_loaded('memcache');
	}
}