<?php

namespace venus\cache\handler;

use venus\cache\depend\base_depend;

class wincache extends base
{

	public function init(): void
	{
	}

	public function get(string $key): mixed
	{
		$data = wincache_ucache_get($this->validate_key($key), $success);

		if($success !== true) {
			return null;
		}

		$data = unserialize((string)$data);
		if (!is_array($data) ||
			!array_key_exists('value', $data) ||
			!array_key_exists('depend', $data)) {
			return null;
		}

		if ($data['depend'] instanceof base_depend && $data['depend']->is_changed($this)) {
			$this->delete($key);
			return null;
		}

		return $data['value'];
	}

	public function set(string $key, mixed $value, int $ttl = 0, ?base_depend $depend = null): bool
	{
		$key = $this->validate_key($key);

		if (!is_null($depend)) {
			$depend->evaluate_depend($this);
		}

		$data = serialize([
			'value' => $value,
			'depend' => $depend
		]);

		return wincache_ucache_set($key, $data, $ttl);
	}

	public function delete(string $key): bool
	{
		$key = $this->validate_key($key);
		return wincache_ucache_delete($key);
	}

	public function clean(): bool
	{
		return wincache_ucache_clear();
	}

	public function is_supported(): bool
	{
		return extension_loaded('wincache') && ini_get('wincache.ucenabled');
	}
}