<?php

namespace venus\debug;

class timer
{
	protected array $timers = [];

	/**
	 * 开始计时
	 * @param string $name 计时器名称
	 * @return $this
	 */
	public function start(string $name): timer
	{
		$this->timers[strtolower($name)] = [
			'start' => microtime(true),
			'end' => null,
		];
		return $this;
	}

	/**
	 * 停止计时
	 * @param string $name 计时器名称
	 * @return $this
	 * @throws \Exception
	 */
	public function stop(string $name): timer
	{
		$name = strtolower($name);
		if (empty($this->timers[$name])) {
			throw new \Exception('Cannot stop timer: invalid name given.');
		}
		$this->timers[$name]['end'] = microtime(true);
		return $this;
	}

	/**
	 * 获取计时器持续时间
	 * @param string $name 计时器名称
	 * @param int $decimals 小数位数
	 * @return float|null 返回计时器持续的时间，计时器不存在时返回null
	 */
	public function get_elapsed_time(string $name, int $decimals = 4): ?float
	{
		$name = strtolower($name);
		if (empty($this->timers[$name])) {
			return null;
		}
		$timer = $this->timers[$name];
		if (empty($timer['end'])) {
			$timer['end'] = microtime(true);
		}
		return (float)number_format($timer['end'] - $timer['start'], $decimals, '.', '');
	}

	/**
	 * 获取所有计时器数据，并计算持续时间
	 * @param int $decimals 小数位数
	 */
	public function get_timers(int $decimals = 4): array
	{
		$timers = $this->timers;
		foreach ($timers as &$timer) {
			if (empty($timer['end'])) {
				$timer['end'] = microtime(true);
			}
			$timer['duration'] = (float)number_format($timer['end'] - $timer['start'], $decimals);
		}
		return $timers;
	}

	/**
	 * 检测计时器是否存在
	 * @param string $name
	 * @return bool
	 */
	public function has(string $name): bool
	{
		return array_key_exists(strtolower($name), $this->timers);
	}
}
