<?php

namespace venus\event;

use venus\base\component;

class event extends component
{
	protected \config\event $config;

	protected array $listeners = [];

	/**
	 * __construct
	 * @param \config\event $config
	 */
	public function __construct(\config\event $config)
	{
		$this->config = $config;
	}

	/**
	 * 初始化事件处理器
	 * @return $this
	 */
	public function init(): event
	{
		// APP
		$event_files = [
			APP_PATH . 'config/event_register.php'
		];

		// Module
		$modules = \venus::$app->module->get_modules();
		foreach ($modules as $module) {
			if ($module['status'] == '1' && !empty($module['directory'])) {
				$event_files[] = MODULE_PATH . $module['directory'] . '/config/event_register.php';
			}
		}

		// Custom
		$event_files = array_unique(array_merge($event_files, $this->config->event_files));

		foreach ($event_files as $event_file) {
			if (is_file($event_file)) {
				include $event_file;
			}
		}

		return $this;
	}

	/**
	 * 注册事件
	 * @param string $name 事件名
	 * @param callable $callback 事件处理程序
	 * @return event
	 */
	public function on(string $name, callable $callback): event
	{
		$this->listeners[$name][] = $callback;
		return $this;
	}

	/**
	 * 触发事件
	 * @param string $name
	 * @param ...$args
	 * @return bool
	 */
	public function trigger(string $name, ...$args): bool
	{
		if (isset($this->listeners[$name]) && is_array($this->listeners[$name])) {
			foreach ($this->listeners[$name] as $listener) {
				$result = $listener(...$args);
				if ($result === false) {
					return false;
				}
			}
		}
		return true;
	}

	/**
	 * 移除事件处理器
	 * @param string|null $name
	 * @return void
	 */
	public function remove_listeners(?string $name = null): void
	{
		if ($name !== null) {
			unset($this->listeners[$name]);
		} else {
			$this->listeners = [];
		}
	}
}