<?php

namespace venus\exception;

abstract class handler
{
	/**
	 * 将异常类映射至方法，针对不同的异常定义不同的处理方法
	 * 定义格式：[exceptionClassName => methodName]
	 * @var array $exception_map
	 */
	public array $exception_map = [];

	protected string $production_view = SYSTEM_PATH . 'exception/view/production.php';
	protected string $development_view = SYSTEM_PATH . 'exception/view/development.php';

	/**
	 * 默认异常处理器
	 * @param \Throwable $exception
	 */
	public function exception_handler(\Throwable $exception): void
	{
		if(ENV == 'dev') {
			include $this->development_view;
		} else {
			include $this->production_view;
		}
	}

	public function error_handler(int $err_no, string $err_str, string $err_file, int $err_line): bool
	{
		//如果函数返回 false，标准错误处理处理程序将会继续调用。
		return false;
	}

	public function shutdown_handler():void
	{
	}

	/**
	 * 编码 GBK 异常消息至 UTF-8 格式
	 * @param \Throwable $exception
	 * @return string
	 */
	protected function get_message(\Throwable $exception): string
	{
		$message = trim($exception->getMessage());

		if (empty($message))
			return $message;

		if (function_exists('mb_detect_encoding') && function_exists('mb_convert_encoding')) {
			$encode = mb_detect_encoding($message, ['UTF-8', 'CP936']);
			if ($encode == 'CP936') {
				$encode_string = mb_convert_encoding($message, 'UTF-8', $encode);
				$encode_string != false && $message = $encode_string;
			}
		}

		return $message;
	}
}