<?php

namespace venus\exception;

use config\exception;

class manager
{
	/**
	 * @var exception handler
	 */
	private exception $handler;

	/**
	 * manager constructor.
	 * @param exception $handler
	 */
	public function __construct(exception $handler)
	{
		$this->handler = $handler;
	}

	public function init(): void
	{
		set_exception_handler([$this, 'exception_handler']);
		set_error_handler([$this, 'error_handler'], E_ALL & ~E_NOTICE & ~E_STRICT & ~E_DEPRECATED);
		register_shutdown_function([$this, 'shutdown_handler']);
	}

	public function exception_handler(\Throwable $exception)
	{

		$exception_class = get_class($exception);
		$exception_map = $this->handler->exception_map;
		$handler_method = 'exception_handler';

		if (key_exists($exception_class, $exception_map)) {
			$method_name = $exception_map[$exception_class];
			is_callable([$this->handler, $method_name]) && $handler_method = $method_name;
		}

		call_user_func_array([$this->handler, $handler_method], [$exception]);
	}

	public function error_handler(int $err_no, string $err_str, string $err_file, int $err_line): bool
	{
		return $this->handler->error_handler($err_no, $err_str, $err_file, $err_line);
	}

	public function shutdown_handler()
	{
		$this->handler->shutdown_handler();
	}
}