<?php

namespace venus\filter;

use venus\base\component;
use venus\di\container;

class filter extends component
{
	private \config\filter $config;

	private array $filter_list = [];

	/**
	 * construct
	 * @throws \Exception
	 */
	public function __construct(\config\filter $config)
	{
		$this->config = $config;

		//create filter instance
		foreach ($this->config->filter as $key => $value) {
			if (is_int($key)) {
				$this->filter_list[$value] = container::get_instance($value);
			} else {
				$this->filter_list[$key] = container::get_instance($key, [$value]);
			}
		}
	}

	public function filter_exists(string $filter_class): bool
	{
		return array_key_exists($filter_class, $this->filter_list);
	}

	public function get_filter(string $filter_class): ?object
	{
		return array_key_exists($filter_class, $this->filter_list) ? $this->filter_list[$filter_class] : null;
	}

	/**
	 * 执行过滤器
	 * @param string $method 调用的方法名称(before/after)
	 * @return void
	 */
	public function run(string $method): void
	{
		foreach ($this->filter_list as $filter) {
			switch ($method) {
				case 'before':
					if ($filter instanceof before_interface) $filter->before();
					break;
				case 'after':
					if ($filter instanceof after_interface) $filter->after();
					break;
			}
		}
	}
}