<?php

namespace venus\format;

class format
{
	private array $formatters = [];

	private \config\format $config;

	public function __construct(\config\format $config)
	{
		$this->config = $config;
	}

	/**
	 * get formatter
	 * @param string $name
	 * @return formatter
	 * @throws \Exception
	 */
	public function get_formatter(string $name): formatter
	{
		if (isset($this->formatters[$name])) {
			return $this->formatters[$name];
		}

		if (!array_key_exists($name, $this->config->formatters)) {
			throw new \Exception("Formatter not found");
		}

		$formatter_config = $this->config->formatters[$name];
		if(is_string($formatter_config)) {
			$formatter_config = [$formatter_config];
		}

		$class_name = array_shift($formatter_config);
		$params = $formatter_config;

		if (!class_exists($class_name)) {
			throw new \Exception('Invalid class name');
		}

		$object = new $class_name($params);

		if (!$object instanceof formatter) {
			throw new \Exception('Invalid object');
		}

		$this->formatters[$name] = $object;
		return $object;
	}
}
