<?php
namespace venus\format;

use SimpleXMLElement;

/**
 * XML data formatter
 */
class xml_formatter extends abstract_formatter
{
	/**
	 * 格式化数据
	 *
	 * @param mixed $data
	 * @return false|string (XML string | false)
	 * @throws \Exception
	 */
    public function format(mixed $data): false|string
    {
        if (! extension_loaded('simplexml')) {
            throw new \Exception('simplexml extension is not enabled');
        }

        $options = $this->params[0] ?? 0;
        $output  = new SimpleXMLElement('<?xml version="1.0" encoding="UTF-8"?><response></response>', $options);

        $this->array_to_xml((array) $data, $output);
        return $output->asXML();
    }

	/**
	 * A recursive method to convert an array into a valid XML string.
	 *
	 * Written by CodexWorld. Received permission by email on Nov 24, 2016 to use this code.
	 *
	 * @see http://www.codexworld.com/convert-array-to-xml-in-php/
	 *
	 * @param array $data
	 * @param SimpleXMLElement $output
	 */
    protected function array_to_xml(array $data, SimpleXMLElement $output): void
    {
        foreach ($data as $key => $value) {
            $key = $this->normalize_xml_tag($key);

            if (is_array($value)) {
                $sub_node = $output->addChild("{$key}");
                $this->array_to_xml($value, $sub_node);
            } else {
                $output->addChild("{$key}", htmlspecialchars("{$value}"));
            }
        }
    }

    /**
     * Normalizes tags into the allowed by W3C.
     * Regex adopted from this StackOverflow answer.
     *
     * @param int|string $key
     *
     * @return string
     *
     * @see https://stackoverflow.com/questions/60001029/invalid-characters-in-xml-tag-name
     */
    protected function normalize_xml_tag(int|string $key): string
    {
        $start_char = 'A-Z_a-z' .
            '\\x{C0}-\\x{D6}\\x{D8}-\\x{F6}\\x{F8}-\\x{2FF}\\x{370}-\\x{37D}' .
            '\\x{37F}-\\x{1FFF}\\x{200C}-\\x{200D}\\x{2070}-\\x{218F}' .
            '\\x{2C00}-\\x{2FEF}\\x{3001}-\\x{D7FF}\\x{F900}-\\x{FDCF}' .
            '\\x{FDF0}-\\x{FFFD}\\x{10000}-\\x{EFFFF}';
        $valid_name = $start_char . '\\.\\d\\x{B7}\\x{300}-\\x{36F}\\x{203F}-\\x{2040}';

        $key = trim($key);
        $key = preg_replace("/[^{$valid_name}-]+/u", '', $key);
        $key = preg_replace("/^[^{$start_char}]+/u", 'item$0', $key);

        return preg_replace('/^(xml).*/iu', 'item$0', $key); // XML is a reserved starting word
    }
}
