<?php
if (!function_exists('array_flatten_with_dots')) {
	/**
	 * 用圆点作为分隔符使多维数组扁平化
	 *
	 * @param array $array 多维数组
	 * @param string $prefix key前缀
	 *
	 * @return array 扁平化后的数组
	 */
	function array_flatten_with_dots(array $array, string $prefix = ''): array
	{
		$flattened = [];

		foreach ($array as $key => $value) {
			$new_key = $prefix . $key;

			if (is_array($value) && $value !== []) {
				$flattened = array_merge($flattened, array_flatten_with_dots($value, $new_key . '.'));
			} else {
				$flattened[$new_key] = $value;
			}
		}

		return $flattened;
	}
}

if (!function_exists('get_value_by_flatten_key')) {
	/**
	 * 使用扁平化的键获取数组中对应元素的值，如键对应的元素不存在，则抛出异常
	 * @param string $flatten_key 扁平化的键，如:a.b.c
	 * @param array $array 数组
	 * @return mixed
	 * @throws Exception
	 */
	function get_value_by_flatten_key(string $flatten_key, array $array)
	{
		$current = &$array;
		foreach (explode('.', $flatten_key) as $key) {
			if (!isset($current[$key])) {
				throw new Exception('Invalid key');
			}
			$current = &$current[$key];
		}
		return $current;
	}
}