<?php
if (!function_exists('previous_url')) {
	/**
	 * 获取上一页URL
	 * @return string
	 */
	function previous_url(): string
	{
		return $_SESSION['_venus_previous_url'] ?? venus::$app->request->server('HTTP_REFERER', FILTER_SANITIZE_URL);
	}
}

if (!function_exists('uri')) {
	/**
	 * 转换uri，支持模块命名空间,自动添加url后缀
	 * @param string $uri 可包含模块命名空间，用$开分。
	 * <code>普通转换：tag/index => tag/index</code>
	 * <code>带模块命名空间：video$tag/index => video/tag/index</code>
	 * <code>带url后缀：tag/index => tag/index.html</code>
	 * @return string
	 */
	function uri(string $uri): string
	{
		if ($uri == '/')
			return $uri;

		if (str_contains($uri, '$')) {
			[$namespace, $uri] = explode('$', $uri);
			$segment = venus::$app->module->get_module($namespace, 'segment');
			if (!empty($segment)) {
				$uri = $segment . '/' . $uri;
			}
		}

		$uri = trim($uri, " \n\r\t\v\x00/");
		// add url suffix
		$uri != '' && $uri .= venus::$app->router->get_config()->get_url_suffix();
		return $uri;
	}
}

if (!function_exists('uri2url')) {
	/**
	 * uri转换为url
	 * @param string $uri
	 * @return string
	 */
	function uri2url(string $uri): string
	{
		$request = venus::$app->request;
		$scheme = $request->is_https() ? 'https://' : 'http://';
		$host = $request->server('HTTP_HOST') ?? $request->server('SERVER_NAME') . ':' . $request->server('SERVER_PORT');
		return $scheme . $host . '/' . $uri;
	}
}