<?php

namespace venus\http;

class curl_response extends \venus\base\component
{
	protected array $info = [];
	protected array $headers = [];
	protected string $body = '';

	/**
	 * Construct
	 * @param string $header
	 * @param string $body
	 * @param array $info
	 */
	public function __construct(string $header, string $body, array $info)
	{
		//info
		$this->info = $info;

		//header
		if (!empty($header)) {
			$header = trim($header);
			if (str_contains($header, "\r\n\r\n")) {
				//Only save headers from last request
				$header = substr($header, strrpos($header, "\r\n\r\n") + 4);
			}

			$list = explode("\n", $header);
			foreach ($list as $item) {
				$item = trim($item);
				if (preg_match('/\A([\w-]+)\:\s*(.+)\z/', $item, $matches) !== 1) {
					continue;
				}
				$key = strtolower($matches[1]);
				$value = $matches[2];
				if (!isset($this->headers[$key])) {
					$this->headers[$key] = $value;
				} elseif (is_string($this->headers[$key])) {
					$this->headers[$key] = [$this->headers[$key], $value];
				} elseif (is_array($this->headers[$key])) {
					$this->headers[$key][] = $value;
				}
			}
		}

		//body
		$this->body = $body;
	}

	public function get_status_code(): int
	{
		return $this->info['http_code'];
	}

	public function get_content_type(): ?string
	{
		return $this->info['content_type'];
	}

	public function get_json(): array|false
	{
		if ($this->get_status_code() != status::HTTP_OK ||
			stripos($this->get_content_type(), 'application/json') === false) {
			return false;
		}
		try {
			return json_decode($this->get_body(), true, 512, JSON_THROW_ON_ERROR);
		} catch (\JsonException) {
			return false;
		}
	}

	public function get_headers(): array
	{
		return $this->headers;
	}

	public function get_header(string $name): string|array|null
	{
		$name = strtolower($name);
		return $this->headers[$name] ?? null;
	}

	public function get_body(): string
	{
		return $this->body;
	}

	public function get_info(): array
	{
		return $this->info;
	}
}