<?php

namespace venus\http\file;

use RecursiveArrayIterator;
use RecursiveIteratorIterator;

class file_collection
{
	protected array $files = [];

	public function __construct()
	{
		if (!empty($_FILES)) {
			$files = $this->fix_files_array($_FILES);
			foreach ($files as $name => $file) {
				$this->files[$name] = $this->create_file_object($file);
			}
		}
	}

	/**
	 * get_files
	 * @param string|null $name
	 * @return array|uploaded_file|null
	 */
	public function get_files(?string $name = null)
	{
		return is_null($name) ? $this->files : ($this->files[$name] ?? null);
	}

	protected function create_file_object(array $array)
	{
		if (!isset($array['name'], $array['type'], $array['tmp_name'], $array['size'], $array['error'])) {
			$output = [];

			foreach ($array as $key => $values) {
				if (!is_array($values)) {
					continue;
				}

				$output[$key] = $this->create_file_object($values);
			}

			return $output;
		}

		return new uploaded_file($array['name'], $array['type'], $array['tmp_name'], $array['size'], $array['error']);
	}

	/**
	 * Thanks to Jack Sleight on the PHP Manual page for the basis
	 * of this method.
	 * @see http://php.net/manual/en/reserved.variables.files.php#118294
	 * @param array $data
	 * @return array
	 */
	protected function fix_files_array(array $data): array
	{
		$output = [];

		foreach ($data as $name => $array) {
			foreach ($array as $field => $value) {
				$pointer = &$output[$name];

				if (!is_array($value)) {
					$pointer[$field] = $value;

					continue;
				}

				$stack = [&$pointer];
				$iterator = new RecursiveIteratorIterator(
					new RecursiveArrayIterator($value),
					RecursiveIteratorIterator::SELF_FIRST
				);

				foreach ($iterator as $key => $val) {
					array_splice($stack, $iterator->getDepth() + 1);
					$pointer = &$stack[count($stack) - 1];
					$pointer = &$pointer[$key];
					$stack[] = &$pointer;

					// RecursiveIteratorIterator::hasChildren() can be used. RecursiveIteratorIterator
					// forwards all unknown method calls to the underlying RecursiveIterator internally.
					// See https://github.com/php/doc-en/issues/787#issuecomment-881446121
					/** @noinspection PhpUndefinedMethodInspection */
					if (!$iterator->hasChildren()) {
						$pointer[$field] = $val;
					}
				}
			}
		}

		return $output;
	}
}