<?php

namespace venus\module;

class module extends \venus\base\component
{
	protected \config\module $config;

	protected ?array $current_module = null;

	/**
	 * construct
	 * @param \config\module $config
	 */
	public function __construct(\config\module $config)
	{
		$this->config = $config;
	}

	/**
	 * 根据命名空间获取模块信息
	 * @param string $namespace 模块命名空间
	 * @param string|null $field 字段名称
	 * @return array|string|null
	 */
	public function get_module(string $namespace, ?string $field = null): array|string|null
	{
		$namespace = trim($namespace, '\\');
		[$ns] = explode('\\', $namespace);
		$module = $this->config->modules[$ns] ?? null;
		if (!is_null($module)) {
			if (is_null($field)) {
				return $module;
			} elseif (isset($module[$field])) {
				return $module[$field];
			}
		}
		return null;
	}

	/**
	 * 检测模块是否有效
	 * @param string $namespace
	 * @return bool
	 */
	public function is_valid_module(string $namespace): bool
	{
		return $this->get_module($namespace, 'status') == '1';
	}

	/**
	 * 获取所有模块信息
	 * @return array
	 */
	public function get_modules(): array
	{
		return $this->config->modules;
	}

	public function get_psr4(): array
	{
		$psr4 = [];
		foreach ($this->config->modules as $module) {
			if (!empty($module['namespace']) && !empty($module['directory']) && is_dir(MODULE_PATH . $module['directory'])) {
				$psr4[$module['namespace']] = MODULE_PATH . $module['directory'] . DIRECTORY_SEPARATOR;
			}
		}
		return $psr4;
	}

	/**
	 * 获取当前模板信息
	 * @param string|null $field 字段名称
	 * @return array|string|null
	 */
	public function get_current_module(string $field = null): array|string|null
	{
		if (!is_null($this->current_module)) {
			return is_null($field) ? $this->current_module : ($this->current_module[$field] ?? null);
		}
		return null;
	}

	/**
	 * 设置指定模块为当前模板
	 * @param array|null $current_module
	 */
	public function set_current_module(?array $current_module): void
	{
		$this->current_module = $current_module;
	}

}