<?php

namespace venus\validation\validator;

use venus\http\file\uploaded_file;
use venus\http\request;

class upload
{
	protected request $request;

	public function __construct()
	{
		$this->request = \venus::$app->request;
		helper('array');
	}

	/**
	 * 检测是否为有效的上传文件
	 * @param $value
	 * @param string $param
	 * @return bool
	 * <code>uploaded[avatar]</code>
	 */
	public function uploaded($value, string $param): bool
	{
		$name = rtrim($param, '.');
		$files_flatten = array_flatten_with_dots($this->request->get_files());

		if (empty($files_flatten)) {
			return false;
		}

		/**
		 * @var uploaded_file $value
		 */
		foreach ($files_flatten as $key => $value) {
			if ($key == $name || str_starts_with($key, $name . '.')) {
				if (!$value->is_valid()) {
					return false;
				}
			}
		}

		return true;
	}

	/**
	 * 检测文件尺寸是否超过指定尺寸(单位:Byte)
	 * @param $value
	 * @param string $params
	 * @return bool
	 * <code>max_size[avatar,1024]</code>
	 */
	public function max_size($value, string $params): bool
	{
		$param_array = explode(',', $params);
		if (count($param_array) !== 2) {
			throw new \InvalidArgumentException('Invalid max_size parameter: "' . $params . '"');
		}
		$name = array_shift($param_array);
		$name = rtrim($name, '.');

		$files_flatten = array_flatten_with_dots($this->request->get_files());

		/**
		 * @var uploaded_file $value
		 */
		foreach ($files_flatten as $key => $value) {
			if ($key == $name || str_starts_with($key, $name . '.')) {

				if ($value->get_error() === UPLOAD_ERR_NO_FILE) {
					continue;
				}

				if ($value->get_error() === UPLOAD_ERR_INI_SIZE || $value->get_size() > floatval($param_array[0])) {
					return false;
				}
			}
		}

		return true;
	}

	/**
	 * 检测文件扩展名
	 * @param $value
	 * @param string $params
	 * @return bool
	 * <code>ext_in[avatar,jpg,png,gif]</code>
	 */
	public function ext_in($value, string $params): bool
	{
		$params = explode(',', $params);
		$name = array_shift($params);
		$name = rtrim($name, '.');
		$params = array_map(fn($value)=>strtolower($value), $params);

		$files_flatten = array_flatten_with_dots($this->request->get_files());

		/**
		 * @var uploaded_file $value
		 */
		foreach ($files_flatten as $key => $value) {

			if ($key == $name || str_starts_with($key, $name . '.')) {

				if ($value->get_error() === UPLOAD_ERR_NO_FILE) {
					continue;
				}

				if (!in_array(strtolower($value->get_extension()), $params, true)) {
					return false;
				}
			}
		}

		return true;
	}
}