<?php

namespace video\config\validation\admin;

use config\validation\validator;
use venus\validation\validator\general;

class field implements \venus\validation\config
{
	private array $validator_class = [
		general::class,
		validator::class,
		self::class
	];

	public function get_validator_class(): array
	{
		return $this->validator_class;
	}

	public function get_rules(?string $scene): array
	{
		$rules = [];
		switch ($scene) {
			case 'add':
				$rules = $this->add();
				break;
			case 'edit':
				$rules = $this->edit();
				break;
			case 'item':
				$rules = $this->item();
				break;
		}
		return $rules;
	}

	/**
	 * 新增字段_验证规则
	 * @return array
	 */
	private function add(): array
	{
		return [
			'field.label' => [
				'rules' => ['required', 'is_unique[pv_video_field.label]'],
				'errors' => [
					'required' => lang('admin.field_label_cannot_be_empty'),
					'is_unique' => lang('admin.field_label_already_exists')
				]
			],
			'field.field' => [
				'rules' => ['required', 'not_equals_i[id]', 'var', 'is_unique[pv_video_field.field]'],
				'errors' => [
					'required' => lang('admin.field_cannot_be_empty'),
					'not_equals_i' => lang('admin.field_cannot_be_id'),
					'var' => lang('admin.field_name_invalid'),
					'is_unique' => lang('admin.field_already_exists')
				]
			],
			'field.field_type' => [
				'rules' => ['required'],
				'errors' => [
					'required' => lang('admin.field_type_cannot_be_empty')
				]
			],
			'field.input_type' => [
				'rules' => ['required'],
				'errors' => [
					'required' => lang('admin.input_type_cannot_be_empty')
				]
			],
			'field.items.value' => [
				'rules' => 'items_value',
				'errors' => [
					'items_value' => lang('admin.items_value_invalid')
				]
			],
			'field.items.label' => [
				'rules' => 'items_label',
				'errors' => [
					'items_label' => lang('admin.items_label_cannot_be_empty')
				]
			],
			'field.items.sort' => [
				'rules' => 'items_sort',
				'errors' => [
					'items_sort' => lang('admin.items_sort_invalid')
				]
			]
		];
	}

	/**
	 * 编辑字段_验证规则
	 * @return array
	 */
	private function edit(): array
	{
		return [
			'field.id' => [
				'rules' => 'id',
				'errors' => [
					'id' => lang('app.invalid_id')
				]
			],
			'field.label' => [
				'rules' => ['required', 'is_unique[pv_video_field.label,id,{field.id}]'],
				'errors' => [
					'required' => lang('admin.field_label_cannot_be_empty'),
					'is_unique' => lang('admin.field_label_already_exists')
				]
			],
			'field.field' => [
				'rules' => ['required', 'not_equals_i[id]', 'var', 'is_unique[pv_video_field.field,id,{field.id}]'],
				'errors' => [
					'required' => lang('admin.field_cannot_be_empty'),
					'not_equals_i' => lang('admin.field_cannot_be_id'),
					'var' => lang('admin.field_name_invalid'),
					'is_unique' => lang('admin.field_already_exists')
				]
			],
			'field.field_type' => [
				'rules' => ['required'],
				'errors' => [
					'required' => lang('admin.field_type_cannot_be_empty')
				]
			],
			'field.input_type' => [
				'rules' => ['required'],
				'errors' => [
					'required' => lang('admin.input_type_cannot_be_empty')
				]
			],
			'field.items.value' => [
				'rules' => 'items_value',
				'errors' => [
					'items_value' => lang('admin.items_value_invalid')
				]
			],
			'field.items.label' => [
				'rules' => 'items_label',
				'errors' => [
					'items_label' => lang('admin.items_label_cannot_be_empty')
				]
			],
			'field.items.sort' => [
				'rules' => 'items_sort',
				'errors' => [
					'items_sort' => lang('admin.items_sort_invalid')
				]
			]
		];
	}

	/**
	 * 检测列表项是否已经在使用_验证规则
	 * @return array
	 */
	private function item(): array
	{
		return [
			'field' => [
				'rules' => ['required', 'not_equals_i[id]', 'var']
			],
			'value' => [
				'rules' => 'required'
			]
		];
	}

	/**
	 * 字段名验证方法，检测是否符合变量命名规则
	 * @param $value
	 * @return bool
	 */
	public function var($value): bool
	{
		return (bool)preg_match('/^[a-zA-Z_]+\w*$/', $value);
	}

	/**
	 * 列表项标签验证方法，所有列表项不允许全部为空
	 * @param $value
	 * @param $data
	 * @param $original_data
	 * @return bool
	 */
	public function items_label($value, $data, $original_data): bool
	{
		if (in_array($original_data['field']['input_type'], ['radio', 'checkbox', 'select'])) {
			if (is_array($value)) {
				foreach ($value as $item_label) {
					if (!is_blank($item_label)) return true;
				}
			}
			return false;
		}
		return true;
	}

	/**
	 * 列表项值验证方法，不允许包含逗号
	 * @param $value
	 * @param $data
	 * @param $original_data
	 * @return bool
	 */
	public function items_value($value, $data, $original_data): bool
	{
		if (in_array($original_data['field']['input_type'], ['radio', 'checkbox', 'select'])) {
			if (is_array($value)) {
				foreach ($value as $item_value) {
					if (str_contains($item_value, ',')) return false;
				}
			}
		}
		return true;
	}

	/**
	 * 列表项排序验证方法，只允许为数字或留空
	 * @param $value
	 * @param $data
	 * @param $original_data
	 * @return bool
	 */
	public function items_sort($value, $data, $original_data): bool
	{
		if (in_array($original_data['field']['input_type'], ['radio', 'checkbox', 'select'])) {
			if (is_array($value)) {
				foreach ($value as $item_sort) {
					if (is_blank($item_sort)) continue;
					if (is_numeric($item_sort) === false) return false;
				}
			}
		}
		return true;
	}
}