<?php

namespace video\config\validation\admin;

use config\validation\validator;
use venus\validation\validator\general;

class mars_server implements \venus\validation\config
{
	private array $validator_class = [
		general::class,
		validator::class,
		self::class
	];

	public function get_validator_class(): array
	{
		return $this->validator_class;
	}

	public function get_rules(?string $scene): array
	{
		return $scene == 'add' ? $this->add() : $this->edit();
	}

	private function add(): array
	{
		return [
			'mars_server.name' => [
				'rules' => ['required', 'is_unique[pv_video_mars_server.name]'],
				'errors' => [
					'required' => lang('admin.server_name_cannot_be_empty'),
					'is_unique' => lang('admin.server_name_already_exists')
				]
			],
			'mars_server.ip' => [
				'rules' => ['required', 'valid_ip[ipv4]'],
				'errors' => [
					'required' => lang('admin.server_ip_cannot_be_empty'),
					'valid_ip' => lang('admin.invalid_server_ip')
				]
			],
			'mars_server.port' => [
				'rules' => ['required', 'int_between[1,65535]'],
				'errors' => [
					'required' => lang('admin.server_port_cannot_be_empty'),
					'int_between' => lang('admin.invalid_server_port')
				]
			],
			'mars_server.secret_key' => [
				'rules' => 'required',
				'errors' => [
					'required' => lang('admin.server_secret_key_cannot_be_empty')
				]
			],
			'mars_server.upload_url' => [
				'rules' => ['required', 'valid_url'],
				'errors' => [
					'required' => lang('admin.server_upload_url_cannot_be_empty'),
					'valid_url' => lang('admin.invalid_server_upload_url')
				]
			],
			'mars_server.notify_url' => [
				'rules' => 'notify_url',
				'errors' => [
					'notify_url' => lang('admin.invalid_notify_url'),
				]
			],
			'mars_server.weight' => [
				'rules' => 'int_between[0,10]',
				'errors' => [
					'int_between' => lang('admin.invalid_server_weight')
				]
			]
		];
	}

	private function edit(): array
	{
		return array_merge($this->add(), [
			'mars_server.id' => [
				'rules' => 'id',
				'errors' => [
					'id' => lang('app.invalid_id')
				]
			],
			'mars_server.name' => [
				'rules' => ['required', 'is_unique[pv_video_mars_server.name,id,{mars_server.id}]'],
				'errors' => [
					'required' => lang('admin.server_name_cannot_be_empty'),
					'is_unique' => lang('admin.server_name_already_exists')
				]
			]
		]);
	}

	public function notify_url($value): bool
	{
		return trim($value) == '' || preg_match('/^https?\:\/\/[^\/]+.*$/i', $value);
	}
}