<?php

namespace video\controller\admin;

use config\validation\validator;
use phpvod\base\backend_controller;
use video\library\config;
use video\model\field;

class category extends backend_controller
{
	protected array $helper = ['form'];
	private \video\model\category $model;

	public function init(): void
	{
		parent::init();
		/** @noinspection PhpFieldAssignmentTypeMismatchInspection */
		$this->model = model(\video\model\category::class);
	}

	public function index(): string
	{
		return $this->view('category/index');
	}

	public function add(): string
	{
		if ($this->request->is_post()) {
			if ($this->validation->load_config(\video\config\validation\admin\category::class, 'add')->with_post()->run()) {
				$data = $this->request->post('category', [
					'sort' => [
						'filter' => FILTER_VALIDATE_INT,
						'flags' => FILTER_REQUIRE_SCALAR,
						'options' => ['min_range' => 0, 'max_range' => 999, 'default' => 0]
					],
					'template' => [
						'filter' => FILTER_CALLBACK,
						'options' => function (string $value) {
							$value = trim($value);
							return $value !== '' ? $value : null;
						}
					]
				]);
				$this->model->insert($data);
				config::get_instance()->update('category');
				$this->module_redirect('category/index', false, true);
			} else {
				$this->set_message_from_validator();
				$this->module_redirect('category/add', true);
			}
		}

		return $this->view('category/add');
	}

	public function edit(): string
	{
		if ($this->request->is_post()) {
			$category = $this->request->post('category', [
				'sort' => [
					'filter' => FILTER_VALIDATE_INT,
					'flags' => FILTER_REQUIRE_SCALAR,
					'options' => ['min_range' => 0, 'max_range' => 999, 'default' => 0]
				],
				'template' => [
					'filter' => FILTER_CALLBACK,
					'options' => function (string $value) {
						$value = trim($value);
						return $value !== '' ? $value : null;
					}
				]
			]);
			if ($this->validation->load_config(\video\config\validation\admin\category::class, 'edit')->with_post()->run()) {
				$this->model->save($category);
				config::get_instance()->update('category');
				$this->module_redirect('category/index', false, true);
			} else {
				$this->set_message_from_validator();
				$this->redirect(admin_module_uri('category/edit') . '?id=' . $category['id'], true);
			}
		}

		$id = $this->request->get('id');
		$category = $this->model->find($id)->fetch_array();
		if ($category === false) {
			$this->module_redirect('category/index', false, lang('app.invalid_id'));
		}
		return $this->view('category/edit', ['category' => $category]);
	}

	public function delete(): void
	{
		$id = $this->request->post('id');
		if ($this->validation->check($id, 'id', validator::class)) {
			//检测栏目下是否包含视频
			/**
			 * @var \video\model\video $video_model
			 */
			$video_model = model(\video\model\video::class);
			$video_count = (int)$video_model->select('count(id)')->where(['category_id' => $id])->query()->fetch_column();
			if ($video_count > 0) {
				$this->response->set_json(['id' => 0, 'msg' => lang('admin.category_is_not_empty')]);
			} else {
				$affected_rows = $this->model->delete($id);
				if ($affected_rows > 0) {

					//删除自定义字段引用的栏目ID
					/**
					 * @var field $field_model
					 */
					$field_model = model(field::class);
					$field_model->remove_category_id($id);

					//更新缓存
					config::get_instance()->update('category');
					config::get_instance()->update('field');

					$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
				} else {
					$this->response->set_json(['id' => 0, 'msg' => lang('app.operation_failed')]);
				}
			}
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_id')]);
		}
	}

	/**
	 * 获取栏目数据
	 * @return void
	 * @throws \Exception
	 */
	public function get_data(): void
	{
		$params = $this->get_bootstrap_table_query_params();
		if ($params !== false) {
			$data = $this->model->get_data($params);
			$this->response->set_json($data);
		}
	}
}