<?php

namespace video\controller\admin;

use config\validation\validator;
use phpvod\base\backend_controller;
use video\library\config;
use video\model\video_ext;

class field extends backend_controller
{
	protected array $helper = ['form'];
	private \video\model\field $model;

	public function init(): void
	{
		parent::init();
		/** @noinspection PhpFieldAssignmentTypeMismatchInspection */
		$this->model = model(\video\model\field::class);
	}

	public function index(): string
	{
		return $this->view('field/index');
	}

	/**
	 * 新增字段
	 * @return string
	 * @throws \Exception
	 */
	public function add(): string
	{
		if ($this->request->is_post()) {
			if ($this->validation->load_config(\video\config\validation\admin\field::class, 'add')->with_post()->run()) {
				$field = $this->request->post('field', [
					'label' => [
						'filter' => FILTER_CALLBACK,
						'options' => function (string $value) {
							return trim($value);
						}
					]
				]);

				//items
				$field['items'] = $this->get_items($field);

				//category_id
				$field['category_id'] = isset($field['category_id']) && is_array($field['category_id']) ? implode(',', $field['category_id']) : null;

				$return = $this->model->add_field($field);
				if (!$return) {
					$this->module_redirect('field/add', true, lang('app.operation_failed'));
				}

				config::get_instance()->update('field');
				$this->module_redirect('field/index', false, true);
			} else {
				$this->set_message_from_validator();
				$this->module_redirect('field/add', true);
			}
		}

		return $this->view('field/add');
	}

	/**
	 * 编辑字段
	 * @return string
	 * @throws \Exception
	 */
	public function edit(): string
	{
		if ($this->request->is_post()) {
			$field = $this->request->post('field', [
				'label' => [
					'filter' => FILTER_CALLBACK,
					'options' => function (string $value) {
						return trim($value);
					}
				]
			]);
			if ($this->validation->load_config(\video\config\validation\admin\field::class, 'edit')->with_post()->run()) {
				//items
				$field['items'] = $this->get_items($field);

				//category_id
				$field['category_id'] = isset($field['category_id']) && is_array($field['category_id']) ? implode(',', $field['category_id']) : null;

				$return = $this->model->edit_field($field);
				if (!$return) {
					$this->redirect(admin_module_uri('field/edit') . '?id=' . $field['id'], true, lang('app.operation_failed'));
				}

				config::get_instance()->update('field');
				$this->module_redirect('field/index', false, true);
			} else {
				$this->set_message_from_validator();
				$this->redirect(admin_module_uri('field/edit') . '?id=' . $field['id'], true);
			}
		}


		$id = $this->request->get('id');
		$field = $this->model->find($id)->fetch_array();
		if ($field === false) {
			$this->module_redirect('field/index', false, lang('app.invalid_id'));
		}

		if (!is_null($field['items'])) {
			$array = json_decode($field['items'], true);
			$field['items'] = [
				'value' => array_column($array, 'value'),
				'label' => array_column($array, 'label'),
				'sort' => array_column($array, 'sort')
			];
		} else {
			$field['items'] = ['value' => [], 'label' => [], 'sort' => []];
		}

		$field['category_id'] = is_null($field['category_id']) ? [] : explode(',', $field['category_id']);
		return $this->view('field/edit', ['field' => $field]);
	}

	/**
	 * 删除字段
	 * @return void
	 * @throws \Exception
	 */
	public function delete(): void
	{
		$id = $this->request->post('id');
		if ($this->validation->check($id, 'id', validator::class)) {
			$this->model->delete_field($id);
			config::get_instance()->update('field');
			$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_id')]);
		}
	}

	/**
	 * 检测列表项是否已经在使用
	 * @return void
	 * @throws \Exception
	 */
	public function check_item_status(): void
	{
		if ($this->validation->load_config(\video\config\validation\admin\field::class, 'item')->with_post()->run()) {
			/**
			 * @var video_ext $model
			 */
			$field = $this->request->post('field');
			$value = $this->request->post('value');
			$model = model(video_ext::class);
			$rows = (int)$model->select('count(id)')->where("FIND_IN_SET('$value', $field)")->query()->fetch_column();
			if ($rows == 0)
				$this->response->set_json(['id' => 1, 'msg' => 'ok']);
			else
				$this->response->set_json(['id' => 0, 'msg' => lang('admin.item_already_in_use')]);
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_params')]);
		}
	}

	public function get_data(): void
	{
		$params = $this->get_bootstrap_table_query_params();
		if ($params !== false) {
			$data = $this->model->get_data($params);
			$this->response->set_json($data);
		}
	}

	private function get_items(array $field): ?string
	{
		if (in_array($field['input_type'], ['radio', 'checkbox', 'select'])) {
			$items = [];
			foreach ($field['items']['label'] as $key => $item_label) {
				$item_label = trim($item_label);
				if ($item_label != '') {
					$item_value = is_blank($field['items']['value'][$key]) ? $key + 1 : trim($field['items']['value'][$key]);
					$item_sort = is_blank($field['items']['sort'][$key]) ? $key + 1 : (int)$field['items']['sort'][$key];
					$items[] = [
						'value' => $item_value,
						'label' => $item_label,
						'sort' => $item_sort
					];
				}
			}
			//sort
			$sort = array_column($items, 'sort');
			array_multisort($sort, SORT_ASC, SORT_NUMERIC, $items); //SORT
			return formatter($items);
		} else {
			return null;
		}
	}
}