<?php

namespace video\controller\admin;

use config\validation\validator;
use video\service\mars;

class mars_server extends \phpvod\base\backend_controller
{
	private \video\model\mars_server $model;
	protected array $helper = ['form'];

	public function init(): void
	{
		parent::init();
		/** @noinspection PhpFieldAssignmentTypeMismatchInspection */
		$this->model = model(\video\model\mars_server::class);
	}

	public function index(): string
	{
		return $this->view('mars_server/index');
	}

	/**
	 * 获取数据
	 * @return void
	 * @throws \Exception
	 */
	public function get_data(): void
	{
		$params = $this->get_bootstrap_table_query_params();
		if ($params !== false) {
			$data = $this->model->get_data($params);
			$this->response->set_json($data);
		}
	}

	public function add(): string
	{
		if ($this->request->is_post()) {
			if ($this->validation->load_config(\video\config\validation\admin\mars_server::class, 'add')->with_post()->run()) {
				$data = $this->request->post('mars_server');
				$this->model->insert($data);
				\video\library\config::get_instance()->update('mars_server');
				$this->module_redirect('mars_server/index', false, true);
			} else {
				$this->set_message_from_validator();
				$this->module_redirect('mars_server/add', true);
			}
		}
		return $this->view('mars_server/add');
	}

	public function edit(): string
	{
		if ($this->request->is_post()) {
			$data = $this->request->post('mars_server');
			if ($this->validation->load_config(\video\config\validation\admin\mars_server::class, 'edit')->with_post()->run()) {
				$this->model->save($data);
				\video\library\config::get_instance()->update('mars_server');
				$this->module_redirect('mars_server/index', false, true);
			} else {
				$this->set_message_from_validator();
				$this->redirect(admin_module_uri('mars_server/edit') . '?id=' . $data['id'], true);
			}
		}

		$id = $this->request->get('id');
		$mars_server = $this->model->find($id)->fetch_array();
		if ($mars_server === false) {
			$this->module_redirect('mars_server/index', false, lang('app.invalid_id'));
		}
		return $this->view('mars_server/edit', ['mars_server' => $mars_server]);
	}

	public function delete(): void
	{
		$id = $this->request->post('id');
		if ($this->validation->check($id, 'id', validator::class)) {
			$affected_rows = $this->model->delete($id);
			if ($affected_rows > 0) {

				//删除域名映射引用的转码服务器ID
				/**
				 * @var \video\model\mars_map $mars_map_model
				 */
				$mars_map_model = model(\video\model\mars_map::class);
				$mars_map_model->remove_server_id($id);

				\video\library\config::get_instance()->update('mars_server');
				$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
			} else {
				$this->response->set_json(['id' => 0, 'msg' => lang('app.operation_failed')]);
			}
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_id')]);
		}
	}

	/**
	 * 测试连接(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function test_conn(): void
	{
		$id = $this->request->post('id');
		$mars = mars::get_instance_by_server_id($id);
		if(!is_null($mars)) {
			$data = $mars->test_conn("server_id=$id");
			$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded'), 'data' => $data, 'server' => ['name' => mars::$config['name'], 'ip' => mars::$config['ip'], 'port' => mars::$config['port']]]);
		}else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_id')]);
		}
	}

	/**
	 * 验证上传地址(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function verify_upload_url(): void
	{
		$upload_url = $this->request->get('upload_url');
		if($this->validation->check($upload_url, 'valid_url')) {
			$headers = \phpvod::$app->curl_request->head($upload_url)->get_headers();
			if(isset($headers['x-mars-file']) && $headers['x-mars-file'] === 'plupload') {
				$this->response->set_json(['id' => 1, 'msg' => lang('admin.server_upload_url_is_valid')]);
				return;
			}
		}
		$this->response->set_json(['id' => 0, 'msg' => lang('admin.invalid_server_upload_url')]);
	}
}