<?php

namespace video\controller\admin;

use config\validation\validator;
use venus\http\file\uploaded_file;
use video\library\config;

class player extends \phpvod\base\backend_controller
{
	private \video\model\player $model;
	protected array $helper = ['form', 'array', 'file_system'];

	public function init(): void
	{
		parent::init();
		/** @noinspection PhpFieldAssignmentTypeMismatchInspection */
		$this->model = model(\video\model\player::class);
	}

	public function index(): string
	{
		return $this->view('player/index');
	}

	public function add(): string
	{
		if ($this->request->is_post()) {
			if ($this->validation->load_config(\config\validation\admin\upload::class, 'upload_zip')->run()) {

				/* @var uploaded_file $file */
				$file = $this->request->get_files('zip_file');
				$file->move(WRITABLE_PATH . 'temp', $file->get_random_name());
				$zip_file = $file->get_saved_file();
				try {
					$this->model->install($zip_file);
					remove_file($zip_file);
					config::get_instance()->update('player'); //更新播放器缓存
					$this->module_redirect('player/index', false, true);
				} catch (\Exception $exception) {
					remove_file($zip_file);
					$this->module_redirect('player/add', false, $exception->getMessage());
				}

			} else {
				$this->set_message_from_validator();
				$this->module_redirect('player/add');
			}
		}

		return $this->view('player/add');
	}

	public function delete(): void
	{
		$id = $this->request->post('id');
		if ($this->validation->check($id, 'id', validator::class)) {
			try {
				$this->model->uninstall($id);
				config::get_instance()->update('player');
				$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
			} catch (\Exception $exception) {
				$exception->getCode() === 2 && config::get_instance()->update('player');
				$this->response->set_json(['id' => $exception->getCode(), 'msg' => $exception->getMessage()]);
			}
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_id')]);
		}
	}

	/**
	 * 获取表格数据(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function get_data(): void
	{
		$params = $this->get_bootstrap_table_query_params();
		if ($params !== false) {
			$data = $this->model->get_data($params);
			$this->response->set_json($data);
		}
	}

	/**
	 * 更改状态(ajax)
	 * @return void
	 * @throws \Exception
	 */
	public function change_status(): void
	{
		$id = $this->request->post('id');
		parent::change_status_by_id([$this->model, 'change_status'], $id, function () {
			config::get_instance()->update('player');
		});
	}

}