<?php

namespace video\controller\admin;

use phpvod\base\backend_controller;
use video\library\config;

class slide extends backend_controller
{
	protected array $helper = ['form'];
	private \video\model\slide $model;

	public function init(): void
	{
		parent::init();
		/** @noinspection PhpFieldAssignmentTypeMismatchInspection */
		$this->model = model(\video\model\slide::class);
	}

	public function index(): string
	{
		return $this->view('slide/index');
	}

	public function add(): string
	{
		if ($this->request->is_post()) {
			if ($this->validation->load_config(\config\validation\admin\upload::class, 'upload_image')->run()) {
				$data = $this->request->post('slide', [
					'sort' => [
						'filter' => FILTER_VALIDATE_INT,
						'flags' => FILTER_REQUIRE_SCALAR,
						'options' => ['min_range' => 0, 'max_range' => 999, 'default' => 0]
					]
				]);
				$file = $this->request->get_files('image_file');
				$file_path = $file->store('video/slide');
				if (!is_null($file_path)) {
					$data['pic'] = basename($file_path);
					$this->model->insert($data);
					config::get_instance()->update('slide');
					$this->module_redirect('slide/index', false, true);
				} else {
					$this->set_message(lang('admin.image_upload_failed'));
					$this->module_redirect('slide/add', true);
				}
			} else {
				$this->set_message_from_validator();
				$this->module_redirect('slide/add', true);
			}
		}

		return $this->view('slide/add');
	}

	public function edit(): string
	{
		if ($this->request->is_post()) {
			$data = $this->request->post('slide', [
				'sort' => [
					'filter' => FILTER_VALIDATE_INT,
					'flags' => FILTER_REQUIRE_SCALAR,
					'options' => ['min_range' => 0, 'max_range' => 999, 'default' => 0]
				]
			]);

			$file = $this->request->get_files('image_file');
			if ($file instanceof \venus\http\file\uploaded_file	&& $file->is_valid()) {
				if(!$this->validation->check(null, 'ext_in[image_file,jpg,jpeg,png,gif,webp]', \venus\validation\validator\upload::class)) {
					$this->set_message(lang('app.invalid_file_type'));
					$this->redirect(admin_module_uri('slide/edit') . '?id='. $data['id'], true);
				}
				$file_path = $file->store('video/slide');
				if (!is_null($file_path)) {
					$data['pic'] = basename($file_path);
					$this->model->remove_file_by_id($data['id']);
				}
			}

			$this->model->save($data);
			config::get_instance()->update('slide');
			$this->module_redirect('slide/index', false, true);
		}

		$id = $this->request->get('id');
		$slide = $this->model->find($id)->fetch_array();
		if ($slide === false) {
			$this->module_redirect('slide/index', false, lang('app.invalid_id'));
		}

		return $this->view('slide/edit', ['slide' => $slide]);
	}

	public function delete(): void
	{
		$id = $this->request->post('id');
		if ($this->validation->check($id, 'id', \config\validation\validator::class)) {
			$this->model->remove_file_by_id($id);
			$this->model->delete($id);
			config::get_instance()->update('slide');
			$this->response->set_json(['id' => 1, 'msg' => lang('app.operation_succeeded')]);
		} else {
			$this->response->set_json(['id' => 0, 'msg' => lang('app.invalid_id')]);
		}
	}

	/**
	 * 获取栏目数据
	 * @return void
	 * @throws \Exception
	 */
	public function get_data(): void
	{
		$params = $this->get_bootstrap_table_query_params();
		if ($params !== false) {
			$data = $this->model->get_data($params);
			$this->response->set_json($data);
		}
	}
}