<?php

namespace video\controller;

use phpvod\base\frontend_controller;
use video\library\config;
use video\tag\tag;

class home extends frontend_controller
{
	protected array $helper = ['form'];

	/**
	 * 首页
	 * @throws \Exception
	 */
	public function index(): string
	{
		return $this->view('home/index');
	}

	/**
	 * 列表页
	 * @param int $id 栏目ID
	 * @return string
	 * @throws \Exception
	 */
	public function category(int $id): string
	{
		$category = config::get_instance()->get('category');
		if (!is_array($category) || !isset($category[$id])) {
			$this->show_message(lang('app.invalid_id'), [self::SHOW_MESSAGE_GO_HOME_BTN]);
		}

		$category_template = $category[$id]['template'] ?? 'category';
		return $this->view('home/' . $category_template, ['id' => $id]);
	}

	/**
	 * 播放页
	 * @param int $id 视频ID
	 * @param int $group 播放组
	 * @param int $index 集数索引
	 * @return string
	 * @throws \Exception
	 */
	public function play(int $id, int $group = 0, int $index = 0): string
	{
		$details = tag::video_details()->fetch($id);
		if ($details === false || !isset($details['video_url'][$group]['url'][$index])) {
			$this->show_message(lang('app.invalid_params'), [self::SHOW_MESSAGE_GO_HOME_BTN]);
		}

		$details['hits']++;
		tag::video_details()->hits_increment($id, 1, threshold: 10); //hits_increment

		return $this->view('home/play', ['id' => $id, 'group' => $group, 'index' => $index, 'details' => $details]);
	}

	/**
	 * 搜索页
	 * @return string
	 * @throws \Exception
	 */
	public function search(): string
	{
		return $this->view('home/search');
	}
}