<?php

namespace video\event;

class handler
{
	public const DEPEND_KEY_VIDEO_LIST = 'depend_key_video_list';
	public const KEY_VIDEO_DETAILS = 'video_details_(:id)';
	public const KEY_VIDEO_HITS = 'video_hits_(:id)';

	/**
	 * insert_from_module 事件处理器
	 * @param string $module_namespace
	 * @param int $resource_id
	 * @return void
	 * @throws \Exception
	 */
	public function event_insert_from_module_handler(string $module_namespace, int $resource_id): void
	{
		$this->update_video_list_depend($module_namespace, $resource_id);
	}

	/**
	 * update_from_module 事件处理器
	 * @param string $module_namespace
	 * @param int $resource_id
	 * @return void
	 * @throws \Exception
	 */
	public function event_update_from_module_handler(string $module_namespace, int $resource_id): void
	{
		$this->update_video_list_depend($module_namespace, $resource_id);
		$this->remove_video_details($module_namespace, $resource_id);
	}

	/**
	 * delete_from_module 事件处理器
	 * @param string $module_namespace
	 * @param int|array $resource_id
	 * @return void
	 * @throws \Exception
	 */
	public function event_delete_from_module_handler(string $module_namespace, int|array $resource_id): void
	{
		$this->update_video_list_depend($module_namespace, $resource_id);
		$this->remove_video_details($module_namespace, $resource_id);
		$this->remove_video_hits($module_namespace, $resource_id);
	}

	/**
	 * 更新视频列表依赖
	 * @param string $module_namespace
	 * @param int|array $resource_id
	 * @return void
	 * @throws \Exception
	 */
	private function update_video_list_depend(string $module_namespace, int|array $resource_id): void
	{
		if ($module_namespace != 'video' || empty($resource_id))
			return;

		\phpvod::$app->cache->get_handler()->set(self::DEPEND_KEY_VIDEO_LIST, TIMESTAMP); //更新依赖
	}

	/**
	 * 删除视频详情缓存
	 * @param string $module_namespace
	 * @param int|array $resource_id
	 * @return void
	 * @throws \Exception
	 */
	private function remove_video_details(string $module_namespace, int|array $resource_id): void
	{
		if ($module_namespace != 'video' || empty($resource_id))
			return;

		$ids = is_array($resource_id) ? $resource_id : [$resource_id];
		foreach ($ids as $id) {
			$key = strtr(self::KEY_VIDEO_DETAILS, ['(:id)' => $id]);
			\phpvod::$app->cache->get_handler()->delete($key);
		}
	}

	/**
	 * 删除视频热度缓存
	 * @param string $module_namespace
	 * @param int|array $resource_id
	 * @return void
	 * @throws \Exception
	 */
	private function remove_video_hits(string $module_namespace, int|array $resource_id): void
	{
		if ($module_namespace != 'video' || empty($resource_id))
			return;

		$ids = is_array($resource_id) ? $resource_id : [$resource_id];
		foreach ($ids as $id) {
			$key = strtr(self::KEY_VIDEO_HITS, ['(:id)' => $id]);
			\phpvod::$app->cache->get_handler()->delete($key);
		}
	}
}