<?php

namespace mars\sdk;
class mars_helper
{
	private mars_client $mars_client;

	/**
	 * @param mars_client $mars_client
	 */
	public function __construct(mars_client $mars_client)
	{
		$this->mars_client = $mars_client;
	}

	/**
	 * 获取上传的文件数据
	 * @param string $post_name
	 * @return array
	 * <pre>
	 * [
	 *  'trailer.mp4' => [
	 *          [token] => TOKEN_STRING
	 *          [truename] = trailer.mp4
	 *          [subtitle_token] = TOKEN_STRING
	 *      ]
	 * ]
	 * </pre>
	 */
	public function get_uploaded_file_data(string $post_name): array
	{
		$uploaded_file_data = [];
		$post_data = $_POST[$post_name] ?? null;
		if (!is_array($post_data) || empty($post_data)) {
			return $uploaded_file_data;
		}

		$temp_data = [];
		foreach ($post_data as $value) {
			$item = json_decode($value, true);
			if ($item === null) continue;
			if (isset($item['token']) && trim($item['token']) != '' && isset($item['truename']) && trim($item['truename']) != '') {
				$path_parts = pathinfo($item['truename']);
				$path_parts['extension'] = strtolower($path_parts['extension']);
				$path_parts['filename'] = strtolower($path_parts['filename']);
				$path_parts['basename'] = strtolower($path_parts['basename']);
				if (in_array($path_parts['extension'], ['ass', 'srt'])) { //字幕文件
					$temp_data[$path_parts['filename']]['subtitle_token'] = $item['token'];
				} else {
					$temp_data[$path_parts['basename']]['token'] = $item['token'];
					$temp_data[$path_parts['basename']]['truename'] = $item['truename'];
				}
			}
		}

		foreach ($temp_data as $key => $value) {
			if (isset($value['token']) && isset($value['truename'])) {
				if (!isset($value['subtitle_token'])) $value['subtitle_token'] = '';
				$uploaded_file_data[$key] = $value;
			}
		}

		return $uploaded_file_data;
	}

	/**
	 * 添加转码任务
	 * @param array $file_data 文件数据
	 * @param array $params 添加转码任务时的额外参数，['tasks' => '', 'priority' => 0]
	 * @return array 已添加的转码任务
	 * @throws \Exception
	 */
	public function add_task(array $file_data, array $params = []): array
	{
		$added_tasks = [];
		//tasks
		$tasks = $params['tasks'] ?? '';
		//priority
		$priority = $params['priority'] ?? 0;
		//passback
		$passback = $params['passback'] ?? '';

		if (!empty($file_data)) {
			foreach ($file_data as $video) {
				$response = $this->mars_client->add_task_by_token($video['token'], $video['subtitle_token'], $tasks, $priority, $passback);
				if (!$response) continue;
				//$response = {"duration":"52.209","msg":"success","code":"84","tid":"84"}
				$response_array = json_decode($response, true);
				if ($response_array['code'] > 0) {
					$added_tasks[] = [
						'tid' => $response_array['tid'],
						'truename' => $video['truename'],
						'duration' => $response_array['duration'],
					];
				}
			}
		}
		return $added_tasks;
	}
}