<?php

namespace video\extension\upload\mars_transcoder;

use phpvod\event\event;
use video\library\config;
use video\model\video;
use video\model\video_file;
use video\service\mars;

class mars_gateway
{
	private ?string $secret_key = null;

	public function __construct(int $server_id)
	{
		$config = config::get_instance()->get('mars_server', $server_id);
		if (is_array($config) && isset($config['secret_key'])) {
			$this->secret_key = $config['secret_key'];
		}
	}

	public function run(): void
	{
		if ($this->check_key()) {
			$action = $_POST['action'];
			if ($action == 'test') {
				$this->action_test();
			} elseif ($action == 'store_complete') {
				$this->action_store_complete();
			}
		} else {
			echo 'key_error';
		}
	}

	protected function action_test(): void
	{
		echo 'success';
	}

	protected function action_store_complete(): void
	{
		$request = \phpvod::$app->request;
		$server_id = $request->post('server_id');
		$tid = $request->post('tid');
		$data = $request->post('data');
		$remote_key = $server_id . '_' . $tid;

		//update pv_video_file
		/**
		 * @var video_file $video_file_model
		 */
		$video_file_model = model(video_file::class);
		$video_file_model->where(['remote_key' => $remote_key])->update(['remote_data' => $data]);

		//update pv_video
		$video_file = $video_file_model->select('vid,file_info,remote_data')->where(['remote_key' => $remote_key])->query()->fetch_array();
		if (is_array($video_file) && (int)$video_file['vid'] > 0) {
			/**
			 * @var video $video_model
			 */
			$video_model = model(video::class);
			$vid = (int)$video_file['vid'];
			$video = $video_model->select('poster,preview,duration')->find($vid)->fetch_array();
			if (is_array($video)) {
				$file_info = json_decode($video_file['file_info'], true);
				$remote_data = json_decode($video_file['remote_data'], true);

				$data = [];
				if (isset($file_info['duration'])) {
					$duration = (int)$file_info['duration']; //float to int
					$data['duration'] = empty($video['duration']) ? $duration : 'duration+' . $duration;
				}
				if (empty($video['poster'])) {
					$result = mars::get_url_by_name('poster', $remote_data);
					isset($result['poster']) && $data['poster'] = $result['poster'];
				}
				if (empty($video['preview'])) {
					$result = mars::get_url_by_name('preview', $remote_data);
					isset($result['preview']) && $data['preview'] = $result['preview'];
				}
				if (!empty($data)) {
					$video_model->update($data, $vid, ['duration']);
					event()->trigger(event::EVENT_UPDATE_FROM_MODULE, 'video', $vid); //触发事件使缓存失效
				}
			}
		}

		echo 'success';
	}

	private function check_key(): bool
	{
		return isset($_POST['key']) && $_POST['key'] == $this->secret_key && !is_null($this->secret_key);
	}
}