<?php
/**
 * @var int $server_id
 */
$form = \phpvod\widget\form\admin_form::get_instance();
\phpvod\library\plupload\asset\plupload::register();
$upload = \video\library\config::get_instance()->get('upload');
$mars_server = \video\library\config::get_instance()->get('mars_server');
$hash_set = old('hash_set', '');
?>
<div class="row mb-4">
	<label class="col-md-2 col-form-label text-md-end">
		<?= lang('video.upload_file') ?>
		<?= $form->tips(lang('video.tips_upload_file', [$mars_server[$server_id]['name'], $upload['format'], $upload['max_size'] . $upload['max_size_unit']]))?>
	</label>
	<div class="col-md-6">
		<div id="plupload_container">
			<table class="table table-hover">
				<thead>
				<tr>
					<th><?= lang('video.filename') ?></th>
					<th class="w-25"><?= lang('video.filesize') ?></th>
					<th class="w-25"><?= lang('video.status') ?></th>
				</tr>
				</thead>
				<tbody id="file_container"></tbody>
				<tfoot>
				<tr>
					<td colspan="3">
						<button type="button" id="pick_files" class="btn btn-outline-success px-1 py-0">
							<i class="mdi mdi-plus me-1" aria-hidden="true"></i><?= lang('video.add') ?>
						</button>

						<button type="button" id="upload" class="btn btn-outline-primary px-1 py-0">
							<i class="mdi mdi-upload me-1" aria-hidden="true"></i><?= lang('video.upload') ?>
						</button>
					</td>
				</tr>
				<tr>
					<td colspan="3">
						<span class="form-check-label me-3">
							<?=lang('video.mars_tasks')?>
							<?=$form->tips(lang('video.tips_mars_tasks'))?>
						</span>
						<?= $form->checkbox_group('mars_tasks[]', \video\library\options::mars_tasks($server_id), null, ['class' => 'form-check-input']) ?>
					</td>
				</tr>
				<tr>
					<td colspan="3">
						<span class="form-check-label me-3"><?=lang('video.mars_priority')?></span>
						<?= $form->radio_group('mars_priority', \video\library\options::mars_priority(), 0, ['class' => 'form-check-input']) ?>
					</td>
				</tr>
				</tfoot>
			</table>
			<input type="hidden" name="hash_set" id="hash_set" value="<?= $hash_set ?>"/>
		</div>
	</div>
</div>

<div class="row mb-4">
	<label class="col-md-2 col-form-label text-md-end"><?= lang('video.uploaded_file') ?></label>
	<div class="col-md-6">
		<table class="table table-hover">
			<thead>
			<tr>
				<th><?= lang('video.filename') ?></th>
				<th class="w-25"><?= lang('video.tag') ?></th>
				<th class="w-25"><?= lang('video.operate') ?></th>
			</tr>
			</thead>
			<tbody id="uploaded_container"></tbody>
		</table>
	</div>
</div>

<?php phpvod::$app->view->section('js'); ?>

<script type="text/javascript">
	$.ajaxSetup({headers: <?=csrf_json()?>});

	/**
	 * 文件上传
	 */
	let upload_video = {
		plupload: null, //plupload instance
		last: {time: null, loaded: null},
		uploaded_file: [], //已上传的文件
		/**
		 * 创建plupload实例
		 */
		new_plupload: function (format, max_size, chunk_size) {
			upload_video.plupload = new plupload.Uploader({
				runtimes: 'html5',
				browse_button: 'pick_files',
				container: 'plupload_container',
				url: '<?=$mars_server[$server_id]['upload_url']?>',
				filters: {
					max_file_size: max_size,
					mime_types: [
						{title: "<?=lang('video.video_file')?>", extensions: format},
					],
					prevent_duplicates: true
				},
				multipart_params: {},
				http_method: 'post',
				chunk_size: chunk_size,
				unique_names: true,

				init: {
					init: function (up, params) {
						$("#plupload_container #file_container").html(`
	                        <tr class="empty">
	                            <td colspan="3" class="text-center"><?=lang('video.list_is_empty')?></td>
	                        </tr>
                        `);
						$("#upload").click(function () {
							upload_video.plupload.start();
						});
					},

					FilesAdded: function (up, files) {
						$.each(files, function (i, file) {
							$("#plupload_container .empty").remove();
							$("#plupload_container #file_container").append(
								'<tr id="' + file.id + '">' +
								'<td><a class="link-danger text-decoration-none me-1" href="javascript:upload_video.remove_item(\'' + file.id + '\');" title="<?=lang('video.delete')?>"><span class="mdi mdi-close-thick"></span></a>' + file.name + '</td>' +
								'<td>' + plupload.formatSize(file.size) + '</td>' +
								'<td class="status"><?=lang('video.wait_for_upload')?></td>' +
								'</tr>'
							);
						});
						up.refresh();
					},

					BeforeUpload: function (up, file) {
						up.settings.multipart_params.truename = file.name;
						up.settings.multipart_params.size = file.size;
						$("#upload").attr({"disabled": "disabled"});
					},

					BeforeChunkUpload: function (up, file, post, blob, offset) {
						upload_video.last.time = new Date().getTime();
						upload_video.last.loaded = file.loaded;
					},

					UploadProgress: function (up, file) {
						let elapse_time = (new Date().getTime() - upload_video.last.time) / 1000; //seconds
						let uploaded_size = file.loaded - upload_video.last.loaded;
						let speed = plupload.formatSize(Math.round(uploaded_size / elapse_time));
						$('#plupload_container #' + file.id + " .status").html(file.percent + "% (" + speed + "/s)");
					},

					Error: function (up, err) {
						$("#upload").removeAttr("disabled");
						$("#plupload_container #" + err.file.id + " .status").html(err.message + "(" + err.status + ")");
						layer.msg(err.message);
						up.refresh();
					},

					FileUploaded: function (up, file, res) {
						try {
							let response = JSON.parse(res.response); //An exception may be thrown
							//response = { errid: "1", error: "Uploaded successfully.", token: "5xcryrFbx8KOf7yJC5ooY55lgAf9wRRvQlgpaanf+A7RCy5gZNtJXK8BTXG+LRx5tS++GtWIXgJhiXGMo3wXeNQ0GVQYVLX5HuA7ccNntI0=", truename: "trailer.mp4" }
							if (response.errid === '1') {
								upload_video.uploaded_file.push(JSON.stringify({token: response.token, truename: response.truename}));
							} else {
								$('#plupload_container ' + '#' + file.id + " .status").html("<?=lang('video.upload_failed')?>(" + response.error + ")");
							}
						} catch (ex) {
							$('#plupload_container ' + '#' + file.id + " .status").html("<?=lang('video.invalid_response')?>");
						}
					},

					UploadComplete: function (uploader, files) {
						//tasks
						let values = $('input[name="mars_tasks[]"]:checked').map(function(){
							return $(this).val();
						}).get();
						let tasks = values.join(',');

						//priority
						let priority = $('input[name="mars_priority"]:checked').val();

						$.ajax({
							type: 'POST',
							async: false, //同步请求
							url: '<?=uri2url(admin_module_uri('video/add_trans_task'))?>',
							data: {server_id: <?=$server_id?>, uploaded_file: upload_video.uploaded_file, tasks: tasks, priority: priority},
							success: function (r) {
								if (r.id === 1) {
									let hash_set = $("#hash_set");
									if (Array.isArray(r.data)) {
										$.each(r.data, function (i, obj) {
											if (hash_set.val() === "")
												hash_set.val(obj.hash);
											else
												hash_set.val(hash_set.val() + "," + obj.hash);
											uploaded.add_item(obj.truename, obj.id, obj.hash);
										});
									}
									let files_id = files.map(file => file.id);
									$.each(files_id, function (i, id) {
										upload_video.remove_item(id);
									});
								} else if (r.hasOwnProperty('msg')) {
									layer.msg(r.msg);
								} else {
									layer.msg('<?=lang('app.unknown_error')?>');
								}
							}
						});

						upload_video.uploaded_file = [];
						$("#upload").removeAttr("disabled");
					}

				} //init
			});
			upload_video.plupload.init();
		},
		/**
		 * 移除队列中的项目
		 */
		remove_item: function (file_id) {
			let file_obj = upload_video.plupload.getFile(file_id);
			upload_video.plupload.removeFile(file_obj);
			$("#" + file_id).remove();
			upload_video.plupload.refresh();
			if (upload_video.plupload.files.length <= 0) {
				$("#plupload_container #file_container").html('<tr class="empty"><td colspan="3" class="text-center"><?=lang('video.list_is_empty')?></td></tr>');
			}
		}
	};
	upload_video.new_plupload("<?=$upload['format']?>", "<?=$upload['max_size'] . $upload['max_size_unit']?>", "<?=$upload['chunk_size'] . $upload['chunk_size_unit']?>");

	/**
	 * 已上传文件
	 */
	let uploaded = {
		init_item: function (vid, hash_set) {
			let params = {};
			if (typeof vid == 'number' && vid > 0) params.vid = vid;
			if (typeof hash_set == 'string' && hash_set.length > 0) params.hash_set = hash_set;
			if (!$.isEmptyObject(params)) {
				$.post("<?=uri2url(admin_module_uri('video/get_uploaded_info'))?>", params, function (r) {
					$.each(r, function (i, n) {
						uploaded.add_item(n.truename, n.id, n.hash);
					});
				})
			}
		},
		add_item: function (filename, id, hash) {
			$("#uploaded_container").append(`
				<tr id="hash_${hash}">
					<td>${filename}</td>
					<td>[file:${id}]</td>
					<td><a href="javascript:uploaded.remove_item('${hash}')" class="link-danger text-decoration-none"><?=lang('video.delete')?></a></td>
				</tr>
			`);
		},
		remove_item: function (hash) {
			$.post("<?=uri2url(admin_module_uri('video/delete_file'))?>", {hash: hash}, function (r) {
				if (r.id === 1) {
					//remove hash from hash_set
					let hash_set_input = $("#hash_set");
					let hash_set = hash_set_input.val();
					if (hash_set.length > 0) {
						const set = hash_set.split(',');
						const index = set.indexOf(hash);
						if (index !== -1) {
							set.splice(index, 1);
							hash_set = set.join(',');
							hash_set_input.val(hash_set);
						}
					}
					//remove tr
					$("#hash_" + hash).remove();
				} else if (r.hasOwnProperty('msg')) {
					layer.msg(r.msg);
				} else {
					layer.msg('<?=lang('app.unknown_error')?>');
				}
			})
		}
	}
	uploaded.init_item(<?=phpvod::$app->request->get('id') ?? 0?>, $("#hash_set").val());
</script>

<?php phpvod::$app->view->end_section(); ?>
