-- ----------------------------
-- Table structure for pv_video
-- ----------------------------
DROP TABLE IF EXISTS `pv_video`;
CREATE TABLE `pv_video`
(
	`id`              int(10) UNSIGNED                                        NOT NULL AUTO_INCREMENT COMMENT 'ID',
	`category_id`     smallint(6) UNSIGNED                                    NOT NULL COMMENT '栏目ID',
	`author_id`       int(10) UNSIGNED                                        NOT NULL COMMENT '发布人ID',
	`author`          varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL COMMENT '发布人',
	`author_identity` tinyint(3) UNSIGNED                                     NOT NULL DEFAULT 0 COMMENT '发布人身份：0会员，1管理员',
	`subject`         varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL COMMENT '标题',
	`kind`            tinyint(3) UNSIGNED                                     NOT NULL DEFAULT 0 COMMENT '视频类别：0普通视频，1会员视频，2收费视频',
	`price`           int(10) UNSIGNED                                        NULL     DEFAULT NULL COMMENT '价格，单位分，kind=2时有效',
	`poster`          varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NULL     DEFAULT NULL COMMENT '图片',
	`preview`         varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NULL     DEFAULT NULL COMMENT '视频预览',
	`duration`        int(10) UNSIGNED                                        NULL     DEFAULT NULL COMMENT '时长',
	`hits`            int(10) UNSIGNED                                        NOT NULL DEFAULT 0 COMMENT '点击数',
	`score`           float(3, 1) UNSIGNED                                    NOT NULL DEFAULT 0.0 COMMENT '评分',
	`score_total`     int(10) UNSIGNED                                        NOT NULL DEFAULT 0 COMMENT '总评分',
	`score_count`     int(10) UNSIGNED                                        NOT NULL DEFAULT 0 COMMENT '参与评分的人数',
	`recommend`       tinyint(3) UNSIGNED                                     NOT NULL DEFAULT 0 COMMENT '推荐：0未推荐，1推荐',
	`status`          tinyint(3) UNSIGNED                                     NOT NULL DEFAULT 0 COMMENT '状态：0下架，1上架',
	`created_at`      int(10) UNSIGNED                                        NOT NULL COMMENT '发布时间',
	`updated_at`      int(10) UNSIGNED                                        NOT NULL COMMENT '最后更新时间',
	PRIMARY KEY (`id`) USING BTREE,
	INDEX `status` (`status`) USING BTREE,
	INDEX `category_id` (`category_id`) USING BTREE
) ENGINE = InnoDB
  AUTO_INCREMENT = 1
  CHARACTER SET = utf8
  COLLATE = utf8_unicode_ci
  ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for pv_video_category
-- ----------------------------
DROP TABLE IF EXISTS `pv_video_category`;
CREATE TABLE `pv_video_category`
(
	`id`       smallint(6) UNSIGNED                                    NOT NULL AUTO_INCREMENT COMMENT 'ID',
	`name`     varchar(80) CHARACTER SET utf8 COLLATE utf8_general_ci  NOT NULL COMMENT '类别名称',
	`sort`     smallint(6) UNSIGNED                                    NOT NULL DEFAULT 0 COMMENT '排序',
	`template` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL     DEFAULT NULL COMMENT '模板文件',
	PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  AUTO_INCREMENT = 7
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci
  ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of pv_video_category
-- ----------------------------
INSERT INTO `pv_video_category`
VALUES (1, '电影', 0, NULL);
INSERT INTO `pv_video_category`
VALUES (2, '电视剧', 0, NULL);
INSERT INTO `pv_video_category`
VALUES (3, '动漫', 0, NULL);
INSERT INTO `pv_video_category`
VALUES (4, '综艺', 0, NULL);
INSERT INTO `pv_video_category`
VALUES (5, '网课', 0, NULL);
INSERT INTO `pv_video_category`
VALUES (6, '音乐', 0, NULL);

-- ----------------------------
-- Table structure for pv_video_collect
-- ----------------------------
DROP TABLE IF EXISTS `pv_video_collect`;
CREATE TABLE `pv_video_collect`
(
	`id`          int(10) UNSIGNED                                        NOT NULL COMMENT '视频ID',
	`source_flag` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL COMMENT '来源标识',
	`update_flag` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL COMMENT '更新标识',
	PRIMARY KEY (`id`) USING BTREE,
	INDEX `source_flag` (`source_flag`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_unicode_ci
  ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for pv_video_data
-- ----------------------------
DROP TABLE IF EXISTS `pv_video_data`;
CREATE TABLE `pv_video_data`
(
	`id`      int(10) UNSIGNED                                      NOT NULL COMMENT '视频ID',
	`content` mediumtext CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL COMMENT '视频简介',
	PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_unicode_ci
  ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for pv_video_delay_task
-- ----------------------------
DROP TABLE IF EXISTS `pv_video_delay_task`;
CREATE TABLE `pv_video_delay_task`
(
	`id`      int(10) UNSIGNED                                        NOT NULL AUTO_INCREMENT COMMENT 'ID',
	`action`  varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL COMMENT '任务执行动作',
	`params`  varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NULL DEFAULT NULL COMMENT '参数',
	`result`  varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NULL DEFAULT NULL COMMENT '任务返回值',
	`status`  tinyint(3)                                              NULL DEFAULT 0 COMMENT '状态：-1失败，0未执行，1成功',
	`last_at` int(10) UNSIGNED                                        NULL DEFAULT NULL COMMENT '最后运行时间',
	PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  AUTO_INCREMENT = 1
  CHARACTER SET = utf8
  COLLATE = utf8_unicode_ci
  ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for pv_video_ext
-- ----------------------------
DROP TABLE IF EXISTS `pv_video_ext`;
CREATE TABLE `pv_video_ext`
(
	`id`          int(10) UNSIGNED    NOT NULL COMMENT '视频ID',
	`_type`       tinyint(3) UNSIGNED NULL DEFAULT NULL COMMENT '类型',
	`_area`       tinyint(3) UNSIGNED NULL DEFAULT NULL COMMENT '地区',
	`_discipline` tinyint(3) UNSIGNED NULL DEFAULT NULL COMMENT '学科',
	`_school`     tinyint(3) UNSIGNED NULL DEFAULT NULL COMMENT '学校',
	PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8
  COLLATE = utf8_unicode_ci
  ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for pv_video_field
-- ----------------------------
DROP TABLE IF EXISTS `pv_video_field`;
CREATE TABLE `pv_video_field`
(
	`id`          int(10) UNSIGNED                                                                                           NOT NULL AUTO_INCREMENT COMMENT 'ID',
	`label`       varchar(60) CHARACTER SET utf8 COLLATE utf8_general_ci                                                     NOT NULL COMMENT '标签',
	`field`       varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci                                                     NOT NULL COMMENT '字段名',
	`field_type`  varchar(60) CHARACTER SET utf8 COLLATE utf8_general_ci                                                     NOT NULL COMMENT '字段类型',
	`input_type`  enum ('text','radio','checkbox','select','textarea','textlist') CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '表单类型',
	`required`    tinyint(3) UNSIGNED                                                                                        NOT NULL DEFAULT 0 COMMENT '是否为必填项',
	`category_id` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci                                                    NULL     DEFAULT NULL COMMENT '所属栏目ID，多个ID之间用逗号分开',
	`items`       text CHARACTER SET utf8 COLLATE utf8_general_ci                                                            NULL COMMENT '列表项(JSON)',
	PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  AUTO_INCREMENT = 5
  CHARACTER SET = utf8
  COLLATE = utf8_general_ci
  ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of pv_video_field
-- ----------------------------
INSERT INTO `pv_video_field`
VALUES (1, '类型', '_type', 'tinyint(3) unsigned', 'select', 1, '1',
		'[{\"value\":\"1\",\"label\":\"动作\",\"sort\":1},{\"value\":\"2\",\"label\":\"喜剧\",\"sort\":2},{\"value\":\"3\",\"label\":\"科幻\",\"sort\":3},{\"value\":\"4\",\"label\":\"爱情\",\"sort\":4},{\"value\":\"5\",\"label\":\"战争\",\"sort\":5},{\"value\":\"6\",\"label\":\"恐怖\",\"sort\":6},{\"value\":\"7\",\"label\":\"剧情\",\"sort\":7},{\"value\":\"8\",\"label\":\"其它\",\"sort\":8}]');
INSERT INTO `pv_video_field`
VALUES (2, '地区', '_area', 'tinyint(3) unsigned', 'select', 1, '1,2,3,4,6',
		'[{\"value\":\"1\",\"label\":\"内地\",\"sort\":1},{\"value\":\"2\",\"label\":\"港台\",\"sort\":2},{\"value\":\"3\",\"label\":\"欧美\",\"sort\":3},{\"value\":\"4\",\"label\":\"韩日\",\"sort\":4},{\"value\":\"5\",\"label\":\"其它\",\"sort\":5}]');
INSERT INTO `pv_video_field`
VALUES (3, '学科', '_discipline', 'tinyint(3) unsigned', 'select', 1, '5',
		'[{\"value\":\"1\",\"label\":\"语文\",\"sort\":1},{\"value\":\"2\",\"label\":\"数学\",\"sort\":2},{\"value\":\"3\",\"label\":\"英语\",\"sort\":3},{\"value\":\"4\",\"label\":\"政治\",\"sort\":4},{\"value\":\"5\",\"label\":\"地理\",\"sort\":5},{\"value\":\"6\",\"label\":\"历史\",\"sort\":6},{\"value\":\"7\",\"label\":\"生物\",\"sort\":7},{\"value\":8,\"label\":\"物理\",\"sort\":8},{\"value\":9,\"label\":\"化学\",\"sort\":9}]');
INSERT INTO `pv_video_field`
VALUES (4, '学校', '_school', 'tinyint(3) unsigned', 'select', 1, '5',
		'[{\"value\":1,\"label\":\"长郡中学\",\"sort\":1},{\"value\":2,\"label\":\"雅礼中学\",\"sort\":2},{\"value\":3,\"label\":\"长沙一中\",\"sort\":3},{\"value\":4,\"label\":\"湖南师大附中\",\"sort\":4},{\"value\":5,\"label\":\"其它\",\"sort\":5}]');

-- ----------------------------
-- Table structure for pv_video_file
-- ----------------------------
DROP TABLE IF EXISTS `pv_video_file`;
CREATE TABLE `pv_video_file`
(
	`id`          int(10) UNSIGNED                                        NOT NULL AUTO_INCREMENT COMMENT 'ID',
	`vid`         int(10) UNSIGNED                                        NOT NULL COMMENT '视频ID',
	`hash`        varchar(32) CHARACTER SET utf8 COLLATE utf8_unicode_ci  NOT NULL COMMENT '文件唯一标识',
	`platform`    varchar(30) CHARACTER SET utf8 COLLATE utf8_unicode_ci  NOT NULL COMMENT '平台',
	`file_info`   text CHARACTER SET utf8 COLLATE utf8_unicode_ci         NOT NULL COMMENT '文件信息',
	`remote_key`  varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NULL DEFAULT NULL COMMENT '远程key，通过该值更新remote_data',
	`remote_data` text CHARACTER SET utf8 COLLATE utf8_unicode_ci         NULL COMMENT '远程数据',
	`created_at`  int(10) UNSIGNED                                        NOT NULL COMMENT '文件上传时间',
	PRIMARY KEY (`id`) USING BTREE,
	INDEX `vid` (`vid`) USING BTREE
) ENGINE = InnoDB
  AUTO_INCREMENT = 1
  CHARACTER SET = utf8
  COLLATE = utf8_unicode_ci
  ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for pv_video_mars_map
-- ----------------------------
DROP TABLE IF EXISTS `pv_video_mars_map`;
CREATE TABLE `pv_video_mars_map`
(
	`id`        int(10) UNSIGNED                                        NOT NULL AUTO_INCREMENT COMMENT 'ID',
	`domain`    varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL COMMENT '域名',
	`server_id` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NULL DEFAULT NULL COMMENT '转码服务器ID，多个ID用半角逗号分开',
	PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  AUTO_INCREMENT = 1
  CHARACTER SET = utf8
  COLLATE = utf8_unicode_ci
  ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for pv_video_mars_server
-- ----------------------------
DROP TABLE IF EXISTS `pv_video_mars_server`;
CREATE TABLE `pv_video_mars_server`
(
	`id`         int(10) UNSIGNED                                        NOT NULL AUTO_INCREMENT COMMENT 'ID',
	`name`       varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL COMMENT '服务器名称',
	`ip`         varchar(45) CHARACTER SET utf8 COLLATE utf8_unicode_ci  NOT NULL COMMENT 'IP',
	`port`       smallint(5) UNSIGNED                                    NOT NULL COMMENT '端口',
	`secret_key` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL COMMENT '通信密钥',
	`upload_url` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL COMMENT '上传网址',
	`notify_url` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NULL DEFAULT NULL COMMENT '通知网址',
	`weight`     tinyint(3) UNSIGNED                                     NOT NULL COMMENT '权重',
	PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  AUTO_INCREMENT = 1
  CHARACTER SET = utf8
  COLLATE = utf8_unicode_ci
  ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for pv_video_player
-- ----------------------------
DROP TABLE IF EXISTS `pv_video_player`;
CREATE TABLE `pv_video_player`
(
	`id`          int(10) UNSIGNED                                        NOT NULL AUTO_INCREMENT COMMENT 'ID',
	`name`        varchar(60) CHARACTER SET utf8 COLLATE utf8_unicode_ci  NOT NULL COMMENT '播放器名称',
	`directory`   varchar(60) CHARACTER SET utf8 COLLATE utf8_unicode_ci  NOT NULL COMMENT '播放器目录',
	`class`       varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL COMMENT '类名',
	`description` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NULL     DEFAULT NULL COMMENT '描述',
	`status`      tinyint(3) UNSIGNED                                     NOT NULL DEFAULT 1 COMMENT '状态：1启用，0禁用',
	PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  AUTO_INCREMENT = 2
  CHARACTER SET = utf8
  COLLATE = utf8_unicode_ci
  ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of pv_video_player
-- ----------------------------
INSERT INTO `pv_video_player`
VALUES (1, 'videojs', 'videojs', '\\video\\extension\\player\\videojs\\videojs',
		'The most popular open source HTML5 player framework in the world.', 1);

-- ----------------------------
-- Table structure for pv_video_purchase
-- ----------------------------
DROP TABLE IF EXISTS `pv_video_purchase`;
CREATE TABLE `pv_video_purchase`
(
	`id`         int(10) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT 'ID',
	`member_id`  int(10) UNSIGNED NOT NULL COMMENT '会员ID',
	`video_id`   int(10) UNSIGNED NOT NULL COMMENT '视频ID',
	`created_at` int(10) UNSIGNED NOT NULL COMMENT '时间',
	PRIMARY KEY (`id`) USING BTREE,
	INDEX `member_id_video_id` (`member_id`, `video_id`) USING BTREE,
	INDEX `member_id` (`member_id`) USING BTREE
) ENGINE = InnoDB
  AUTO_INCREMENT = 1
  CHARACTER SET = utf8
  COLLATE = utf8_unicode_ci
  ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for pv_video_slide
-- ----------------------------
DROP TABLE IF EXISTS `pv_video_slide`;
CREATE TABLE `pv_video_slide`
(
	`id`          int(10) UNSIGNED                                        NOT NULL AUTO_INCREMENT COMMENT 'ID',
	`pic`         varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL COMMENT '图片文件名',
	`link`        varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NULL     DEFAULT NULL COMMENT '链接',
	`link_text`   varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NULL     DEFAULT NULL COMMENT '链接文本',
	`title`       varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NULL     DEFAULT NULL COMMENT '标题',
	`description` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NULL     DEFAULT NULL COMMENT '描述',
	`sort`        smallint(6) UNSIGNED                                    NOT NULL DEFAULT 0 COMMENT '排序',
	PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  AUTO_INCREMENT = 3
  CHARACTER SET = utf8
  COLLATE = utf8_unicode_ci
  ROW_FORMAT = Dynamic;

-- ----------------------------
-- Records of pv_video_slide
-- ----------------------------
INSERT INTO `pv_video_slide`
VALUES (1, 'slide_1.jpg', 'https://www.phpvod.com', '查看详情', 'PHPVOD 视频点播系统', '高效便捷、极致性能、全新架构、全新体验', 0);
INSERT INTO `pv_video_slide`
VALUES (2, 'slide_2.jpg', 'https://www.phpvod.com/mars', '查看详情', 'Mars Transcoder 视频转码系统', '支持多线程转码、切片、截图、水印、添加字幕、添加关键帧等。 ', 0);

-- ----------------------------
-- Table structure for pv_video_url
-- ----------------------------
DROP TABLE IF EXISTS `pv_video_url`;
CREATE TABLE `pv_video_url`
(
	`id`         int(10) UNSIGNED                                        NOT NULL AUTO_INCREMENT COMMENT 'ID',
	`vid`        int(10) UNSIGNED                                        NOT NULL COMMENT '视频ID',
	`player`     varchar(60) CHARACTER SET utf8 COLLATE utf8_unicode_ci  NOT NULL COMMENT '播放器名称',
	`url`        text CHARACTER SET utf8 COLLATE utf8_unicode_ci         NOT NULL COMMENT '视频URL',
	`group_name` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NULL DEFAULT NULL COMMENT '组名',
	PRIMARY KEY (`id`) USING BTREE,
	INDEX `vid` (`vid`) USING BTREE
) ENGINE = InnoDB
  AUTO_INCREMENT = 1
  CHARACTER SET = utf8
  COLLATE = utf8_unicode_ci
  ROW_FORMAT = Dynamic;