<?php

namespace video\library;

use video\service\mars;

class options
{
	/**
	 * 字段类型
	 * @return array
	 */
	public static function field_type(): array
	{
		return [
			'varchar(255)' => 'varchar',
			'text' => 'text',
			'tinyint(3)' => 'tinyint',
			'tinyint(3) unsigned' => 'tinyint unsigned',
			'smallint(6)' => 'smallint',
			'smallint(6) unsigned' => 'smallint unsigned',
			'int(10)' => 'int',
			'int(10) unsigned' => 'int unsigned',
			'float' => 'float',
			'float unsigned' => 'float unsigned',
			'double' => 'double',
			'double unsigned' => 'double unsigned',
		];
	}

	/**
	 * 表单类型
	 * @return array
	 */
	public static function input_type(): array
	{
		return [
			'text' => lang('admin.input_text'),
			'textarea' => lang('admin.form_textarea'),
			'textlist' => lang('admin.input_textlist'),
			'radio' => lang('admin.input_radio'),
			'checkbox' => lang('admin.input_checkbox'),
			'select' => lang('admin.form_select'),
		];
	}

	/**
	 * 栏目
	 * @return array
	 */
	public static function category(): array
	{
		return array_column(config::get_instance()->get('category'), 'name', 'id');
	}

	/**
	 * 视频类别
	 * @return array
	 */
	public static function kind(): array
	{
		return [
			'0' => lang('admin.free_video'),
			'1' => lang('admin.member_video'),
			'2' => lang('admin.paid_video'),
		];
	}

	/**
	 * 海报来源
	 * @return array
	 */
	public static function poster_from(): array
	{
		return [
			'0' => lang('app.url'),
			'1' => lang('app.upload')
		];
	}

	/**
	 * 播放器
	 * @return array
	 */
	public static function player(): array
	{
		return array_column(config::get_instance()->get('player'), 'name', 'name');
	}

	/**
	 * 水印位置
	 * @return array
	 */
	public static function watermark_position(): array
	{
		return [
			'1' => lang('admin.top_left'),
			'2' => lang('admin.top_center'),
			'3' => lang('admin.top_right'),
			'4' => lang('admin.middle_left'),
			'5' => lang('admin.middle_center'),
			'6' => lang('admin.middle_right'),
			'7' => lang('admin.bottom_left'),
			'8' => lang('admin.bottom_center'),
			'9' => lang('admin.bottom_right'),
		];
	}

	/**
	 * 视频上传方式
	 * @return array
	 */
	public static function upload(): array
	{
		return [
			'off' => lang('admin.off'),
			'server' => lang('admin.server'),
			'mars_transcoder' => lang('admin.mars_transcoder')
		];
	}

	/**
	 * 转码服务器
	 * @return array
	 */
	public static function mars_server(): array
	{
		return array_column(config::get_instance()->get('mars_server'), 'name', 'id');
	}

	/**
	 * 转码任务标签
	 * @param int $server_id
	 * @return array
	 * @throws \Exception
	 */
	public static function mars_tasks(int $server_id): array
	{
		$mars_service = mars::get_instance_by_server_id($server_id);
		if (!is_null($mars_service)) {
			$tasks = $mars_service->get_tasks();
			if (is_string($tasks)) {
				$tasks = json_decode($tasks, true);
				return array_column($tasks, 'tag', 'tag');
			}
		}
		return [];
	}

	/**
	 * 转码优先级
	 * @return array
	 */
	public static function mars_priority(): array
	{
		return [
			0 => lang('video.low'),
			1 => lang('video.high')
		];
	}
}
