<?php

namespace video\model;

use video\library\config;

class category extends \phpvod\base\model
{
	protected string $table = 'pv_video_category';
	protected ?string $primary_key = 'id';
	protected array $allowed_fields = ['name', 'sort', 'template'];

	/**
	 * 获取数据
	 * @param array $params 查询参数，包含search/order_by/offset_limit元素(非null即可用)
	 * @return array
	 */
	public function get_data(array $params): array
	{
		//where
		if (!is_null($params['search'])) {
			$this->where('name LIKE :name', ['name' => '%' . $params['search'] . '%']);
		}

		$total = (int)$this->select('count(id)')->query(false)->fetch_column();

		//order by
		if(!is_null($params['order_by'])) {
			$this->order_by($params['order_by']);
		}

		//offset_limit
		if(!is_null($params['offset_limit'])) {
			$this->limit($params['offset_limit']);
		}

		$rows = $this->select('*')->query()->fetch_all_by_callback(function (array $row) {
			$row['field'] = $this->get_field_by_category_id($row['id']);
			return $row;
		});
		return ['total' => $total, 'rows' => $rows];
	}

	private function get_field_by_category_id(int $category_id): array
	{
		static $data = null;
		if (is_null($data)) {
			$data = [];
			$fields = config::get_instance()->get('field');
			foreach ($fields as $field) {
				if(empty($field['category_id'])) {
					continue;
				}
				$label = \phpvod::$app->language->key_is_exists('pv_video_ext.' . $field['field']) ? lang('pv_video_ext.' . $field['field']) : $field['label'];
				foreach ($field['category_id'] as $value) {
					$data[$value][] = $label;
				}
			}
		}
		return isset($data[$category_id]) && is_array($data[$category_id]) ? $data[$category_id] : [];
	}
}