<?php

namespace video\model;

use video\library\config;

class field extends \phpvod\base\model
{
	protected string $table = 'pv_video_field';
	protected ?string $primary_key = 'id';
	protected array $allowed_fields = ['label', 'field', 'field_type', 'input_type', 'required', 'category_id', 'items'];

	/**
	 * 新增字段
	 * @param array $data 字段信息数组
	 * @return bool
	 */
	public function add_field(array $data): bool
	{
		try {
			$this->db->exec("ALTER TABLE pv_video_ext ADD COLUMN `{$data['field']}` {$data['field_type']} NULL COMMENT '{$data['label']}'");
		} catch (\Exception $exception) {
			return false;
		}

		$affected_rows = $this->insert($data);
		if ($affected_rows == 0) {
			$this->db->exec("ALTER TABLE pv_video_ext DROP COLUMN {$data['field']}"); //ROLLBACK
			return false;
		}

		return true;
	}

	public function edit_field(array $data): bool
	{
		$field = $this->find($data['id'])->fetch_array();
		if ($field === false)
			return false;

		try {
			if ($data['field'] != $field['field'] || $data['label'] != $field['label']) {
				$this->db->exec("ALTER TABLE pv_video_ext CHANGE COLUMN `{$field['field']}` `{$data['field']}` {$field['field_type']} NULL COMMENT '{$data['label']}'");
			}
		} catch (\Exception $exception) {
			return false;
		}

		$this->save($data);
		return true;
	}

	/**
	 * 删除字段
	 * @param int $id
	 * @return bool
	 * @throws \Exception
	 */
	public function delete_field(int $id): bool
	{
		$field = $this->select('field')->find($id)->fetch_column();
		if ($field === false) {
			return false;
		}

		try {
			$info = $this->db->query("SHOW COLUMNS FROM pv_video_ext LIKE '$field'")->fetch_array();
			if (is_array($info)) {
				$this->db->exec("ALTER TABLE pv_video_ext DROP COLUMN `$field`");
			}
		} catch (\Exception $exception) {
			return false;
		}

		$this->delete($id);
		return true;
	}

	public function remove_category_id(int $id): void
	{
		$this->db->exec("UPDATE pv_video_field SET category_id = TRIM(BOTH ',' FROM REPLACE(CONCAT(',', category_id, ','), CONCAT(',', '$id', ','), ',')) WHERE FIND_IN_SET('$id', category_id) > 0");
	}

	/**
	 * 获取数据
	 * @param array $params
	 * @return array
	 */
	public function get_data(array $params): array
	{
		//where
		if (!is_null($params['search'])) {
			$this->where('label LIKE :label OR field LIKE :field', [
				'label' => '%' . $params['search'] . '%',
				'field' => '%' . $params['search'] . '%',
			]);
		}


		$total = (int)$this->select('count(id)')->query(false)->fetch_column();

		//order by
		if(!is_null($params['order_by'])) {
			$this->order_by($params['order_by']);
		}

		//offset_limit
		if(!is_null($params['offset_limit'])) {
			$this->limit($params['offset_limit']);
		}

		//load category cache
		$category = config::get_instance()->get('category');

		$rows = $this->select('*')->query()->fetch_all_by_callback(function (array $row) use ($category) {
			if (!is_null($row['category_id'])) {
				$ids = explode(',', $row['category_id']);
				$row['category_id'] = array_map(function (int $id) use ($category) {
					return isset($category[$id]) ? $category[$id]['name'] : null;
				}, $ids);
			}
			return $row;
		});

		return ['total' => $total, 'rows' => $rows];
	}
}