<?php

namespace video\model;

use video\library\config;

class mars_map extends \phpvod\base\model
{
	protected string $table = 'pv_video_mars_map';
	protected ?string $primary_key = 'id';
	protected array $allowed_fields = ['domain', 'server_id'];

	/**
	 * 获取数据
	 * @param array $params 查询参数，包含search/order_by/offset_limit元素(非null即可用)
	 * @return array
	 */
	public function get_data(array $params): array
	{
		//where
		if (!is_null($params['search'])) {
			$this->where('domain LIKE :domain', ['domain' => '%' . $params['search'] . '%']);
		}

		$total = (int)$this->select('count(id)')->query(false)->fetch_column();

		//order by
		if (!is_null($params['order_by'])) {
			$this->order_by($params['order_by']);
		}

		//offset_limit
		if (!is_null($params['offset_limit'])) {
			$this->limit($params['offset_limit']);
		}

		$mars_server = config::get_instance()->get('mars_server');

		$rows = $this->select('*')->query()->fetch_all_by_callback(function (array $row) use ($mars_server) {
			$row['server'] = [];
			if (is_string($row['server_id']) && trim($row['server_id']) != '') {
				$ids = explode(',', $row['server_id']);
				foreach ($ids as $id) {
					isset($mars_server[$id]) && $row['server'][] = $mars_server[$id]['name'];
				}
			}
			return $row;
		});

		return ['total' => $total, 'rows' => $rows];
	}

	public function remove_server_id(int $id): void
	{
		$this->db->exec("UPDATE pv_video_mars_map SET server_id = TRIM(BOTH ',' FROM REPLACE(CONCAT(',', server_id, ','), CONCAT(',', '$id', ','), ',')) WHERE FIND_IN_SET('$id', server_id) > 0");
	}
}
