<?php

namespace video\model;

use phpvod\widget\form\admin_form;
use video\library\config;

class video extends \phpvod\base\model
{
	protected string $table = 'pv_video';
	protected ?string $primary_key = 'id';
	protected array $allowed_fields = ['category_id', 'author_id', 'author', 'author_identity', 'subject', 'kind', 'price', 'poster', 'preview', 'duration', 'hits', 'score', 'score_total', 'score_count', 'recommend', 'status', 'created_at', 'updated_at'];
	protected ?string $created_field = 'created_at';
	protected ?string $updated_field = 'updated_at';

	/**
	 * 获取数据
	 * @param array $params 查询参数，包含search/order_by/offset_limit元素(非null即可用)
	 * @return array
	 */
	public function get_data(array $params): array
	{
		$category = config::get_instance()->get('category');

		//category_id
		if (isset($params['category_id']) && is_numeric($params['category_id'])) {
			$this->where(['category_id' => $params['category_id']]);
		}
		//kind
		if (isset($params['kind']) && is_numeric($params['kind'])) {
			$this->where(['kind' => $params['kind']]);
		}
		//subject
		if(isset($params['subject'])) {
			$this->where('subject LIKE :subject', ['subject' => '%' . $params['subject'] . '%']);
		}
		//author
		if(isset($params['author'])) {
			$this->where(['author' => $params['author']]);
		}
		//recommend
		if (isset($params['recommend']) && is_numeric($params['recommend'])) {
			$this->where(['recommend' => $params['recommend']]);
		}
		//status
		if (isset($params['status']) && is_numeric($params['status'])) {
			$this->where(['status' => $params['status']]);
		}

		$total = (int)$this->select('count(id)')->query(false)->fetch_column();

		//order by
		if(!is_null($params['order_by'])) {
			$this->order_by($params['order_by']);
		}

		//offset_limit
		if(!is_null($params['offset_limit'])) {
			$this->limit($params['offset_limit']);
		}

		$rows = $this->select('*')->query()->fetch_all_by_callback(function (array $row) use ($category) {
			$row['category'] = $category[$row['category_id']]['name'] ?? null;
			$row['duration'] = is_numeric($row['duration']) ? seconds2duration($row['duration']) : null;
			$row['recommend'] = admin_form::get_instance()->switch((boolean)$row['recommend'], ['class' => 'form-check-input', 'role' => 'recommend-switch', 'value' => '1']);
			$row['status'] = admin_form::get_instance()->switch((boolean)$row['status'], ['class' => 'form-check-input', 'role' => 'status-switch', 'value' => '1']);
			$row['created_at'] = timetostr($row['created_at']);
			$row['updated_at'] = timetostr($row['updated_at']);
			return $row;
		});

		return ['total' => $total, 'rows' => $rows];
	}

	/**
	 * 更新视频状态
	 * @param int $id 视频ID
	 * @return int|false 成功返回更新后的状态，失败返回false
	 * @throws \Exception
	 */
	public function change_status(int $id): int|false
	{
		$this->update(['status' => 'CASE status WHEN 0 THEN 1 ELSE 0 END'], $id, ['status']);
		$row = $this->select("status")->find($id)->fetch_array();
		return is_array($row) ? (int)$row['status'] : false;
	}

	/**
	 * 更新视频推荐
	 * @param int $id 视频ID
	 * @return int|false 成功返回更新后的推荐值，失败返回false
	 * @throws \Exception
	 */
	public function change_recommend(int $id): int|false
	{
		$this->update(['recommend' => 'CASE recommend WHEN 0 THEN 1 ELSE 0 END'], $id, ['recommend']);
		$row = $this->select("recommend")->find($id)->fetch_array();
		return is_array($row) ? (int)$row['recommend'] : false;
	}
}