<?php

namespace video\model;

class video_file extends \phpvod\base\model
{
	protected string $table = 'pv_video_file';
	protected ?string $primary_key = 'id';
	protected array $allowed_fields = ['vid', 'hash', 'platform', 'file_info', 'remote_key', 'remote_data', 'created_at'];
	protected ?string $created_field = 'created_at';

	/**
	 * 获取已上传的文件信息
	 * @param ?int $vid 视频id
	 * @param ?string $hash_set 新记录hash集合(vid=0),多个hash之间用半角逗号分开
	 * @return array
	 * @throws \Exception
	 */
	public function get_uploaded_info(?int $vid, ?string $hash_set): array
	{
		$set_where = false;

		if (is_int($vid) && $vid > 0) {
			$this->where("vid=$vid");
			$set_where = true;
		}

		if (is_string($hash_set) && trim($hash_set) != '') {
			$set = explode(',', $hash_set);
			$this->or_group_start()->where("vid=0")->where_in('hash', $set)->group_end();
			$set_where = true;
		}

		if (!$set_where) return [];

		return $this->select('*')->query()
			->fetch_all_by_callback(function (array $row) {
				$file_info = json_decode($row['file_info'], true);
				return [
					'id' => $row['id'],
					'hash' => $row['hash'],
					'truename' => $file_info['truename'],
				];
			});
	}

	/**
	 * 绑定vid
	 * @param string $hash_set
	 * @param int $vid
	 * @return void
	 */
	public function bind_vid(string $hash_set, int $vid): void
	{
		if (empty($hash_set)) {
			return;
		}
		$hash_set = explode(',', $hash_set);
		$this->where('vid=0')->where_in('hash', $hash_set)->update(['vid' => $vid]);
	}
}