<?php

namespace video\service;

use video\model\video_file;
use video\model\delay_task;

class file
{
	private video_file $video_file_model;
	private delay_task $delay_task_model;

	/** @noinspection PhpFieldAssignmentTypeMismatchInspection */
	public function __construct()
	{
		helper('file_system');
		$this->video_file_model = model(video_file::class);
		$this->delay_task_model = model(delay_task::class);
	}

	/**
	 * 通过hash_set激活转码任务
	 * @param string $hash_set
	 * @return void
	 * @throws \Exception
	 */
	public function active_task_by_hash_set(string $hash_set): void
	{
		if (empty($hash_set)) {
			return;
		}
		$hash_set = explode(',', $hash_set);
		$rows = $this->video_file_model->select('platform,remote_key')->where_in('hash', $hash_set)->query()->fetch_all_array();
		foreach ($rows as $row) {
			if ($row['platform'] == 'mars_transcoder' && !empty($row['remote_key'])) {
				[$server_id, $tid] = explode('_', $row['remote_key']);
				$mars_service = mars::get_instance_by_server_id($server_id);
				if (!is_null($mars_service) && !$mars_service->active_task($tid)) {
					$this->delay_task_model->add('active_task', formatter(['server_id' => $server_id, 'tid' => $tid]));
				}
			}
		}
	}

	/**
	 * 通过hash删除记录与文件
	 * @param string $hash hash
	 * @return array
	 * @throws \Exception
	 */
	public function delete_by_hash(string $hash): array
	{
		$row = $this->video_file_model->where(['hash' => $hash])->query()->fetch_array();
		if (!is_array($row)) {
			return ['id' => 0, 'msg' => lang('video.invalid_hash')];
		}

		//delete file
		$this->delete($row);

		//delete record
		$this->video_file_model->delete($row['id']);
		return ['id' => 1, 'msg' => lang('app.operation_succeeded')];
	}

	/**
	 * 删除数据库记录关联的文件，失败时添加至延迟任务
	 * @param array $row
	 * @return void
	 * @throws \Exception
	 */
	public function delete(array $row): void
	{
		if (!isset($row['platform'])) {
			return;
		}

		if ($row['platform'] == 'server' && isset($row['file_info'])) {
			$data = json_decode($row['file_info'], true);
			if (isset($data['file']) && is_file($data['file'])) {
				$result = remove_file($data['file']);
				if ($result === false) {
					$this->delay_task_model->add('remove_file', $data['file']);
				}
			}
		} elseif ($row['platform'] == 'mars_transcoder' && isset($row['remote_key'])) {
			[$server_id, $tid] = explode('_', $row['remote_key']);
			$mars_service = mars::get_instance_by_server_id($server_id);
			if (!is_null($mars_service)) {
				$response = $mars_service->del_task($tid);
				if ($response === false) {
					$this->delay_task_model->add('del_task', formatter(['server_id' => $server_id, 'tid' => $tid]));
				} elseif (is_string($response)) {
					$data = json_decode($response, true);
					if ($data['code'] != '1') {
						$this->delay_task_model->add('del_task', formatter(['server_id' => $server_id, 'tid' => $tid]));
					}
				}
			}
		}
	}

	/**
	 * 清理无效文件
	 * @return void
	 * @throws \Exception
	 */
	public function cleanup(): void
	{
		$cleanup_probability = 10; //执行清除操作的机率(取值范围：0-100)
		$max_file_age = 6 * 3600; //文件超时时间
		$rand = mt_rand(1, 100);
		if ($rand <= $cleanup_probability) {
			$rows = $this->video_file_model->select('id,platform,file_info,remote_key,remote_data')->where('vid=0 AND created_at<' . (TIMESTAMP - $max_file_age))->query()->fetch_all_array();
			foreach ($rows as $row) {
				$this->delete($row);
				$this->video_file_model->delete($row['id']);
			}
		}
	}
}