<?php

namespace video\service;

use phpvod\library\image;
use venus\http\file\uploaded_file;
use video\library\config;

class poster
{
	public function __construct()
	{
		helper('file_system');
	}

	/**
	 * 更新海报(url)
	 * @param int $vid 视频ID
	 * @param string $url URL
	 * @return void
	 * @throws \Exception
	 */
	public function update_url(int $vid, string $url): void
	{
		is_blank($url) && $url = null;
		/**
		 * @var \video\model\video $video_model
		 */
		$video_model = model(\video\model\video::class);
		$old_poster = $video_model->select('poster')->find($vid)->fetch_column();
		if ($old_poster != $url) {
			//update
			$video_model->update(['poster' => $url], $vid);
			//remove redundant poster
			$this->delete($old_poster);
		}
	}

	/**
	 * 更新海报(file)
	 * @param int $vid 视频ID
	 * @param uploaded_file $file 上传的文件
	 * @return void
	 * @throws \Exception
	 */
	public function update_file(int $vid, uploaded_file $file): void
	{
		if ($file->is_valid()) {
			//path
			$relative_path = $this->get_poster_relative_path();
			$absolute_path = $this->get_poster_absolute_path($relative_path);
			if (!is_dir($absolute_path)) {
				create_directory($absolute_path);
			}
			//file
			$extension = $file->get_extension();
			$filename = $vid . ($extension != '' ? '.' . $extension : '');
			$file->move($absolute_path, $filename);

			//resize and watermark
			$this->image_resize_and_watermark($absolute_path . '/' . $filename);

			/**
			 * @var \video\model\video $video_model
			 */
			$video_model = model(\video\model\video::class);
			$old_poster = $video_model->select('poster')->find($vid)->fetch_column();
			$new_poster = $relative_path . '/' . $filename;
			//update
			$video_model->update(['poster' => $new_poster], $vid);
			//remove redundant poster
			$old_poster != $new_poster && $this->delete($old_poster);
		}
	}

	/**
	 * 删除海报
	 * @param string|null $poster 海报文件路径
	 * @return void
	 */
	public function delete(?string $poster): void
	{
		if (is_null($poster) || is_blank($poster) || is_http_url($poster))
			return;

		$file = $this->get_poster_absolute_path($poster);
		is_file($file) && remove_file($file);
	}

	/**
	 * 获取海报存储相对路径
	 * @return string
	 */
	private function get_poster_relative_path(): string
	{
		return 'upload/video/poster/' . timetostr(TIMESTAMP, 'Ym');
	}


	/**
	 * 获取海报存储绝对路径
	 * @param string $relative_path 相对路径
	 * @return string
	 */
	private function get_poster_absolute_path(string $relative_path): string
	{
		return WRITABLE_PATH . $relative_path;
	}

	/**
	 * 生成海报缩略图及添加水印
	 * @param string $poster
	 * @return void
	 * @throws \Exception
	 */
	private function image_resize_and_watermark(string $poster): void
	{
		$config = config::get_instance()->get('image');
		if (is_file($poster) && ($config['create_thumb'] == '1' || $config['create_watermark'] == '1')) {
			/**
			 * @var image $image
			 */
			$image = create_object(image::class, []);
			$image->open($poster);

			//thumb
			if ($config['create_thumb'] == '1') {
				$image->resize($config['width'], $config['height']);
			}

			//watermark
			if ($config['create_watermark'] == '1') {
				$watermark = WRITABLE_PATH . 'upload/video/watermark/' . $config['watermark_file'];
				if (is_file($watermark)) {
					$image->watermark($watermark, $config['watermark_position']);
				}
			}

			$image->save($poster);
		}
	}
}