<?php

namespace video\service;

class transaction
{
	protected \venus\database\database $db;

	public function __construct()
	{
		$this->db = \phpvod::$app->database;
	}

	/**
	 * 购买视频
	 * @param int $id
	 * @return array
	 * @throws \Exception
	 */
	public function buy_video(int $id): array
	{
		$identity = \phpvod::$app->user_auth->get_frontend_identity();
		if (!is_array($identity)) {
			return ['id' => 0, 'msg' => lang('app.please_login_first')];
		}

		/* @var \video\model\video $video_model */
		$video_model = model(\video\model\video::class);
		$video = $video_model->select('subject,kind,price')->find($id)->fetch_array();
		if (empty($video)) {
			return ['id' => 0, 'msg' => lang('app.invalid_id')];
		}

		//check kind&price
		if ($video['kind'] != '2') {
			return ['id' => 0, 'msg' => lang('home.no_need_to_buy')];
		}

		//check purchase
		/* @var \video\model\purchase $purchase_model */
		$purchase_model = model(\video\model\purchase::class);
		$count = (int)$purchase_model->select('count(id)')->where(['member_id' => $identity['id'], 'video_id' => $id])->query()->fetch_column();
		if ($count >= 1) {
			return ['id' => 0, 'msg' => lang('home.no_need_to_repeat_purchase')];
		}

		//check balance
		$discount = floatval(get_permission('video:video_purchase_discount')); //折扣
		$discount_price = ceil($video['price'] * $discount); //折后价
		if ($identity['balance'] < $discount_price) {
			return ['id' => 0, 'msg' => lang('app.insufficient_balance')];
		}

		//buy video
		$this->db->begin_transaction();
		try {
			//member
			/* @var \phpvod\model\member $member_model */
			$member_model = model(\phpvod\model\member::class);
			$member_model->update(['balance' => 'balance-' . $discount_price], $identity['id'], ['balance']);
			//purchase
			$purchase_model->insert(['member_id' => $identity['id'], 'video_id' => $id]);
			//transaction_history
			/* @var \phpvod\model\transaction_history $transaction_history_model */
			$transaction_history_model = model(\phpvod\model\transaction_history::class);
			$transaction_history_model->insert([
				'member_id' => $identity['id'],
				'type' => \phpvod\model\transaction_history::TYPE_EXPENDITURE,
				'action' => 'buy_video',
				'related' => $video['subject'],
				'amount' => $discount_price,
				'data' => formatter(['video_id' => $id, 'price' => $video['price'], 'discount_price' => $discount_price])
			]);
		} catch (\Exception) {
			$this->db->roll_back();
			return ['id' => 0, 'msg' => lang('app.operation_failed')];
		}

		return $this->db->commit() ? ['id' => 1, 'msg' => lang('app.purchase_succeeds')] : ['id' => 0, 'msg' => lang('app.operation_failed')];
	}
}