<?php

namespace video\tag;

use video\library\config;

class field
{
	private array $field = [];

	public function __construct()
	{
		$field = config::get_instance()->get('field');
		is_array($field) && $this->field = $field;
	}

	/**
	 * 字段列表
	 * @param int $category_id 栏目ID
	 * @param array $extra_data 附加数据，格式：
	 * <code>[['field'=>'order', 'label'=>'排序', 'items'=>[['value'=>'create_at', 'label'=>'最新'], ['value'=>'hits', 'label'=>'最热'], ...]], ...]</code>
	 * @return array
	 */
	public function fetch(int $category_id, array $extra_data = []): array
	{
		$list = [];

		$data = $this->field + $extra_data;
		foreach ($data as $field) {
			if ((array_key_exists('category_id', $field) && !in_array($category_id, $field['category_id'])) ||
				(array_key_exists('input_type', $field) && !in_array($field['input_type'], ['select', 'radio', 'checkbox']))) {
				continue;
			}

			$get = $_GET;
			unset($get['page']);
			$field_name = $field['field'];
			$active = $get[$field_name] ?? null;
			$items = [];
			foreach ($field['items'] as $item) {
				//set value
				$get[$field_name] = $item['value'];
				//items
				$items[] = [
					'value' => $item['value'],
					'label' => $item['label'],
					'query' => http_build_query($get),
				];
			}

			//exclude_query
			unset($get[$field_name]);
			$query = http_build_query($get);

			$list[] = ['field' => $field['field'], 'label' => $field['label'], 'query' => $query, 'active' => $active, 'items' => $items];
		}

		return $list;
	}

	/**
	 * 获取ext参数值
	 * @param int|null $category_id
	 * @return array
	 */
	public function get_ext_param(?int $category_id = null): array
	{
		$ext = [];
		$get = $_GET;
		foreach ($this->field as $field) {
			$field_name = $field['field'];
			if ((is_int($category_id) && !in_array($category_id, $field['category_id'])) || !isset($get[$field_name]))
				continue;

			$key = match ($field['input_type']) {
				'select', 'radio' => $field_name,
				'checkbox', 'textlist' => $field_name . '*',
				'text', 'textarea' => $field_name . '%'
			};
			$ext[$key] = $get[$field_name];
		}
		return $ext;
	}
}