<?php

use phpvod\library\options;

phpvod\asset\jquery_tagsinput\jquery_tagsinput::register();

/**
 * @var \phpvod\widget\form\admin_form $form
 * @var \venus\view\view $this
 * @var array $config
 */
$form = \phpvod\widget\form\admin_form::get_instance();
$this->extend('admin/layout');
$config = old('config', $config);
?>

<?php $this->section('content'); ?>


<div class="card">
	<div class="card-header"><?= lang('admin.settings') ?></div>
	<div class="card-body">

		<?php $this->set_vars(['active' => 'image'])->include('admin/config/_tabs');?>

		<div class="tab-content p-4">
			<div id="image-tab-pane" class="tab-pane fade show active">
				<?= form_open(admin_module_uri('config/image')) ?>
				<div class="row mb-4">
					<label class="col-md-2 col-form-label text-md-end"><?= lang('admin.image_format') ?></label>
					<div class="col-md-6">
						<?= $form->input('config[format]', 'text', $config['format'], ['class' => 'form-control', 'id' => 'format']) ?>
					</div>
				</div>
				<div class="row mb-4">
					<label class="col-md-2 col-form-label text-md-end" for="max-size"><?= lang('admin.image_max_size') ?></label>
					<div class="col-md-6">
						<div class="input-group">
							<?= $form->input('config[max_size]', 'text', $config['max_size'], ['class' => 'form-control', 'id' => 'max-size']) ?>
							<?= $form->select('config[max_size_unit]', options::disk_unit(), $config['max_size_unit'], ['class' => 'form-select']) ?>
						</div>
					</div>
				</div>
				<div class="row mb-4">
					<label class="col-md-2 col-form-label text-md-end"><?= lang('admin.image_create_thumb') ?></label>
					<div class="col-md-6">
						<?= $form->radio_group('config[create_thumb]', options::open_close(), $config['create_thumb'], ['class' => 'form-check-input']) ?>
					</div>
				</div>
				<div id="thumb" class="f-d-n">
					<div class="row mb-4">
						<label class="col-md-2 col-form-label text-md-end" for="width"><?= lang('admin.image_width') ?></label>
						<div class="col-md-6">
							<div class="input-group">
								<input type="text" class="form-control" id="width" name="config[width]" value="<?= $config['width'] ?>">
								<span class="input-group-text">px</span>
							</div>
						</div>
					</div>
					<div class="row mb-4">
						<label class="col-md-2 col-form-label text-md-end" for="height"><?= lang('admin.image_height') ?></label>
						<div class="col-md-6">
							<div class="input-group">
								<input type="text" class="form-control" id="height" name="config[height]" value="<?= $config['height'] ?>">
								<span class="input-group-text">px</span>
							</div>
						</div>
					</div>
				</div>
				<div class="row mb-4">
					<label class="col-md-2 col-form-label text-md-end"><?= lang('admin.image_create_watermark') ?></label>
					<div class="col-md-6">
						<?= $form->radio_group('config[create_watermark]', options::open_close(), $config['create_watermark'], ['class' => 'form-check-input']) ?>
					</div>
				</div>
				<div id="watermark" class="f-d-n">
					<div class="row mb-4">
						<label class="col-md-2 col-form-label text-md-end" for="watermark_file"><?= lang('admin.image_watermark_file') ?></label>
						<div class="col-md-6">
							<?php if(is_file(WRITABLE_PATH . 'upload/video/watermark/' . $config['watermark_file'])): ?>
								<img src="upload/video/watermark/<?=$config['watermark_file']?>" class="img-fluid mb-1" />
							<?php else: ?>
								<div class="alert alert-danger" role="alert">水印文件不存在</div>
							<?php endif; ?>
							<div class="input-group">
								<span class="input-group-text"><?= WRITABLE_PATH . 'upload' . DIRECTORY_SEPARATOR . 'video' . DIRECTORY_SEPARATOR . 'watermark' . DIRECTORY_SEPARATOR ?></span>
								<?= $form->input('config[watermark_file]', 'text', $config['watermark_file'], ['class' => 'form-control', 'id' => 'watermark_file']) ?>
							</div>
						</div>
					</div>
					<div class="row mb-4">
						<label class="col-md-2 col-form-label text-md-end"><?= lang('admin.image_watermark_position') ?></label>
						<div class="col-md-6">
							<?= $form->select('config[watermark_position]', \video\library\options::watermark_position(), $config['watermark_position'], ['class' => 'form-select']) ?>
						</div>
					</div>
				</div>
				<div class="row">
					<div class="col-md-6 offset-md-2">
						<button class="btn btn-primary" type="submit"><?= lang('app.save') ?></button>
					</div>
				</div>
				<?= form_close() ?>
			</div>
		</div>

	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>
<?php $this->end_section(); ?>

<?php $this->section('js'); ?>
<script type="text/javascript">
    $("#format").tagsInput({
        'height':'35px',
        'width':'100%',
        'interactive': true,
        'defaultText': '<?=lang('app.add')?>',
        'delimiter': [','],
        'removeWithBackspace': true,
        'minChars': 0,
        'maxChars': 0, // if not provided there is no limit
    });
    bindPanel("config[create_thumb]", [{"id": "thumb", "value": "1"}]);
    bindPanel("config[create_watermark]", [{"id": "watermark", "value": "1"}]);
</script>
<?php $this->end_section(); ?>
