<?php
/**
 * @var \venus\view\view $this
 */

use video\library\options;

$form = \phpvod\widget\form\admin_form::get_instance();
$this->extend('admin/layout');
$field = old('field', []);
?>
<?php $this->section('content'); ?>

<div class="card">
	<div class="card-header"><?= lang('admin.add_field') ?></div>
	<div class="card-body">
		<?= form_open(admin_module_uri('field/add')) ?>
		<div class="row mb-4">
			<label class="col-md-2 col-form-label text-md-end" for="label"><?= lang('pv_video_field.label') ?></label>
			<div class="col-md-6">
				<input class="form-control" type="text" id="label" name="field[label]" value="<?= $field['label'] ?? '' ?>">
			</div>
		</div>
		<div class="row mb-4">
			<label class="col-md-2 col-form-label text-md-end" for="field">
				<?= lang('pv_video_field.field') ?>
				<?= $form->tips(lang('admin.tips_field')) ?>
			</label>
			<div class="col-md-3">
				<input class="form-control" type="text" id="field" name="field[field]" value="<?= $field['field'] ?? '' ?>">
			</div>
			<div class="col-md-3">
				<?= $form->select('field[field_type]', options::field_type(), $field['field_type'] ?? null, ['class' => 'form-select']) ?>
			</div>
		</div>
		<div class="row mb-4">
			<label class="col-md-2 col-form-label text-md-end">
				<?= lang('pv_video_field.input_type') ?>
			</label>
			<div class="col-md-6">
				<?= $form->select('field[input_type]', options::input_type(), $field['input_type'] ?? null, ['id' => 'input_type', 'class' => 'form-select']) ?>
			</div>
		</div>

		<!-- items -->
		<div id="items" class="f-d-n">
			<div class="row mb-4">
				<label class="col-md-2 col-form-label text-md-end">
					<?= lang('pv_video_field.items') ?>
				</label>
				<div class="col-md-6">
					<table id="key-value-table" class="table table-sm align-middle mb-0">
						<thead>
						<tr>
							<th class="w-25"><?= lang('admin.value') ?></th>
							<th class="w-25"><?= lang('admin.label') ?></th>
							<th class="w-25"><?= lang('admin.sort') ?> <?= $form->tips(lang('admin.tips_sort')) ?></th>
							<th class="w-25"><?= lang('app.operation') ?></th>
						</tr>
						</thead>
						<tbody>

						<?php
						if (isset($field['items']['value']) && is_array($field['items']['value'])): foreach ($field['items']['value'] as $key => $value):
							?>
							<tr>
								<td><input class="form-control form-control-sm" type="text" name="field[items][value][]" value="<?= $value ?>"></td>
								<td><input class="form-control form-control-sm" type="text" name="field[items][label][]"
								           value="<?= $field['items']['label'][$key] ?>"></td>
								<td><input class="form-control form-control-sm" type="text" name="field[items][sort][]"
								           value="<?= $field['items']['sort'][$key] ?>"></td>
								<td>
									<button type="button" onclick="remove_item(this)" class="btn btn-outline-danger px-1 py-0">
										<i class="mdi mdi-window-close me-1"></i><?= lang('app.delete') ?>
									</button>
								</td>
							</tr>
						<?php endforeach; endif; ?>

						</tbody>
						<tfoot>
						<td colspan="3">
							<button type="button" onclick="add_item()" class="btn btn-outline-success px-1 py-0">
								<i class="mdi mdi-plus me-1"></i><?= lang('app.add') ?>
							</button>
						</td>
						</tfoot>
					</table>
				</div>
			</div>
		</div>

		<div class="row mb-4">
			<label class="col-md-2 col-form-label text-md-end">
				<?= lang('admin.belong_to') ?>
			</label>
			<div class="col-md-6">
				<?= $form->checkbox_group('field[category_id][]', options::category(), $field['category_id'] ?? [], ['class' => 'form-check-input']) ?>
			</div>
		</div>
		<div class="row mb-4">
			<label class="col-md-2 col-form-label text-md-end">
				<?= lang('pv_video_field.required') ?>
			</label>
			<div class="col-md-6">
				<?= $form->radio_group('field[required]', \phpvod\library\options::yes_no(), $field['required'] ?? 0, ['class' => 'form-check-input']) ?>
			</div>
		</div>
		<div class="row">
			<div class="col-md-6 offset-md-2">
				<button class="btn btn-primary" type="submit"><?= lang('app.save') ?></button>
			</div>
		</div>
		<?= form_close() ?>
	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>

<?php $this->end_section(); ?>

<?php $this->section('js'); ?>
<script type="text/javascript">
	let panel_list = [{"id": "items", "value": ["radio", "checkbox", "select"]}];
	bindPanel("field[input_type]", panel_list, 'select');

	function add_item() {
		let template = '<tr>' +
			'<td><input class="form-control form-control-sm" type="text" name="field[items][value][]"></td>' +
			'<td><input class="form-control form-control-sm" type="text" name="field[items][label][]"></td>' +
			'<td><input class="form-control form-control-sm" type="text" name="field[items][sort][]"></td>' +
			'<td><button type="button" onclick="remove_item(this)" class="btn btn-outline-danger px-1 py-0"><i class="mdi mdi-window-close me-1"></i><?=lang('app.delete')?></button></td>' +
			'</tr>';
		$("#key-value-table").find('tbody').append(template);
	}

	function remove_item(btn) {
		$(btn).parents('tr').remove();
	}
</script>
<?php $this->end_section(); ?>
