<?php
/**
 * @var \phpvod\widget\form\admin_form $form
 * @var \venus\view\view $this
 */
\phpvod\asset\bootstrap_table\bootstrap_table::register();
$this->extend('admin/layout');
?>

<?php $this->section('content'); ?>

<div class="card">
	<div class="card-header"><?= lang('admin.mars_map') ?></div>
	<div class="card-body">
		<div id="toolbar" class="toolbar-btn-action">
			<div class="input-group">
				<button type="button" class="btn btn-primary me-2"
				        onclick="window.location='<?= admin_module_uri('mars-map/add') ?>'">
					<span class="mdi mdi-plus me-1" aria-hidden="true"></span><?= lang('app.add') ?>
				</button>
			</div>
		</div>
		<table id="bootstrap-table"></table>
	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>

<?php $this->end_section(); ?>

<?php $this->section('js'); ?>
<script type="text/javascript">
	$.ajaxSetup({headers: <?=csrf_json()?>});
	let bt = new bootstrap_table_helper('backend_video_mars_map');

	let columns = [
		{field: 'id', title: '<?= lang('pv_video_mars_map.id') ?>', visible: bt.visible('id')},
		{field: 'domain', title: '<?= lang('pv_video_mars_map.domain') ?>', visible: bt.visible('domain')},
		{
			field: 'server',
			title: '<?= lang('pv_video_mars_map.server') ?>',
			visible: bt.visible('server'),
			formatter: function(value) {
				let badge = '';
				if (value instanceof Object) {
					$.each(value, function (i, n) {
						if (n !== null) {
							badge += '<span class="badge bg-secondary">' + n + '</span> ';
						}
					});
				}
				return badge === '' ? null : badge;
			}
		},
		{

			field: '__operation__',
			width: 30,
			widthUnit: '%',
			title: '<?=lang('app.operation')?>',
			visible: bt.visible('__operation__'),
			formatter: function (value, row, index, field) {
				return '<button type="button" class="btn btn-outline-primary px-1 py-0 me-1 edit-btn"><i class="mdi mdi-pencil me-1"></i><?=lang('app.edit')?></button>' +
					'<button type="button" class="btn btn-outline-danger px-1 py-0 delete-btn"><i class="mdi mdi-delete me-1"></i><?=lang('app.delete')?></button>';
			},
			events: {
				'click .edit-btn': function (event, value, row, index) {
					event.stopPropagation();
					window.location.href = "<?= admin_module_uri('mars-map/edit')?>" + '?id=' + row.id;
				},
				'click .delete-btn': function (event, value, row, index) {
					event.stopPropagation();
					delete_mars_map(row.id);
				}
			}
		}
	];

	let options = {
		columns,
		url: '<?=admin_module_uri('mars-map/get-data')?>',
		search: true,
		pagination: bt.pagination(),
		pageSize: bt.page_size(),
		locale: '<?=phpvod::$app->language->get_format_language('{lang}-{TAG}')?>',
		onColumnSwitch: function (column, checked) {
			bt.save_hidden_column(column, checked);
		},
		onPageChange: function (number, size) {
			bt.save_page_size(size);
		},
		onTogglePagination: function (status) {
			bt.save_pagination(status);
		},
		queryParams: function (params) {
			//sort
			if (params.sort === undefined) {
				params.sort = 'id';
				params.order = 'asc';
			}
			return params;
		}
	}

	$('#bootstrap-table').bootstrapTable({
		...default_options,
		...options
	});

	function delete_mars_map(id) {
		layer.confirm("<?=lang('app.confirm_deletion')?>", {
			icon: 3,
			title: "<?=lang('app.message')?>",
			btn: ['<?=lang('app.delete')?>', '<?=lang('app.cancel')?>']
		}, function (index) {
			$.post("<?= admin_module_uri('mars-map/delete') ?>", {id: id}, function (r) {
				if (r.id === 1) {
					$('#bootstrap-table').bootstrapTable('refresh');
				} else if (r.hasOwnProperty('msg')) {
					layer.msg(r.msg);
				} else {
					layer.msg('<?=lang('app.unknown_error')?>');
				}
			});
			layer.close(index);
		});
	}
</script>
<?php $this->end_section(); ?>
