<?php
/**
 * @var \phpvod\widget\form\admin_form $form
 * @var \venus\view\view $this
 */
\phpvod\asset\bootstrap_table\bootstrap_table::register();
$this->extend('admin/layout');
?>

<?php $this->section('content'); ?>

<div class="card">
	<div class="card-header"><?= lang('admin.mars_server') ?></div>
	<div class="card-body">
		<div id="toolbar" class="toolbar-btn-action">
			<div class="input-group">
				<button type="button" class="btn btn-primary me-2"
				        onclick="window.location='<?= admin_module_uri('mars-server/add') ?>'">
					<span class="mdi mdi-plus me-1" aria-hidden="true"></span><?= lang('app.add') ?>
				</button>
			</div>
		</div>
		<table id="bootstrap-table"></table>
	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>

<?php $this->end_section(); ?>

<?php $this->section('js'); ?>
<script type="text/javascript">
	$.ajaxSetup({headers: <?=csrf_json()?>});
	let bt = new bootstrap_table_helper('backend_video_mars_server', ['ip', 'port', 'secret_key', 'upload_url']);

	let columns = [
		{field: 'id', title: '<?= lang('pv_video_mars_server.id') ?>', visible: bt.visible('id')},
		{field: 'name', title: '<?= lang('pv_video_mars_server.name') ?>', visible: bt.visible('name')},
		{field: 'ip', title: '<?= lang('pv_video_mars_server.ip') ?>', visible: bt.visible('ip')},
		{field: 'port', title: '<?= lang('pv_video_mars_server.port') ?>', visible: bt.visible('port')},
		{field: 'secret_key', title: '<?= lang('pv_video_mars_server.secret_key') ?>', visible: bt.visible('secret_key')},
		{field: 'upload_url', title: '<?= lang('pv_video_mars_server.upload_url') ?>', visible: bt.visible('upload_url')},
		{field: 'weight', title: '<?= lang('pv_video_mars_server.weight') ?>', visible: bt.visible('weight')},
		{

			field: '__operation__',
			width: 30,
			widthUnit: '%',
			title: '<?=lang('app.operation')?>',
			visible: bt.visible('__operation__'),
			formatter: function (value, row, index, field) {
				return '<button type="button" class="btn btn-outline-success px-1 py-0 me-1 test-conn-btn"><i class="mdi mdi-connection me-1"></i><?=lang('admin.test_conn')?></button>' +
					'<button type="button" class="btn btn-outline-primary px-1 py-0 me-1 edit-btn"><i class="mdi mdi-pencil me-1"></i><?=lang('app.edit')?></button>' +
					'<button type="button" class="btn btn-outline-danger px-1 py-0 delete-btn"><i class="mdi mdi-delete me-1"></i><?=lang('app.delete')?></button>';
			},
			events: {
				'click .test-conn-btn': function (event, value, row, index) {
					event.stopPropagation();
					test_mars_server(row.id);
				},
				'click .edit-btn': function (event, value, row, index) {
					event.stopPropagation();
					window.location.href = "<?= admin_module_uri('mars-server/edit')?>" + '?id=' + row.id;
				},
				'click .delete-btn': function (event, value, row, index) {
					event.stopPropagation();
					delete_mars_server(row.id);
				}
			}
		}
	];

	let options = {
		columns,
		url: '<?=admin_module_uri('mars-server/get-data')?>',
		search: true,
		pagination: bt.pagination(),
		pageSize: bt.page_size(),
		locale: '<?=phpvod::$app->language->get_format_language('{lang}-{TAG}')?>',
		onColumnSwitch: function (column, checked) {
			bt.save_hidden_column(column, checked);
		},
		onPageChange: function (number, size) {
			bt.save_page_size(size);
		},
		onTogglePagination: function (status) {
			bt.save_pagination(status);
		},
		queryParams: function (params) {
			//sort
			if (params.sort === undefined) {
				params.sort = 'id';
				params.order = 'asc';
			}
			return params;
		}
	}

	$('#bootstrap-table').bootstrapTable({
		...default_options,
		...options
	});

	function test_mars_server(id) {

		function get_text(data) {
			if (data === null) {
				return '<span class="text-danger"><?=lang('admin.test_return_null')?></span>';
			} else if (data === false) {
				return '<span class="text-danger"><?=lang('admin.test_return_false')?></span>';
			} else if (typeof data === 'object') {
				if (data.code === '1')
					return '<span class="text-success"><?=lang('admin.test_success')?></span>';
				else if (data.code === '0')
					return '<span class="text-danger"><?=lang('admin.invalid_secret_key')?></span>';
				else if (data.code === '-1')
					return '<span class="text-danger"><?=lang('admin.test_fail')?></span>';
			}
		}

		let index = layer.load(2);
		$.post("<?= admin_module_uri('mars-server/test-conn') ?>", {id: id}, function (r) {
			if (r.id === 1) {
				layer.close(index);
				let server = r.server;
				let c2s = get_text(r.data.c2s);
				let s2c = get_text(r.data.s2c);
				let msg = `
					<?=lang('app.server')?>: ${server.name}(${server.ip}:${server.port})<br />
					<?=lang('admin.c2s')?>: ${c2s}<br />
					<?=lang('admin.s2c')?>: ${s2c}
				`;
				layer.alert(msg);
			} else if (r.hasOwnProperty('msg')) {
				layer.msg(r.msg);
			} else {
				layer.msg('<?=lang('app.unknown_error')?>');
			}
		});
	}

	function delete_mars_server(id) {
		layer.confirm("<?=lang('app.confirm_deletion')?>", {
			icon: 3,
			title: "<?=lang('app.message')?>",
			btn: ['<?=lang('app.delete')?>', '<?=lang('app.cancel')?>']
		}, function (index) {
			$.post("<?= admin_module_uri('mars-server/delete') ?>", {id: id}, function (r) {
				if (r.id === 1) {
					$('#bootstrap-table').bootstrapTable('refresh');
				} else if (r.hasOwnProperty('msg')) {
					layer.msg(r.msg);
				} else {
					layer.msg('<?=lang('app.unknown_error')?>');
				}
			});
			layer.close(index);
		});
	}
</script>
<?php $this->end_section(); ?>
