<?php
/**
 * @var \phpvod\widget\form\admin_form $form
 * @var \venus\view\view $this
 */
\phpvod\asset\bootstrap_table\bootstrap_table::register();
$this->extend('admin/layout');
?>

<?php $this->section('content'); ?>

<div class="card">
	<div class="card-header"><?= lang('admin.player_management') ?></div>
	<div class="card-body">
		<div id="toolbar" class="toolbar-btn-action">
			<div class="input-group">
				<button type="button" class="btn btn-primary me-2"
				        onclick="window.location='<?= admin_module_uri('player/add') ?>'">
					<span class="mdi mdi-plus me-1" aria-hidden="true"></span><?= lang('app.add') ?>
				</button>
			</div>
		</div>
		<table id="bootstrap-table"></table>
	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>

<?php $this->end_section(); ?>

<?php $this->section('js'); ?>
<script type="text/javascript">
    $.ajaxSetup({headers: <?=csrf_json()?>});
    let bt = new bootstrap_table_helper('backend_video_player', ['class']);

    let columns = [
        {field: 'id', title: '<?= lang('pv_video_player.id') ?>', visible: bt.visible('id')},
        {field: 'name', title: '<?= lang('pv_video_player.name') ?>', visible: bt.visible('name')},
        {field: 'description', width: 30, widthUnit: '%', title: '<?= lang('pv_video_player.description') ?>', visible: bt.visible('description')},
        {field: 'class', width: 20, widthUnit: '%', title: '<?= lang('pv_video_player.class') ?>', visible: bt.visible('class')},
        {
            field: 'status',
            title: '<?= lang('pv_video_player.status') ?>',
            visible: bt.visible('status'),
            events: {
                'click .form-check-input[role="switch"]': function (event, value, row, index) {
                    //更改状态
                    event.stopPropagation();
                    $.post("<?= admin_module_uri('player/change-status') ?>", {id: row.id}, function (r) {
                        if (r.id === 1) {
                            $(event.currentTarget).prop("checked", r.data === 1);
                        } else {
                            $(event.currentTarget).prop("checked", !$(event.currentTarget).is(':checked')); //返回之前的状态
                            if (r.hasOwnProperty('msg'))
                                layer.msg(r.msg);
                            else
                                layer.msg('<?=lang('app.unknown_error')?>');
                        }
                    });
                }
            }
        },
	    {

            field: '__operation__',
            width: 15,
            widthUnit: '%',
            title: '<?=lang('app.operation')?>',
            visible: bt.visible('__operation__'),
            formatter: function (value, row, index, field) {
                return '<button type="button" class="btn btn-outline-danger px-1 py-0 delete-btn"><i class="mdi mdi-delete me-1"></i><?=lang('app.delete')?></button>';
            },
            events: {
                'click .delete-btn': function (event, value, row, index) {
                    //删除
                    event.stopPropagation();
                    delete_player(row.id);
                }
            }
        }
    ];

    let options = {
        columns,
        url: '<?=admin_module_uri('player/get-data')?>',
        search: true,
		pagination: bt.pagination(),
		pageSize: bt.page_size(),
        locale: '<?=phpvod::$app->language->get_format_language('{lang}-{TAG}')?>',
		onColumnSwitch: function (column, checked) {
			bt.save_hidden_column(column, checked);
		},
		onPageChange: function(number, size) {
			bt.save_page_size(size);
		},
		onTogglePagination: function(status) {
			bt.save_pagination(status);
		},
        queryParams: function (params) {
			//sort
			if(params.sort === undefined) {
				params.sort = 'id';
				params.order = 'asc';
			}
            return params;
        }
    }

    $('#bootstrap-table').bootstrapTable({
        ...default_options,
        ...options
    });

    function delete_player(id) {
        layer.confirm("<?=lang('app.confirm_deletion')?>", {
            icon: 3,
            title: "<?=lang('app.message')?>",
            btn: ['<?=lang('app.delete')?>', '<?=lang('app.cancel')?>']
        }, function (index) {
            $.post("<?= admin_module_uri('player/delete') ?>", {id: id}, function (r) {
                if (r.id === 1 || r.id === 2) {
                    $('#bootstrap-table').bootstrapTable('refresh');
                    if (r.id === 2) {
                        layer.alert(r.msg); //播放器卸载成功，请手动删除播放器目录
                    }
                } else if (r.hasOwnProperty('msg')) {
                    layer.msg(r.msg);
                } else {
                    layer.msg('<?=lang('app.unknown_error')?>');
                }
            });
            layer.close(index);
        });
    }
</script>
<?php $this->end_section(); ?>
