<?php
/**
 * @var \venus\view\view $this
 */
\phpvod\asset\bootstrap_table\bootstrap_table::register();
$this->extend('admin/layout');
?>

<?php $this->section('content'); ?>

<div class="card">
	<div class="card-header"><?= lang('admin.slide_management') ?></div>
	<div class="card-body">
		<div id="toolbar" class="toolbar-btn-action">
			<div class="input-group">
				<button type="button" class="btn btn-primary me-2"
				        onclick="window.location.href='<?= admin_module_uri('slide/add') ?>'">
					<span class="mdi mdi-plus me-1" aria-hidden="true"></span><?= lang('app.add') ?>
				</button>
			</div>
		</div>
		<table id="bootstrap-table"></table>
	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>

<?php $this->end_section(); ?>

<?php $this->section('js'); ?>

<script type="text/javascript">
    $.ajaxSetup({headers: <?=csrf_json()?>});

    let bt = new bootstrap_table_helper('backend_video_slide', ['link', 'link_text', 'title', 'description']);

    let columns = [
        {field: 'id', title: '<?= lang('pv_video_slide.id') ?>', visible: bt.visible('id')},
		{
			field: 'pic',
			title: '<?= lang('pv_video_slide.pic') ?>',
			visible: bt.visible('pic'),
			formatter: function(value, row, index, field) {
				return value !== null ? '<img src="upload/video/slide/' + value + '" style="max-height: 120px" />' : value;
			}
		},
		{field: 'link', title: '<?= lang('pv_video_slide.link') ?>', visible: bt.visible('link')},
		{field: 'link_text', title: '<?= lang('pv_video_slide.link_text') ?>', visible: bt.visible('link_text')},
		{field: 'title', title: '<?= lang('pv_video_slide.title') ?>', visible: bt.visible('title')},
	    {field: 'description', title: '<?= lang('pv_video_slide.description') ?>', visible: bt.visible('description')},
	    {field: 'sort', title: '<?= lang('pv_video_slide.sort') ?>', width: 10, widthUnit: '%', visible: bt.visible('sort')},
        {
            field: '__operation__',
            title: '<?=lang('app.operation')?>',
            width: 20,
            widthUnit: '%',
            visible: bt.visible('__operation__'),
            formatter: function () {
                return '<button type="button" class="btn btn-outline-primary px-1 py-0 me-1 edit-btn"><i class="mdi mdi-pencil me-1"></i><?=lang('app.edit')?></button>' +
                    '<button type="button" class="btn btn-outline-danger px-1 py-0 del-btn"><i class="mdi mdi-window-close me-1"></i><?=lang('app.delete')?></button>';
            },
            events: {
                'click .edit-btn': function (event, value, row, index) {
                    event.stopPropagation();
                    window.location.href = "<?= admin_module_uri('slide/edit')?>" + '?id=' + row.id;
                },
                'click .del-btn': function (event, value, row, index) {
                    event.stopPropagation();
                    delete_slide(row.id);
                }
            }
        }
    ];

    let options = {
        columns,
        url: '<?=admin_module_uri('slide/get-data')?>',
        search: false,
		pagination: bt.pagination(),
		pageSize: bt.page_size(),
        locale: '<?=phpvod::$app->language->get_format_language('{lang}-{TAG}')?>',
		onColumnSwitch: function (column, checked) {
			bt.save_hidden_column(column, checked);
		},
		onPageChange: function(number, size) {
			bt.save_page_size(size);
		},
		onTogglePagination: function(status) {
			bt.save_pagination(status);
		},
        queryParams: function (params) {
			if(params.sort === undefined) {
				params.sort = 'sort';
				params.order = 'desc';
			}
			return params;
        }
    }

    $('#bootstrap-table').bootstrapTable({
        ...default_options,
        ...options
    });

    function delete_slide(id) {
        layer.confirm("<?=lang('app.confirm_deletion')?>", {
            icon: 3,
            title: "<?=lang('app.message')?>",
            btn: ['<?=lang('app.delete')?>', '<?=lang('app.cancel')?>']
        }, function (index) {
            $.post("<?= admin_module_uri('slide/delete') ?>", {id: id}, function (r) {
                if (r.id === 1) {
                    $('#bootstrap-table').bootstrapTable('refresh');
                } else if (r.hasOwnProperty('msg')) {
                    layer.msg(r.msg);
                } else {
                    layer.msg('<?=lang('app.unknown_error')?>');
                }
            });
            layer.close(index);
        });
    }
</script>
<?php $this->end_section(); ?>
