<?php
/**
 * @var \venus\view\view $this
 */
\phpvod\asset\bootstrap_table\bootstrap_table::register();
$admin_form = \phpvod\widget\form\admin_form::get_instance();
$this->extend('admin/layout');

?>

<?php $this->section('content'); ?>

<div class="card">
	<div class="card-header"><?= lang('admin.video_management') ?></div>
	<div class="card-body">
		<div id="toolbar" class="toolbar-btn-action">
			<div class="input-group">
				<button type="button" class="btn btn-primary me-2"
				        onclick="window.location.href='<?= admin_module_uri('video/add') ?>'">
					<span class="mdi mdi-plus me-1" aria-hidden="true"></span><?= lang('app.add') ?>
				</button>
				<button type="button" class="btn btn-danger me-4" onclick="batch_delete_video()">
					<span class="mdi mdi-window-close me-1" aria-hidden="true"></span><?= lang('app.delete') ?>
				</button>

				<span class="input-group-text"><?= lang('pv_video.category') ?></span>
				<?= $admin_form->select('category', \phpvod\library\options::unlimited() + \video\library\options::category(), null, ['class' => 'form-select']) ?>
				<span class="input-group-text"><?= lang('pv_video.kind') ?></span>
				<?= $admin_form->select('kind', \phpvod\library\options::unlimited() + \video\library\options::kind(), null, ['class' => 'form-select']) ?>
				<span class="input-group-text"><?= lang('pv_video.subject') ?></span>
				<?= $admin_form->input('subject', 'text', options: ['class' => 'form-control']) ?>
				<span class="input-group-text"><?= lang('pv_video.author') ?></span>
				<?= $admin_form->input('author', 'text', options: ['class' => 'form-control']) ?>
				<span class="input-group-text"><?= lang('pv_video.recommend') ?></span>
				<?= $admin_form->select('recommend', \phpvod\library\options::unlimited() + \phpvod\library\options::yes_no(), null, ['class' => 'form-select']) ?>
				<span class="input-group-text"><?= lang('pv_video.status') ?></span>
				<?= $admin_form->select('status', \phpvod\library\options::unlimited() + \phpvod\library\options::yes_no(), null, ['class' => 'form-select']) ?>
				<button type="button" class="btn btn-success search-btn">
					<span class="mdi mdi-magnify me-1" aria-hidden="true"></span><?= lang('app.search') ?>
				</button>
			</div>
		</div>
		<table id="bootstrap-table"></table>
	</div>
	<div class="card-footer">
		<div class="f-tar"><?= phpvod::copyright() ?></div>
	</div>
</div>

<?php $this->end_section(); ?>

<?php $this->section('js'); ?>

<script type="text/javascript">
	$.ajaxSetup({headers: <?=csrf_json()?>});

	let bt = new bootstrap_table_helper('backend_video', ['price', 'duration', 'hits', 'score', 'created_at', 'updated_at']);

	let columns = [
		{checkbox: true, width: 4, widthUnit: 'rem'},
		{field: 'id', title: '<?= lang('pv_video.id') ?>', sortable: true, visible: bt.visible('id')},
		{field: 'category', title: '<?= lang('pv_video.category') ?>', visible: bt.visible('category')},
		{field: 'subject', title: '<?= lang('pv_video.subject') ?>', visible: bt.visible('subject')},
		{
			field: 'kind',
			title: '<?= lang('pv_video.kind') ?>',
			visible: bt.visible('kind'),
			formatter: function (value, row, index, field) {
				if (value == 1)
					return '<?=lang('admin.member_video') ?>';
				else if (value == 2)
					return '<?=lang('admin.paid_video') ?>';
				else
					return '<?=lang('admin.free_video') ?>';
			}
		},
		{
			field: 'price',
			title: '<?= lang('pv_video.price') ?>',
			visible: bt.visible('price'),
			formatter: function(value, row, index, field) {
				return row['kind'] == 2 ? (value / 100).toFixed(2) : null;
			}
		},
		{field: 'author', title: '<?= lang('pv_video.author') ?>', visible: bt.visible('author')},
		{field: 'duration', title: '<?= lang('pv_video.duration') ?>', sortable: true, visible: bt.visible('duration')},
		{field: 'hits', title: '<?= lang('pv_video.hits') ?>', sortable: true, visible: bt.visible('hits')},
		{field: 'score', title: '<?= lang('pv_video.score') ?>', sortable: true, visible: bt.visible('score')},
		{
			field: 'recommend',
			title: '<?= lang('pv_video.recommend') ?>',
			visible: bt.visible('recommend'),
			events: {
				'click .form-check-input[role="recommend-switch"]': function (event, value, row, index) {
					//更改推荐状态
					event.stopPropagation();
					$.post("<?= admin_module_uri('video/change-recommend') ?>", {id: row.id}, function (r) {
						if (r.id === 1) {
							$(event.currentTarget).prop("checked", r.data === 1);
						} else {
							$(event.currentTarget).prop("checked", !$(event.currentTarget).is(':checked')); //返回之前的状态
							if (r.hasOwnProperty('msg'))
								layer.msg(r.msg);
							else
								layer.msg('<?=lang('app.unknown_error')?>');
						}
					});
				}
			}
		},
		{
			field: 'status',
			title: '<?= lang('pv_video.status') ?>',
			visible: bt.visible('status'),
			events: {
				'click .form-check-input[role="status-switch"]': function (event, value, row, index) {
					//更改状态
					event.stopPropagation();
					$.post("<?= admin_module_uri('video/change-status') ?>", {id: row.id}, function (r) {
						if (r.id === 1) {
							$(event.currentTarget).prop("checked", r.data === 1);
						} else {
							$(event.currentTarget).prop("checked", !$(event.currentTarget).is(':checked')); //返回之前的状态
							if (r.hasOwnProperty('msg'))
								layer.msg(r.msg);
							else
								layer.msg('<?=lang('app.unknown_error')?>');
						}
					});
				}
			}
		},
		{field: 'created_at', title: '<?= lang('pv_video.created_at') ?>', sortable: true, visible: bt.visible('created_at')},
		{field: 'updated_at', title: '<?= lang('pv_video.updated_at') ?>', sortable: true, visible: bt.visible('updated_at')},
		{
			field: '__operation__',
			title: '<?=lang('app.operation')?>',
			visible: bt.visible('__operation__'),
			formatter: function () {
				return '<button type="button" class="btn btn-outline-primary px-1 py-0 me-1 edit-btn"><i class="mdi mdi-pencil me-1"></i><?=lang('app.edit')?></button>' +
					'<button type="button" class="btn btn-outline-danger px-1 py-0 del-btn"><i class="mdi mdi-window-close me-1"></i><?=lang('app.delete')?></button>';
			},
			events: {
				'click .edit-btn': function (event, value, row, index) {
					event.stopPropagation();
					window.location.href = "<?= admin_module_uri('video/edit')?>" + '?id=' + row.id;
				},
				'click .del-btn': function (event, value, row, index) {
					event.stopPropagation();
					delete_video(row.id);
				}
			}
		}
	];

	let options = {
		columns,
		url: '<?=admin_module_uri('video/get-data')?>',
		search: false,
		pagination: bt.pagination(),
		pageSize: bt.page_size(),
		locale: '<?=phpvod::$app->language->get_format_language('{lang}-{TAG}')?>',
		onColumnSwitch: function (column, checked) {
			bt.save_hidden_column(column, checked);
		},
		onPageChange: function (number, size) {
			bt.save_page_size(size);
		},
		onTogglePagination: function (status) {
			bt.save_pagination(status);
		},
		queryParams: function (params) {
			//category
			let category_id = $("select[name='category']").val();
			if (category_id !== 'unlimited') {
				params.category_id = category_id;
			}
			//kind
			let kind = $("select[name='kind']").val();
			if (kind !== 'unlimited') {
				params.kind = kind;
			}
			//subject
			let subject = $.trim($("input[name='subject']").val());
			if (subject !== '') {
				params.subject = subject;
			}
			//author
			let author = $.trim($("input[name='author']").val());
			if (author !== '') {
				params.author = author;
			}
			//recommend
			let recommend = $("select[name='recommend']").val();
			if (recommend !== 'unlimited') {
				params.recommend = recommend;
			}
			//status
			let status = $("select[name='status']").val();
			if (status !== 'unlimited') {
				params.status = status;
			}
			//sort
			if (params.sort === undefined) {
				params.sort = 'id';
				params.order = 'desc';
			}
			return params;
		}
	}

	$('#bootstrap-table').bootstrapTable({
		...default_options,
		...options
	});

	function batch_delete_video() {
		let select = $('#bootstrap-table').bootstrapTable('getSelections');
		if (select.length === 0) {
			layer.msg("<?=lang('app.no_object_is_selected')?>");
		} else {
			let id = $.map(select, function (row) {
				return row.id;
			});
			delete_video(id); //id is array
		}
	}

	function delete_video(id) {
		layer.confirm("<?=lang('app.confirm_deletion')?>", {
			icon: 3,
			title: "<?=lang('app.message')?>",
			btn: ['<?=lang('app.delete')?>', '<?=lang('app.cancel')?>']
		}, function (index) {
			$.post("<?= admin_module_uri('video/delete') ?>", {id: id}, function (r) {
				if (r.id === 1) {
					$('#bootstrap-table').bootstrapTable('refresh');
				} else if (r.hasOwnProperty('msg')) {
					layer.msg(r.msg);
				} else {
					layer.msg('<?=lang('app.unknown_error')?>');
				}
			});
			layer.close(index);
		});
	}

	$("#toolbar .search-btn").click(function () {
		$('#bootstrap-table').bootstrapTable('refresh', {pageNumber: 1});
	});
	$("#toolbar input[type='text']").keyup(function (event) {
		if (event.keyCode === 13) { //按回车键开始搜索
			$('#bootstrap-table').bootstrapTable('refresh', {pageNumber: 1});
		}
	});
</script>
<?php $this->end_section(); ?>
