<?php

use video\tag\tag;
use phpvod\widget\pagination\pagination;

/**
 * @var int $id 栏目ID
 * @var \venus\view\view $this
 */
$this->extend('home/layout');
$this->set_vars([
	'header_class' => 'header',
	'page_title' => tag::category()->get_name_by_id($id),
]);
$extra_data = [
	[
		'field' => 'kind',
		'label' => lang('home.kind'),
		'items' => [
			['value' => '0', 'label' => lang('home.kind_free')],
			['value' => '1', 'label' => lang('home.kind_member')],
			['value' => '2', 'label' => lang('home.kind_paid')],
		]
	],
	[
		'field' => 'order',
		'label' => lang('home.newest'),
		'items' => [
			['value' => 'hits', 'label' => lang('home.hot')],
			['value' => 'score', 'label' => lang('home.score')],
		]
	]
];
?>

<?php $this->section('content'); ?>
	<!-- 全屏搜索 -->
<?php $this->include('home/home/subview/search_full'); ?>
	<!-- 导航栏 -->
<?php $this->include('home/home/subview/nav'); ?>

	<div class="category pb-60">
		<div class="container">
			<div class="row">
				<div class="col">
					<nav aria-label="breadcrumb">
						<ol class="breadcrumb">
							<li class="breadcrumb-item"><a href="<?= home_module_uri('/') ?>"><?= lang('app.home') ?></a></li>
							<li class="breadcrumb-item active" aria-current="page"><?= tag::category()->get_name_by_id($id) ?></li>
						</ol>
					</nav>
				</div>
			</div>

			<div class="row">
				<div class="col">
					<!-- 自定义字段 -->
					<div class="video-filter">
						<?php foreach (tag::field()->fetch($id, $extra_data) as $field): ?>
							<ul>
								<li><a <?php if (is_null($field['active'])): ?>class="active" <?php endif; ?>href="<?= home_module_uri('category/' . $id) . (!empty($field['query']) ? '?' . $field['query'] : '') ?>"><?= $field['label'] ?></a></li>
								<?php foreach ($field['items'] as $item): ?>
									<li><a <?php if ($field['active'] == $item['value']): ?>class="active" <?php endif; ?>href="<?= home_module_uri('category/' . $id) . (!empty($item['query']) ? '?' . $item['query'] : '') ?>"><?= $item['label'] ?></a></li>
								<?php endforeach; ?>
							</ul>
						<?php endforeach; ?>
					</div>
				</div>
			</div>
		</div>

		<div class="video-section">
			<div class="container">
				<div class="row gx-3 gy-3 gx-md-4 gy-md-4">

					<?php
					//ext
					$ext = tag::field()->get_ext_param($id);
					//url_pattern
					$get = $_GET;
					unset($get['page']);
					$url_pattern = home_module_uri('category/' . $id) . '?' . (empty($get) ? 'page=' . pagination::NUM_PLACEHOLDER : http_build_query($get) . '&page=' . pagination::NUM_PLACEHOLDER);

					$list = tag::video_list()->fetch(
						category_id: $id,
						kind: $_GET['kind'] ?? null,
						ext: $ext,
						order: isset($_GET['order']) && !is_blank($_GET['order']) ? [$_GET['order'] => 'DESC'] : ['id' => 'DESC'],
						limit: 24,
						current_page: $_GET['page'] ?? 1,
						url_pattern: $url_pattern,
						depend_key: \video\event\handler::DEPEND_KEY_VIDEO_LIST
					);
					?>

					<?php foreach ($list['data'] as $video): ?>
						<div class="col-6 col-sm-4 col-md-3 col-lg-2 video-item">
							<a href="<?= home_module_uri('play/' . $video['id']) ?>" target="_blank">
								<div class="poster-preview-container ratio ratio-138"<?php if (!empty($video['preview'])): ?> data-preview="<?= $video['preview'] ?>"<?php endif; ?>>
									<div class="poster">
										<img src="<?= tag::video()->poster($video['poster']) ?>" />
										<?php if ($video['kind'] == '1'): ?>
											<div class="corner-mark vip">VIP</div>
										<?php elseif ($video['kind'] == '2'): ?>
											<div class="corner-mark paid"><?= lang('home.kind_paid') ?></div>
										<?php endif; ?>
										<?php if (is_numeric($video['duration'])): ?>
											<div class="duration-mark"><?= seconds2duration(intval($video['duration'])) ?></div>
										<?php endif; ?>
									</div>
								</div>
								<div class="subject"><?= $video['subject'] ?></div>
							</a>
						</div>
					<?php endforeach; ?>

				</div>
			</div>
		</div>

		<?php if (!is_null($list['pagination_params'])): ?>
			<div class="container">
				<div class="row">
					<div class="col pt-3 text-end ">
						<?= (new pagination(
							$list['pagination_params']['total_items'],
							$list['pagination_params']['items_per_page'],
							$list['pagination_params']['current_page'],
							$list['pagination_params']['url_pattern']
						))->set_template('bootstrap')->set_align(pagination::ALIGN_CENTER)->render(); ?>
					</div>
				</div>
			</div>
		<?php endif; ?>

	</div>
<?php $this->end_section(); ?>