<?php

use video\tag\tag;

/**
 * @var \venus\view\view $this
 * @var int $id
 * @var int $group
 * @var int $index
 * @var array $details
 */
$this->extend('home/layout');
$this->set_vars([
	'header_class' => 'header',
	'page_title' => $details['subject'],
	'page_keywords' => $details['subject'],
	'page_description' => !empty($details['content']) ? trim($details['content']) : null
]);
$comment_module_is_valid = phpvod::$app->module->is_valid_module('comment');
?>

<?php $this->section('content'); ?>

<!-- 全屏搜索 -->
<?php $this->include('home/home/subview/search_full'); ?>
<!-- 导航栏 -->
<?php $this->include('home/home/subview/nav'); ?>

<div class="play">
	<div class="container pb-60">
		<!-- breadcrumb -->
		<div class="row">
			<div class="col">
				<nav aria-label="breadcrumb">
					<ol class="breadcrumb">
						<li class="breadcrumb-item"><a href="<?= home_module_uri('/') ?>"><?= lang('app.home') ?></a></li>
						<li class="breadcrumb-item"><a href="<?= home_module_uri('category/' . $details['category_id']) ?>"><?= tag::category()->get_name_by_id($details['category_id']) ?></a></li>
						<li class="breadcrumb-item active" aria-current="page"><?= $details['subject'] ?></li>
					</ol>
				</nav>
			</div>
		</div>
		<!-- player -->
		<div class="row">
			<div class="col-12">
				<div class="ratio ratio-16x9" style="background-color: #dddddd">
					<?php if ($details['kind'] == '1' && get_permission('video:allow_play_member_video') != '1'): ?> <!--会员视频(VIP)-->
						<div class="tips">
							<div class="text-center">
								<p><?= lang('home.no_permission_to_play') ?></p>
								<?php if (phpvod::$app->user_auth->frontend_is_logged_in()): ?>
									<p><a class="btn btn-primary btn-sm" href="<?= home_uri('member/buy-member-group') ?>"><?= lang('home.buy_member_group') ?></a></p>
								<?php else: ?>
									<p><a class="btn btn-primary btn-sm" onclick="$('.login-btn').click();"><?= lang('app.login') ?></a></p>
								<?php endif; ?>
							</div>
						</div>
					<?php elseif ($details['kind'] == '2' && !tag::video_details()->has_purchased($id)): ?> <!--收费视频-->
						<div class="tips">
							<div class="text-center">
								<?php if (phpvod::$app->user_auth->frontend_is_logged_in()): ?>
									<?php
									$discount = floatval(get_permission('video:video_purchase_discount'));
									$discount_price = number_format(ceil($details['price'] * $discount) / 100, 2, '.', '');
									?>
									<p><?= lang('home.watch_after_purchase') ?></p>
									<p><a class="btn btn-primary btn-sm" onclick="buy_video(<?= $id ?>)"><?= lang('home.buy_video', [$discount_price]) ?></a></p>
								<?php else: ?>
									<p><?= lang('app.please_login_first') ?></p>
									<p><a class="btn btn-primary btn-sm" onclick="$('.login-btn').click();"><?= lang('app.login') ?></a></p>
								<?php endif; ?>
							</div>
						</div>
					<?php else: ?>
						<?php
						$player_name = $details['video_url'][$group]['player'];
						$player = tag::video()->get_player($player_name);
						if (is_null($player)):
							?>
							<div class="tips">
								<div class="text-center"><p><?= lang('home.invalid_player', [$player_name]) ?></p></div>
							</div>
						<?php
						else:
							$url = tag::video_details()->get_play_url($details, $group, $index);
							if (is_null($url)):
								?>
								<div class="tips">
									<div class="text-center"><p><?= lang('home.invalid_url') ?></p></div>
								</div>
							<?php
							else:
								$remote_data = tag::video_details()->get_remote_data($details, $group, $index, ['player_poster', 'sprite']);
								$player->set_url($url)->set_poster($remote_data['player_poster'] ?? $details['poster']);
								if($player instanceof \video\extension\player\videojs\videojs) {
									$player->set_preview($remote_data['sprite'] ?? []);
								}
								$player->show();
							endif;
						endif;
						?>
					<?php endif; ?>
				</div>
			</div>
		</div>

		<!-- nav-tabs -->
		<div class="row">
			<div class="col-12">
				<ul class="nav nav-tabs pt-3" role="tablist">
					<!-- video tab -->
					<li class="nav-item">
						<button class="nav-link active" data-bs-toggle="tab" data-bs-target="#video-tab-pane" role="tab"><?= lang('home.video') ?></button>
					</li>

					<?php if ($comment_module_is_valid): ?>
						<!-- comment tab -->
						<li class="nav-item">
							<button class="nav-link" data-bs-toggle="tab" data-bs-target="#comment-tab-pane" role="tab"><?= lang('home.comment') ?></button>
						</li>
					<?php endif; ?>
				</ul>
			</div>
			<div class="col-12">
				<div class="tab-content py-4">
					<!-- video-tab-panel -->
					<div id="video-tab-pane" class="tab-pane fade show active" role="tabpanel">
						<div class="row">
							<div class="d-none d-md-block col-md-3 col-lg-3 col-xl-3">
								<div class="poster ratio ratio-138">
									<img src="<?= tag::video()->poster($details['poster']) ?>"/>
								</div>
							</div>
							<div class="col-12 col-md-9 col-lg-9 col-xl-9">
								<!-- 视频信息 -->
								<div class="info">
									<div class="subject"><?= $details['subject'] ?></div>
									<div class="data">
										<div class="item hits"><i class="mdi mdi-fire"></i><span><?= $details['hits'] ?></span></div>
										<div class="item score"><i class="mdi mdi-star-half-full"></i><span><?= $details['score'] * 2 ?></span></div>
										<div class="item stars">
											<select id="bar-rating" style="display: none;">
												<option value="1">1</option>
												<option value="2">2</option>
												<option value="3">3</option>
												<option value="4">4</option>
												<option value="5">5</option>
											</select>
										</div>
									</div>
									<div class="tags">
										<!--category-->
										<a href="<?= home_module_uri('category/' . $details['category_id']) ?>">
											<span class="badge bg-primary" data-bs-toggle="tooltip" data-bs-placement="top" title="<?= lang('home.category') ?>"><?= tag::category()->get_name_by_id($details['category_id']) ?></span>
										</a>
										<!--kind-->
										<a href="<?= home_module_uri('search') . '?kind=' . $details['kind'] ?>">
									<span class="badge bg-primary" data-bs-toggle="tooltip" data-bs-placement="top" title="<?= lang('home.kind') ?>"><?= match ($details['kind']) {
											'1' => lang('home.kind_member'),
											'2' => lang('home.kind_paid'),
											default => lang('home.kind_free')
										} ?></span>
										</a>
										<!--recommend-->
										<?php if ($details['recommend'] == '1'): ?>
											<a href="<?= home_module_uri('search') . '?recommend=1' ?>">
												<span class="badge bg-primary" data-bs-toggle="tooltip" data-bs-placement="top" title="<?= lang('home.recommend') ?>"><?= lang('home.recommend') ?></span>
											</a>
										<?php endif; ?>
										<!-- author -->
										<a href="<?= home_module_uri('search') . '?' . http_build_query(['author_id' => $details['author_id'], 'author_identity' => $details['author_identity']]) ?>">
											<span class="badge bg-primary" data-bs-toggle="tooltip" data-bs-placement="top" title="<?= lang('home.author') ?>"><?= $details['author'] ?></span>
										</a>
										<!-- updated_at -->
										<span class="badge bg-secondary" data-bs-toggle="tooltip" data-bs-placement="top" title="<?= lang('home.updated_at') ?>"><?= timetostr($details['updated_at'], 'Y-m-d') ?></span>
										<!--video_ext-->
										<?php foreach ($details['video_ext'] as $video_ext): ?>
											<a href="<?= home_module_uri('search') . '?' . http_build_query([$video_ext['field'] => $video_ext['value']]) ?>">
												<span class="badge bg-success" data-bs-toggle="tooltip" data-bs-placement="top" title="<?= $video_ext['field_label'] ?>"><?= $video_ext['value_label'] ?></span>
											</a>
										<?php endforeach; ?>
									</div>
									<?php if (!empty($details['content'])): ?>
										<div class="content mt-3"><?= $details['content'] ?></div>
									<?php endif; ?>
								</div>

								<!-- 播放列表 -->
								<div class="play-group mt-4">
									<ul class="nav nav-tabs">
										<?php foreach ($details['video_url'] as $key => $value): ?>
											<li class="nav-item">
												<button class="nav-link<?php if ($group == $key): ?> active<?php endif; ?>" data-bs-toggle="tab" data-bs-target="#video-url-<?= $key ?>"><?= !is_blank($value['group_name']) ? $value['group_name'] : lang('home.play_group', [$key + 1]) ?></button>
											</li>
										<?php endforeach; ?>
									</ul>

									<div class="btn-group btn-group-sm" role="group" aria-label="Basic radio toggle button group">
										<input type="radio" class="btn-check" name="view" id="btn-list" autocomplete="off" onchange="change_view('list')">
										<label class="btn btn-outline-secondary" for="btn-list"><span class="mdi mdi-view-module"></span></label>
										<input type="radio" class="btn-check" name="view" id="btn-details" autocomplete="off" onchange="change_view('details')">
										<label class="btn btn-outline-secondary" for="btn-details"><span class="mdi mdi-view-list"></span></label>
									</div>

									<div class="tab-content pt-4 pb-4">
										<?php foreach ($details['video_url'] as $key => $value): ?>
											<div id="video-url-<?= $key ?>" class="tab-pane fade<?php if ($group == $key): ?> show active<?php endif; ?>">
												<!-- 列表视图 -->
												<ul class="list f-d-n">
													<?php foreach ($value['url'] as $idx => $url): ?>
														<li><a href="<?= home_module_uri("play/$id/$key/$idx") ?>"<?php if ($group == $key && $index == $idx): ?> class="active"<?php endif; ?>><?= $url['label'] ?? $idx + 1 ?></a></li>
													<?php endforeach; ?>
												</ul>
												<!-- 详情视图 -->
												<table class="table table-borderless table-hover details f-d-n">
													<tbody>
													<?php
													foreach ($value['url'] as $idx => $url):
														$images = $array = [];
														$remote_data = tag::video_details()->get_remote_data($details, $key, $idx, ['static', 'dynamic']);
														if(isset($remote_data['static'])) $array = array_merge($array, is_array($remote_data['static']) ? $remote_data['static'] : [$remote_data['static']]);
														if(isset($remote_data['dynamic'])) $array = array_merge($array, is_array($remote_data['dynamic']) ? $remote_data['dynamic'] : [$remote_data['dynamic']]);
														foreach ($array as $src) {
															$images[] = ['src' => $src, 'title' => basename($src)];
														}
														?>
														<tr>
															<td class="label"><?= $url['label'] ?? $idx + 1 ?></td>
															<td class="duration"><?= isset($url['value']['file_info']['duration']) ? seconds2duration(round($url['value']['file_info']['duration'])) : '' ?></td>
															<td class="operation">
																<a href="<?= home_module_uri("play/$id/$key/$idx") ?>" class="btn btn-outline-primary px-1 py-0"><i class="mdi mdi-play me-1"></i><?= lang('home.play') ?></a>
																<?php if (!empty($images)): ?>
																	<a onclick="show_image(this)" class="btn btn-outline-danger px-1 py-0" data-image="<?= base64_encode(formatter($images)) ?>"><i class="mdi mdi-image me-1"></i><?= lang('home.screenshot') ?></a>
																<?php endif; ?>
															</td>
														</tr>
													<?php endforeach; ?>
													</tbody>
												</table>
											</div>
										<?php endforeach; ?>
									</div>

								</div>
							</div>
						</div>
					</div>

					<?php if ($comment_module_is_valid): ?>
						<!-- comment-tab-panel -->
						<div id="comment-tab-pane" class="tab-pane fade" role="tabpanel">
							<div id="comment-container">
								<div class="text-center">Loading...</div>
							</div>
						</div>
					<?php endif; ?>
				</div>
			</div>
		</div>
		<!-- related-videos -->
		<?php $list = tag::video_list()->fetch(category_id: $details['category_id'], order: ['hits' => 'DESC', 'id' => 'DESC'], limit: 10, depend_key: \video\event\handler::DEPEND_KEY_VIDEO_LIST); ?>
		<?php if (!empty($list['data'])): ?>
			<div class="row pt-60">
				<section class="video-section">
					<div class="col-12 mb-5">
						<div class="title"><?= lang('home.related_video') ?></div>
					</div>
					<div class="col-12">
						<div class="row gx-3 gy-3 gx-md-4 gy-md-4">
							<?php foreach ($list['data'] as $video): ?>
								<div class="col-6 col-sm-4 col-md-3 col-lg-2 video-item">
									<a href="<?= home_module_uri('play/' . $video['id']) ?>" target="_blank">
										<div class="poster-preview-container ratio ratio-138"<?php if (!empty($video['preview'])): ?> data-preview="<?= $video['preview'] ?>"<?php endif; ?>>
											<div class="poster">
												<img src="<?= tag::video()->poster($video['poster']) ?>"/>
												<?php if ($video['kind'] == '1'): ?>
													<div class="corner-mark vip">VIP</div>
												<?php elseif ($video['kind'] == '2'): ?>
													<div class="corner-mark paid"><?= lang('home.kind_paid') ?></div>
												<?php endif; ?>
												<?php if (is_numeric($video['duration'])): ?>
													<div class="duration-mark"><?= seconds2duration(intval($video['duration'])) ?></div>
												<?php endif; ?>
											</div>
										</div>
										<div class="subject"><?= $video['subject'] ?></div>
									</a>
								</div>
							<?php endforeach; ?>
						</div>
					</div>
				</section>
			</div>
		<?php endif; ?>
	</div>
</div>

<?php $this->end_section(); ?>
<?php $this->section('js'); ?>
<script type="text/javascript">
	/**
	 * 评分
	 * @param id
	 * @param init_rating
	 * @param container_id
	 */
	function video_rating(id, init_rating, container_id) {
		$('#' + container_id).barrating({
			theme: 'materialdesignicons-stars',
			initialRating: init_rating,
			onSelect: function (value, text) {
				let ids = [];
				let key = 'video_rating';
				let video_rating = localStorage.getItem(key);
				if (video_rating != null) {
					ids = JSON.parse(video_rating);
				}
				if (ids.includes(id)) {
					layer.msg("<?= lang('home.score_repeat') ?>");
					return;
				}
				$.post("<?= api_module_uri('score/index')?>", {id, value}, function (r) {
					if (r.id === 1) {
						ids.push(id);
						localStorage.setItem(key, JSON.stringify(ids));
						layer.msg(r.msg);
					} else if (r.hasOwnProperty('msg')) {
						layer.msg(r.msg);
					} else {
						layer.msg('<?=lang('app.unknown_error')?>');
					}
				});
			}
		});
	}

	video_rating(<?=$id?>, <?=floor($details['score'])?>, 'bar-rating');

	//评论TAB
	<?php if ($comment_module_is_valid):  ?>
	let comment_tab = document.querySelector('button[data-bs-target="#comment-tab-pane"]');
	let comment_loaded = false;
	comment_tab.addEventListener('shown.bs.tab', function (event) {
		if (!comment_loaded) {
			<?php echo \comment\tag\tag::comment()->fetch('comment-container', 'video', $id) ?>
			comment_loaded = true;
		}
	});
	<?php endif; ?>

	/**
	 * 更改视图
	 * @param play_group_view
	 */
	function change_view(play_group_view) {
		['list', 'details'].forEach(function (item) {
			let btn_el = $('#btn-' + item);
			let el = $('.play-group .tab-pane .' + item);
			if (item === play_group_view) {
				btn_el.attr('checked', 'checked');
				el.removeClass('f-d-n')
				localStorage.setItem('play_group_view', item);
			} else {
				btn_el.removeAttr('checked');
				el.addClass('f-d-n');
			}
		});
	}

	/**
	 * 初始化视图
	 */
	function init_view() {
		let play_group_view = localStorage.getItem('play_group_view');
		if (play_group_view === null) {
			play_group_view = 'list';
		}
		change_view(play_group_view);
	}

	init_view();

	/**
	 * 显示截图
	 * @param obj
	 */
	function show_image(obj) {
		try {
			let items = JSON.parse(atob($(obj).attr('data-image')));
			if (items instanceof Array) {
				$.magnificPopup.open({
					items: items,
					type: 'image',
					gallery: {
						enabled: true
					}
				}, 0);
			}
		} catch (e) {
			layer.msg('<?=lang('app.invalid_params')?>');
		}
	}

	/**
	 * 购买视频
	 * @param id
	 */
	function buy_video(id) {
		layer.confirm("<?=lang('home.confirm_buy_video', [$discount_price ?? '-'])?>", {
			icon: 3,
			title: "<?=lang('app.message')?>",
			btn: ['<?=lang('app.ok')?>', '<?=lang('app.cancel')?>']
		}, function (layer_index) {
			$.post("<?= api_module_uri('video/buy-video')?>", {id}, function (r) {
				if (r.id === 1) {
					layer.msg(r.msg);
					setTimeout(function () {
						location.reload();
					}, 1500);
				} else if (r.hasOwnProperty('msg')) {
					layer.msg(r.msg);
				} else {
					layer.msg('<?=lang('app.unknown_error')?>');
				}
			});
			layer.close(layer_index);
		});
	}

</script>
<?php $this->end_section(); ?>
